@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: H20_dwarf.c,v 1.1 2001/11/01 14:23:27 alor Exp $
+    $Id: H20_dwarf.c,v 1.2 2002/02/22 19:48:56 alor Exp $
 */
 
 #include <stdio.h>
@@ -41,7 +41,7 @@ void Parse_SMTP_mail(u_char *data);
 
 // plugin operation
 
-struct plugin_ops ops = {
+struct plugin_ops dwarf_ops = {
    ettercap_version: VERSION,
    plug_info:        "logs all mail (POP SMTP) activity",
    plug_version:     10,
@@ -54,7 +54,7 @@ struct plugin_ops ops = {
 
 int Plugin_Init(void *params)
 {
-   return Plugin_Register(params, &ops);
+   return Plugin_Register(params, &dwarf_ops);
 }
 
 int Plugin_Fini(void *params)
