@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: H30_thief.c,v 1.3 2002/02/01 20:55:11 alor Exp $
+    $Id: H30_thief.c,v 1.7 2002/04/19 15:47:35 alor Exp $
 */
 
 #include <stdio.h>
@@ -27,13 +27,14 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
+//#define DEBUG 1
+
 #include "../../src/include/ec_main.h"
 #include "../../src/include/ec_plugins.h"
 #include "../../src/include/ec_error.h"
 #include "../../src/include/ec_inet_structures.h"
 #include "../../src/include/ec_debug.h"
 
-//#define DEBUG
 
 struct state_machine   // state machine double linked list for some protocol dissector
 {
@@ -74,7 +75,7 @@ char * Thief_mime(char *mime);
 
 // plugin operation
 
-struct plugin_ops ops = {
+struct plugin_ops thief_ops = {
    ettercap_version: VERSION,
    plug_info:        "steal files from HTTP stream",
    plug_version:     10,
@@ -87,7 +88,7 @@ struct plugin_ops ops = {
 
 int Plugin_Init(void *params)
 {
-   return Plugin_Register(params, &ops);
+   return Plugin_Register(params, &thief_ops);
 }
 
 int Plugin_Fini(void *params)
@@ -99,7 +100,6 @@ int Plugin_Fini(void *params)
 
 
 
-
 int Parse_Packet(void *data)
 {
 
@@ -130,43 +130,39 @@ int Parse_Packet(void *data)
 
    if ( (length = Thief_StateMachine_GetStatus(data_from_ettercap->connection, &ftw)) )
    {
-      #ifdef DEBUG
-         Debug_msg("Thief content reget -- [%d] \n", length);
-      #endif
+      DEBUG_MSG("Thief content reget -- [%d] \n", length);
 
       write(ftw, collector, data_from_ettercap->connection->datalen);
 
       Thief_StateMachine_SetStatus(data_from_ettercap->connection, length - data_from_ettercap->connection->datalen, ftw );
 
-      #ifdef DEBUG
-         Debug_msg("Thief content end -- [%d] \n", length - data_from_ettercap->connection->datalen);
-      #endif
+      DEBUG_MSG("Thief content end -- [%d] \n", length - data_from_ettercap->connection->datalen);
 
-   }
-   else
-   {
-      if ( (c = strstr(collector, "Content-Length: ")) )
-      {
+   } else {
+      if ( (c = strstr(collector, "Content-Length: ")) ) {
          char *q, *t;
+
+         DEBUG_MSG("Content-Length = [%s]", c);
+         
          q = strdup(c);
          t = strstr(q, "\r");
-         *t = 0;
+         if (t) *t = 0;
          c = q + strlen("Content-Length: ");
 
          length = atoi(c);
          free(q);
+
       }
 
-      if ( (p = strstr(collector, "Content-Type: ")) )
-      {
+      if ( (p = strstr(collector, "Content-Type: ")) ) {
          char *q, *t, *to_write;
-         char filename[50];
+         char filename[150];
          char *ext;
-         int write_len;
+         int write_len = 0;
 
          q = strdup(p);
          t = strstr(q, "\r");
-         *t = 0;
+         if (t) *t = 0;
          p = q + strlen("Content-Type: ");
 
          ext = Thief_mime(p);
@@ -177,29 +173,36 @@ int Parse_Packet(void *data)
             return 0;
          }
 
-         #ifdef DEBUG
-            Debug_msg("Thief content -- [%s] -- [%s] -- [%d]\n", p, ext, length);
-         #endif
+         if (!length) return 0;
+         
+	      mkdir("./TheivedFiles", 0755);
 
-         sprintf(filename, "./%s-%d.%s", data_from_ettercap->connection->source_ip, file_number++, ext);
+         sprintf(filename, "./TheivedFiles/%s-%d.%s", data_from_ettercap->connection->source_ip, file_number++, ext);
 
+         DEBUG_MSG("Thief content -- [%d] -- [%s]\n", length, filename);
+         
          ftw = open( filename, O_CREAT|O_TRUNC|O_WRONLY, 0600 );
 
          Thief_StateMachine_SetStatus(data_from_ettercap->connection, length, ftw );
 
          to_write = strstr(collector, "\r\n\r\n");
+         if (!to_write) return 0;
+         
          to_write += 4;
 
          write_len = data_from_ettercap->connection->datalen - ((int)to_write - (int)collector);
-
+         
+         if (write_len <= 0) return 0;
+         
+         DEBUG_MSG("Thief write -- [%d] -- [%d] -- [%s]\n", length, write_len, filename);
+         
          write(ftw, to_write, write_len);
-
+         
+         if (length - write_len <= 0) return 0;
+         
+         DEBUG_MSG("Thief content byte LEFT -- [%d] -- [%s]\n", length - write_len, filename);
+         
          Thief_StateMachine_SetStatus(data_from_ettercap->connection, length - write_len, ftw );
-
-         #ifdef DEBUG
-            Debug_msg("Thief content end -- [%d] \n", length - write_len);
-         #endif
-
       }
 
    }
@@ -252,21 +255,17 @@ int Thief_StateMachine_SetStatus(CONNECTION *data_to_ettercap, int length, int f
              ptr->dest_port == data_to_ettercap->source_port))
           )
       {
-         #ifdef DEBUG
-            Debug_msg("\tThief_StateMachine_SetStatus -  %s:%d - %s:%d -- [%d]",
-                        data_to_ettercap->source_ip,
-                        data_to_ettercap->source_port,
-                        data_to_ettercap->dest_ip,
-                        data_to_ettercap->dest_port,
-                        length);
-         #endif
-         if (length)
-         {
+         DEBUG_MSG("\tThief_StateMachine_SetStatus -  %s:%d - %s:%d -- [%d]",
+                data_to_ettercap->source_ip,
+                data_to_ettercap->source_port,
+                data_to_ettercap->dest_ip,
+                data_to_ettercap->dest_port,
+                length);
+         
+         if (length) {
             ptr->length = length;
             return 0;
-         }
-         else
-         {
+         } else {
             close(ptr->f);
             LIST_REMOVE(ptr, next);
             free(ptr);
@@ -277,14 +276,12 @@ int Thief_StateMachine_SetStatus(CONNECTION *data_to_ettercap, int length, int f
 
    if (length)
    {
-      #ifdef DEBUG
-         Debug_msg("\tThief_StateMachine_SetStatus - new item - state %s:%d - %s:%d -- [%d]",
-                      data_to_ettercap->source_ip,
-                      data_to_ettercap->source_port,
-                      data_to_ettercap->dest_ip,
-                      data_to_ettercap->dest_port,
-                      length);
-      #endif
+     DEBUG_MSG("\tThief_StateMachine_SetStatus - new item - state %s:%d - %s:%d -- [%d]",
+              data_to_ettercap->source_ip,
+              data_to_ettercap->source_port,
+              data_to_ettercap->dest_ip,
+              data_to_ettercap->dest_port,
+              length);
 
       current = (struct state_machine *)calloc(1, sizeof(struct state_machine));
       if (current == NULL)
@@ -328,8 +325,7 @@ char * Thief_mime(char *mime)
          if (!fto)
             Error_msg("Can't open \"etter.mime\" file !!");
 
-      while (fgets (line, 1024, fto))
-      {
+      while (fgets (line, 1024, fto)) {
          if ( (ptr = strchr(line, '#')) )
             *ptr = 0;
 
@@ -352,10 +348,8 @@ char * Thief_mime(char *mime)
    }
 
    mime_index = mime_list;
-   for( ; mime_index; mime_index = (mime_database *)mime_index->next)
-   {
-      if (!strcmp(mime_index->mime, mime))
-      {
+   for( ; mime_index; mime_index = (mime_database *)mime_index->next) {
+      if (!strcmp(mime_index->mime, mime)) {
          return mime_index->extension;
       }
    }
