@@ -19,7 +19,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: arpcop.c,v 1.4 2001/12/20 20:09:44 alor Exp $
+    $Id: arpcop.c,v 1.5 2002/02/22 19:48:56 alor Exp $
 */
 
 #include <stdio.h>
@@ -63,7 +63,7 @@ void Parse_packet(char *buffer);
 
 // plugin operation
 
-struct plugin_ops ops = {
+struct plugin_ops arpcop_ops = {
    ettercap_version: VERSION,
    plug_info:        "Report suspicious ARP activity",
    plug_version:     10,
@@ -76,7 +76,7 @@ struct plugin_ops ops = {
 
 int Plugin_Init(void *params)
 {
-   return Plugin_Register(params, &ops);
+   return Plugin_Register(params, &arpcop_ops);
 }
 
 int Plugin_Fini(void *params)
