@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ooze.c,v 1.3 2001/09/27 19:07:40 alor Exp $
+    $Id: ooze.c,v 1.4 2002/02/22 19:48:56 alor Exp $
 */
 
 
@@ -41,7 +41,7 @@ int ooze_function(void *dummy);
 
 // plugin operation
 
-struct plugin_ops ops = {
+struct plugin_ops ooze_ops = {
    ettercap_version: VERSION,
    plug_info:        "Ping a host",
    plug_version:     14,
@@ -54,7 +54,7 @@ struct plugin_ops ops = {
 
 int Plugin_Init(void *params)
 {
-   return Plugin_Register(params, &ops);
+   return Plugin_Register(params, &ooze_ops);
 }
 
 int Plugin_Fini(void *params)
