@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: shadow.c,v 1.3 2001/09/27 19:07:40 alor Exp $
+    $Id: shadow.c,v 1.4 2002/02/22 19:48:56 alor Exp $
 */
 
 #include <stdlib.h>
@@ -49,7 +49,7 @@ void Parse_packet(char *buffer);
 
 // plugin operation
 
-struct plugin_ops ops = {
+struct plugin_ops shadow_ops = {
    ettercap_version: VERSION,
    plug_info:        "A very simple SYN/TCP port scanner",
    plug_version:     18,
@@ -62,7 +62,7 @@ struct plugin_ops ops = {
 
 int Plugin_Init(void *params)
 {
-   return Plugin_Register(params, &ops);
+   return Plugin_Register(params, &shadow_ops);
 }
 
 int Plugin_Fini(void *params)
