@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: spectre.c,v 1.5 2002/02/10 10:07:01 alor Exp $
+    $Id: spectre.c,v 1.6 2002/02/22 19:48:56 alor Exp $
 */
 
 #include <stdlib.h>
@@ -39,7 +39,7 @@ int spectre_function(void *dummy);
 
 // plugin operation
 
-struct plugin_ops ops = {
+struct plugin_ops spectre_ops = {
    ettercap_version: VERSION,
    plug_info:        "Flood the LAN with random MAC addresses",
    plug_version:     13,
@@ -52,7 +52,7 @@ struct plugin_ops ops = {
 
 int Plugin_Init(void *params)
 {
-   return Plugin_Register(params, &ops);
+   return Plugin_Register(params, &spectre_ops);
 }
 
 int Plugin_Fini(void *params)
