@@ -19,12 +19,20 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_inet_BSD.c,v 1.9 2002/02/11 01:15:48 alor Exp $
+    $Id: ec_inet_BSD.c,v 1.14 2002/04/11 20:16:36 alor Exp $
 */
 
+#include "../../include/ec_main.h"
 
-// This file is included from ../ec_inet.c
+#include "../../include/ec_inet.h"
+#include "../../include/ec_thread.h"
+#include "../../include/ec_buffer.h"
+#include "../../include/ec_inet_forge.h"
+#include "../../include/ec_inet_structures.h"
 
+#include <ctype.h>
+#include <sys/ioctl.h>
+#include <fcntl.h>
 
 #include <sys/sysctl.h>
 #include <sys/param.h>
@@ -52,10 +60,37 @@
 #endif
 
 
-int fdprom;
+int IpForward_status;      // old ipforward status
+
+int bpf_in_use;
 int size;
 int SocketBuffer = -1;
 
+static char ARP_BROADCAST[6] = {0x0,0x0,0x0,0x0,0x0,0x0};
+
+// protos...
+
+int Inet_FindIFace(char *iface);
+int Inet_CorrectIface(char *iface);
+int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, u_long *IP, u_long *NetMask);
+int Inet_SetPromisc(char *iface);
+int Inet_OpenRawSock(char *iface);
+void Inet_CloseRawSock(int sock);
+int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type);
+int Inet_SendRawPacket(int sock, char *buffer, int len);
+void Inet_Restore_ifr(void);
+void Inet_DisableForwarding(void);
+void Inet_RestoreForwarding(void);
+char *Inet_MacFromIP(unsigned long ip);
+#ifdef PERMIT_HTTPS
+   void Inet_UnSetARPEntry(void);
+   int Inet_SetARPEntry(unsigned long IP, char MAC[6]);
+   void Inet_UnsetRoute(void);
+   void Inet_SetRoute(void);
+#endif
+
+
+// ----------------------------------------------
 
 int Inet_FindIFace(char *iface)
 {
@@ -63,7 +98,7 @@ int Inet_FindIFace(char *iface)
    struct ifaddrs *ifalist, *ifa, *ifp = NULL;
 
    if (getifaddrs(&ifalist) != 0)
-      Error_msg("ec_inet_BSD:%d  getifaddrs() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("getifaddrs()");
 
 
    for (ifa = ifalist; ifa; ifa = ifa->ifa_next)
@@ -82,9 +117,7 @@ int Inet_FindIFace(char *iface)
 
    strlcpy(iface, ifp->ifa_name, sizeof(Options.netiface));
 
-#ifdef DEBUG
-   Debug_msg("Inet_FindIFace -- %s found !!", iface);
-#endif
+   DEBUG_MSG("Inet_FindIFace -- %s found !!", iface);
 
    free(ifalist);
    return 0;
@@ -103,20 +136,20 @@ int Inet_FindIFace(char *iface)
 
    fd = socket(AF_INET, SOCK_DGRAM, 0);
    if (fd < 0)
-      Error_msg("ec_inet_BSD:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("socket()");
 
    buf_size = 8192;
 
    for (;;) {
       buf = malloc (buf_size);
       if (buf == NULL)
-         Error_msg("ec_inet_BSD:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG("malloc()");
 
       ifc.ifc_len = buf_size;
       ifc.ifc_buf = buf;
       memset (buf, 0, buf_size);
       if (ioctl(fd, SIOCGIFCONF, (char *)&ifc) < 0 && errno != EINVAL)
-         Error_msg("ec_inet_BSD:%d ioctl(SIOCGIFCONF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFCONF)");
 
       if (ifc.ifc_len < buf_size)
          break;
@@ -152,12 +185,10 @@ int Inet_FindIFace(char *iface)
       {
          if (errno == ENXIO)
             continue;
-         Error_msg("ec_inet_BSD:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFFLAGS)");
       }
 
-#ifdef DEBUG
-   Debug_msg("Inet_FindIFace -- check for [%s]", ifr.ifr_name);
-#endif
+      DEBUG_MSG("Inet_FindIFace -- check for [%s]", ifr.ifr_name);
 
       /* Must be up and not the loopback */
       if ((ifr.ifr_flags & IFF_UP) == 0 || (ifr.ifr_flags & IFF_LOOPBACK) != 0  || !strncmp(ifr.ifa_name, "pflog", 5))
@@ -190,9 +221,7 @@ int Inet_FindIFace(char *iface)
 
    free(buf);
 
-#ifdef DEBUG
-   Debug_msg("Inet_FindIFace -- %s found !!", iface);
-#endif
+   DEBUG_MSG("Inet_FindIFace -- %s found !!", iface);
 
    return 0;
 
@@ -206,12 +235,10 @@ int Inet_CorrectIface(char *iface)
 #ifdef HAVE_GETIFADDRS
    struct ifaddrs *ifalist, *ifa;
 
-#ifdef DEBUG
-   Debug_msg("Inet_CorrectIface -- %s ", iface);
-#endif
+   DEBUG_MSG("Inet_CorrectIface -- %s ", iface);
 
    if (getifaddrs(&ifalist) != 0)
-      Error_msg("ec_inet_BSD:%d  getifaddrs() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG(" getifaddrs()");
 
 
    for (ifa = ifalist; ifa; ifa = ifa->ifa_next)
@@ -233,13 +260,11 @@ int Inet_CorrectIface(char *iface)
    int sock;
    struct ifreq ifr;
 
-#ifdef DEBUG
-   Debug_msg("Inet_CorrectIface\t\tIface: %s", iface);
-#endif
+   DEBUG_MSG("Inet_CorrectIface\t\tIface: %s", iface);
 
    sock = socket(AF_INET, SOCK_DGRAM, 0);
    if (sock < 0)
-      Error_msg("ec_inet_BSD:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("socket()");
 
    memset(&ifr, 0, sizeof(ifr));
    strncpy(ifr.ifr_name, iface, sizeof(ifr.ifr_name));
@@ -289,9 +314,7 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
    {
       if ( ioctl(sock, SIOCGIFMTU, &ifr) < 0)
       {
-         #ifdef DEBUG
-            Debug_msg("Inet_GetIfaceInfo -- MTU FAILED... assuming 1500");
-         #endif
+         DEBUG_MSG("Inet_GetIfaceInfo -- MTU FAILED... assuming 1500");
          *MTU = 1500;
       }
       else
@@ -315,13 +338,13 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
       mib[5] = 0;
 
       if (sysctl(mib, 6, NULL, &len, NULL, 0) < 0)
-         Error_msg("ec_inet_BSD:%d sysctl() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("sysctl()");
 
       if ((buf = (char *)malloc(len)) == NULL )
-         Error_msg("ec_inet_BSD:%d malloc() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("malloc()");
 
       if (sysctl(mib, 6, buf, &len, NULL, 0) < 0)
-         Error_msg("ec_inet_BSD:%d sysctl() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("sysctl()");
 
       end = buf + len;
 
@@ -345,14 +368,14 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
    if (IP != NULL)
    {
       if ( ioctl(sock, SIOCGIFADDR, &ifr) < 0 )
-         Error_msg("ec_inet_BSD:%d ioctl(SIOCGIFADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFADDR)");
       memcpy((char *)IP, ifr.ifr_addr.sa_data+2, 4);
    }
 
    if (NetMask != NULL)
    {
       if ( ioctl(sock, SIOCGIFNETMASK, &ifr) < 0 )
-         Error_msg("ec_inet_BSD:%d ioctl(SIOCGIFNETMASK) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFNETMASK)");
       memcpy((char *)NetMask, ifr.ifr_addr.sa_data+2, 4);
       if (strcmp(Options.netmask, ""))       // specified on command line
          *NetMask = inet_addr(Options.netmask);
@@ -370,11 +393,9 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
 void Inet_CloseRawSock(int sock)
 {
 
-#ifdef DEBUG
-   Debug_msg("Inet_CloseRawSock \t fd = %d", sock);
-#endif
+   DEBUG_MSG("Inet_CloseRawSock \t wrappered to NULL");
 
-   close(sock);
+   //close(sock);    // the bpf is close when ettercap exits
 
 }
 
@@ -410,6 +431,12 @@ int Inet_OpenRawSock(char *iface)
     u_int spoof_eth_src = 1;
 #endif
 
+   if (bpf_in_use != 0) {
+      DEBUG_MSG("Inet_OpenRawSock %s", iface);
+      DEBUG_MSG("Inet_OpenRawSock \t bpf_in_use = %d ", bpf_in_use);
+      return bpf_in_use;
+   }
+
    Inet_GetIfaceInfo(iface, NULL, MyMAC, NULL, NULL);
 
    insns[1].k = htons(*(short *)MyMAC);         // put MyMac in the filter...
@@ -417,10 +444,7 @@ int Inet_OpenRawSock(char *iface)
    insns[5].k = htons(*(short *)(MyMAC+4));
 
 
-#ifdef DEBUG
-   Debug_msg("Inet_OpenRawSock %s", iface);
-#endif
-
+   DEBUG_MSG("Inet_OpenRawSock %s", iface);
 
    do    // find an available bpf device
    {
@@ -429,14 +453,12 @@ int Inet_OpenRawSock(char *iface)
    } while (fd < 0 && errno == EBUSY);
 
    if (fd < 0)
-      Error_msg("ec_inet_BSD:%d  no /dev/bpf* available (tried to open %d) | ERRNO : %d | %s", __LINE__, i, errno, strerror(errno));
+      Error_msg("ec_inet_bsd:%d no /dev/bpf* available (tried to open %d) | ERRNO : %d | %s", __LINE__, i, errno, strerror(errno));
 
-#ifdef DEBUG
-   Debug_msg("Inet_OpenRawSock \t fd = %d -- /dev/bpf%d ", fd, i-1);
-#endif
+   DEBUG_MSG("Inet_OpenRawSock \t fd = %d -- /dev/bpf%d ", fd, i-1);
 
    if (ioctl(fd, BIOCVERSION, (caddr_t)&bv) < 0)      // get bpf version
-      Error_msg("ec_inet_BSD:%d  ioctl(BIOCVERSION) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG(" ioctl(BIOCVERSION)");
 
 
    if (bv.bv_major != BPF_MAJOR_VERSION || bv.bv_minor < BPF_MINOR_VERSION)
@@ -451,35 +473,35 @@ int Inet_OpenRawSock(char *iface)
          break;  /* that size worked; we're done */
 
       if (errno != ENOBUFS)
-         Error_msg("ec_inet_BSD:%d  ioctl(BIOCSETIF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG(" ioctl(BIOCSETIF)");
    }
 
    if (size == 0) Error_msg("BIOCSBLEN: No buffer size worked");
 
    if (ioctl(fd, BIOCGBLEN, (caddr_t)&size) < 0)
-     Error_msg("ec_inet_BSD:%d  ioctl(BIOCGBLEN) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+     ERROR_MSG(" ioctl(BIOCGBLEN)");
 
    if (ioctl(fd, BIOCGDLT, (caddr_t)&type) == -1)           // Get the data link layer type.
-      Error_msg("ec_inet_BSD:%d  ioctl(BIOCGDLT) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG(" ioctl(BIOCGDLT)");
 
    if (type != DLT_EN10MB)
       Error_msg("Interface not supported ( only DLT_EN10MB) | %d", type);
 
 #if defined(BIOCGHDRCMPLT) && defined(BIOCSHDRCMPLT)     // auto fill the source mac address now set to OFF
     if (ioctl(fd, BIOCSHDRCMPLT, &spoof_eth_src) == -1)
-      Error_msg("ec_inet_BSD:%d  ioctl(BIOCSHDRCMPLT) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG(" ioctl(BIOCSHDRCMPLT)");
 #endif
 
    i = 1;
    if (ioctl(fd, BIOCIMMEDIATE, &i) < 0)                    // Set immediate mode so packets are processed as they arrive.
-      Error_msg("ec_inet_BSD:%d  ioctl(BIOCIMMEDIATE) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG(" ioctl(BIOCIMMEDIATE)");
 
 
    if (ioctl(fd, BIOCSETF, (caddr_t)&filter) < 0)           // Set filter program.
-      Error_msg("ec_inet_BSD:%d  ioctl(BIOCSETF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG(" ioctl(BIOCSETF)");
 
 
-   fdprom = fd;
+   bpf_in_use = fd;
 
    return fd;
 
@@ -496,9 +518,7 @@ int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type)
    if (SocketBuffer == -1)                   // only the first time
    {
       SocketBuffer = Buffer_Create(1.0e5);   // 100 K buffer
-      #ifdef DEBUG
-         Debug_msg("Inet_GetRawPacket creates the buffer for the first time -- buf id = %d", SocketBuffer);
-      #endif
+      DEBUG_MSG("Inet_GetRawPacket creates the buffer for the first time -- buf id = %d", SocketBuffer);
    }
 
    Buffer_Get(SocketBuffer, &pktlen, sizeof(u_int));
@@ -573,7 +593,7 @@ int Inet_SendRawPacket(int sock, char *buffer, int len)
          if (sent == len) return (sent);
       }
 
-      Error_msg("ec_inet_BSD:%d write() %d(%d) | ERRNO : %d | %s \n", __LINE__, len, sent, errno, strerror(errno));
+      Error_msg("ec_inet_bsd:%d write() %d(%d) | ERRNO : %d | %s \n", __LINE__, len, sent, errno, strerror(errno));
    }
 
    return (sent);
@@ -584,12 +604,10 @@ int Inet_SendRawPacket(int sock, char *buffer, int len)
 int Inet_SetPromisc(char *iface)
 {
 
-#ifdef DEBUG
-   Debug_msg("Inet_SetPromisc %s %d", iface, fdprom);
-#endif
+   DEBUG_MSG("Inet_SetPromisc %s %d", iface, bpf_in_use);
 
-   if ( ioctl(fdprom, BIOCPROMISC, NULL) < 0 )
-      Error_msg("ec_inet_BSD:%d ioctl(BIOCPROMISC) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+   if ( ioctl(bpf_in_use, BIOCPROMISC, NULL) < 0 )
+      ERROR_MSG("ioctl(BIOCPROMISC)");
 
    return 0;
 }
@@ -621,11 +639,9 @@ void Inet_DisableForwarding(void)
    len = sizeof(IpForward_status);
 
    if( (sysctl(mib, 4, &IpForward_status, &len, &val, sizeof(val))) == -1)
-    Error_msg("ec_inet_BSD:%d sysctl() | net.inet.ip.forwarding | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+    ERROR_MSG("sysctl() | net.inet.ip.forwarding");
 
-#ifdef DEBUG
-   Debug_msg("Inet_DisableForwarding | net.inet.ip.forwarding = %d  old_value = %d\n", val, IpForward_status);
-#endif
+   DEBUG_MSG("Inet_DisableForwarding | net.inet.ip.forwarding = %d  old_value = %d\n", val, IpForward_status);
 
    atexit(Inet_RestoreForwarding);
 
@@ -646,12 +662,9 @@ void Inet_RestoreForwarding(void)
    if (strcmp(ECThread_getname(pthread_self()), PROGRAM)) return;
 
    if( (sysctl(mib, 4, NULL, NULL, &IpForward_status, sizeof(IpForward_status))) == -1)
-      Error_msg("ec_inet_BSD:%d sysctl() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
-
-#ifdef DEBUG
-   Debug_msg("Inet_RestoreForwarding | net.inet.ip.forwarding = %d\n", IpForward_status);
-#endif
+      ERROR_MSG("sysctl()");
 
+   DEBUG_MSG("Inet_RestoreForwarding | net.inet.ip.forwarding = %d\n", IpForward_status);
 
 }
 
@@ -666,9 +679,7 @@ char *Inet_MacFromIP(unsigned long ip)
    struct sockaddr_dl *sdl;
    static char ETH_BROADCAST[6] = {0xFF,0xFF,0xFF,0xFF,0xFF,0xFF};
 
-#ifdef DEBUG
-   Debug_msg("Inet_MacFromIP");
-#endif
+   DEBUG_MSG("Inet_MacFromIP");
 
    mib[0] = CTL_NET;
    mib[1] = AF_ROUTE;
@@ -678,15 +689,15 @@ char *Inet_MacFromIP(unsigned long ip)
    mib[5] = RTF_LLINFO;
 
    if (sysctl(mib, 6, NULL, &len, NULL, 0) < 0)
-      Error_msg("ec_inet_BSD:%d sysctl() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("sysctl()");
 
    if ((buf = (char *)malloc(len)) == NULL)
-      Error_msg("ec_inet_BSD:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("malloc()");
 
    if (sysctl(mib, 6, buf, &len, NULL, 0) < 0)
    {
       free(buf);
-      Error_msg("ec_inet_BSD:%d sysctl() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("sysctl()");
    }
    end = buf + len;
 
@@ -709,9 +720,7 @@ char *Inet_MacFromIP(unsigned long ip)
          int MTU, sock;
          TIME_DECLARE;
 
-#ifdef DEBUG
-   Debug_msg("Inet_MacFromIP -- try to find it");
-#endif
+         DEBUG_MSG("Inet_MacFromIP -- try to find it");
 
          sock = Inet_OpenRawSock(Options.netiface);
 
@@ -719,9 +728,7 @@ char *Inet_MacFromIP(unsigned long ip)
 
          if (ip == MyIP)
          {
-            #ifdef DEBUG
-               Debug_msg("Inet_MacFromIP -- try to find me... ;)");
-            #endif
+            DEBUG_MSG("Inet_MacFromIP -- try to find me... ;)");
             memcpy(LLADDR(sdl), MyMAC, ETHER_ADDR_LEN);
             Inet_CloseRawSock(sock);
             return (char *) LLADDR(sdl);
@@ -848,13 +855,13 @@ doit:
 
    if ((rlen = write(s, (char *)&m_rtmsg, l)) < 0) {
       if (errno != ESRCH || cmd != RTM_DELETE)
-         Error_msg("ec_inet_BSD:%d writing on PF_ROUTE socket | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG("writing on PF_ROUTE socket");
    }
    do {
       l = read(s, (char *)&m_rtmsg, sizeof(m_rtmsg));
    } while (l > 0 && (rtm->rtm_seq != seq || rtm->rtm_pid != pid));
    if (l < 0)
-      Error_msg("ec_inet_BSD:%d reading on PF_ROUTE socket | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("reading on PF_ROUTE socket");
 
    return (0);
 }
@@ -867,13 +874,11 @@ void Inet_UnSetARPEntry(void)
    register struct rt_msghdr *rtm = &m_rtmsg.m_rtm;
    struct sockaddr_dl *sdl;
 
-#ifdef DEBUG
-   Debug_msg("Inet_UnSetARPEntry");
-#endif
+   DEBUG_MSG("Inet_UnSetARPEntry");
 
    s = socket(PF_ROUTE, SOCK_RAW, 0);
    if (s < 0)
-      Error_msg("ec_inet_BSD:%d socket(PF_ROUTE) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("socket(PF_ROUTE)");
 
    sin_m = blank_sin;
    sin->sin_addr.s_addr = SavedIP;
@@ -898,15 +903,13 @@ int Inet_SetARPEntry(unsigned long IP, char MAC[6])
    u_char *ea;
    int ret;
 
-#ifdef DEBUG
-   Debug_msg("Inet_SetARPEntry");
-#endif
+   DEBUG_MSG("Inet_SetARPEntry");
 
    pid = getpid();
 
    s = socket(PF_ROUTE, SOCK_RAW, 0);
    if (s < 0)
-      Error_msg("ec_inet_BSD:%d socket(PF_ROUTE) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("socket(PF_ROUTE)");
 
    sdl_m = blank_sdl;
    sin_m = blank_sin;
@@ -1067,7 +1070,7 @@ netdone:
           MIN(hp->h_length, sizeof(su->sin.sin_addr)));
       return (1);
    }
-   Error_msg("ec_inet_BSD:%d bad address %s | ERRNO : %d | %s", __LINE__, s, errno, strerror(errno));
+   Error_msg("ec_inet_BSD:%d  bad address %s | ERRNO : %d | %s", __LINE__, s, errno, strerror(errno));
    return 0;
 }
 
@@ -1138,7 +1141,7 @@ int rtmsg_route(int cmd, int flags)
    NEXTADDR(RTA_IFA, so_ifa);
    rtm.rtm_msglen = l = cp - (char *)&m_rtmsg;
    if ((rlen = write(s, (char *)&m_rtmsg, l)) < 0)
-      Error_msg("ec_inet_BSD:%d writing to routing socket | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("writing to routing socket");
 
 #undef rtm
 #undef NEXTADDR
@@ -1153,15 +1156,13 @@ void Inet_UnsetRoute(void)
    struct hostent *hp = 0;
    int IP;
 
-#ifdef DEBUG
-   Debug_msg("Inet_UnsetRoute");
-#endif
+   DEBUG_MSG("Inet_UnsetRoute");
 
    pid = getpid();
 
    s = socket(PF_ROUTE, SOCK_RAW, 0);
    if (s < 0)
-      Error_msg("ec_inet_BSD:%d socket(PF_ROUTE) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("socket(PF_ROUTE)");
 
 
    forcehost = 0;
@@ -1193,15 +1194,13 @@ void Inet_SetRoute(void)
    struct hostent *hp = 0;
    int IP;
 
-#ifdef DEBUG
-   Debug_msg("Inet_SetRoute NET");
-#endif
+   DEBUG_MSG("Inet_SetRoute NET");
 
    pid = getpid();
 
    s = socket(PF_ROUTE, SOCK_RAW, 0);
    if (s < 0)
-      Error_msg("ec_inet_BSD:%d socket(PF_ROUTE) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("socket(PF_ROUTE)");
 
 
    forcehost = 0;
@@ -1229,3 +1228,6 @@ void Inet_SetRoute(void)
 #endif
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
