@@ -1,6 +1,6 @@
 /*
     ettercap -- inet utilities -- Module for MacOsX darwin 1.[34]
-                                                    darwin 5.[01]
+                                                    darwin 5.[012]
 
     Copyright (C) 2001  ALoR <alor@users.sourceforge.net>, NaGA <crwm@freemail.it>
 
@@ -18,12 +18,19 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_inet_macosx.c,v 1.7 2002/02/11 01:15:48 alor Exp $
+    $Id: ec_inet_macosx.c,v 1.11 2002/04/07 23:46:29 alor Exp $
 */
 
+#include "../../include/ec_main.h"
 
-// This file is included from ../ec_inet.c
+#include "../../include/ec_thread.h"
+#include "../../include/ec_buffer.h"
+#include "../../include/ec_inet_forge.h"
+#include "../../include/ec_inet_structures.h"
 
+#include <ctype.h>
+#include <sys/ioctl.h>
+#include <fcntl.h>
 
 #include <sys/sysctl.h>
 #include <sys/param.h>
@@ -48,10 +55,31 @@
 #endif
 
 
-int fdprom;
+int IpForward_status;      // old ipforward status
+
+int bpf_in_use;
 int size;
 int SocketBuffer = -1;
 
+static char ARP_BROADCAST[6] = {0x0,0x0,0x0,0x0,0x0,0x0};
+
+// protos...
+
+int Inet_FindIFace(char *iface);
+int Inet_CorrectIface(char *iface);
+int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, u_long *IP, u_long *NetMask);
+int Inet_SetPromisc(char *iface);
+int Inet_OpenRawSock(char *iface);
+void Inet_CloseRawSock(int sock);
+int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type);
+int Inet_SendRawPacket(int sock, char *buffer, int len);
+void Inet_Restore_ifr(void);
+void Inet_DisableForwarding(void);
+void Inet_RestoreForwarding(void);
+char *Inet_MacFromIP(unsigned long ip);
+
+
+// ----------------------------------------------
 
 int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
 {
@@ -65,20 +93,20 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
 
    fd = socket(AF_INET, SOCK_DGRAM, 0);
    if (fd < 0)
-      Error_msg("ec_inet_macosx:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("socket()");
 
    buf_size = 8192;
 
    for (;;) {
       buf = malloc (buf_size);
       if (buf == NULL)
-         Error_msg("ec_inet_macosx:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG("malloc()");
 
       ifc.ifc_len = buf_size;
       ifc.ifc_buf = buf;
       memset (buf, 0, buf_size);
       if (ioctl(fd, SIOCGIFCONF, (char *)&ifc) < 0 && errno != EINVAL)
-         Error_msg("ec_inet_macosx:%d ioctl(SIOCGIFCONF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFCONF)");
 
       if (ifc.ifc_len < buf_size)
          break;
@@ -114,12 +142,10 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
       {
          if (errno == ENXIO)
             continue;
-         Error_msg("ec_inet_macosx:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFFLAGS)");
       }
 
-#ifdef DEBUG
-   Debug_msg("Inet_FindIFace -- check for [%s]", ifr.ifr_name);
-#endif
+      DEBUG_MSG("Inet_FindIFace -- check for [%s]", ifr.ifr_name);
 
       /* Must be up and not the loopback */
       if ((ifr.ifr_flags & IFF_UP) == 0 || (ifr.ifr_flags & IFF_LOOPBACK) != 0)
@@ -152,9 +178,7 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
 
    free(buf);
 
-#ifdef DEBUG
-   Debug_msg("Inet_FindIFace -- %s found !!", iface);
-#endif
+   DEBUG_MSG("Inet_FindIFace -- %s found !!", iface);
 
    return 0;
 
@@ -166,13 +190,11 @@ int Inet_CorrectIface(char *iface)
    int sock;
    struct ifreq ifr;
 
-#ifdef DEBUG
-   Debug_msg("Inet_CorrectIface\t\tIface: %s", iface);
-#endif
+   DEBUG_MSG("Inet_CorrectIface\t\tIface: %s", iface);
 
    sock = socket(AF_INET, SOCK_DGRAM, 0);
    if (sock < 0)
-      Error_msg("ec_inet_macosx:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("socket()");
 
    memset(&ifr, 0, sizeof(ifr));
    strncpy(ifr.ifr_name, iface, sizeof(ifr.ifr_name));
@@ -222,9 +244,7 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
    {
       if ( ioctl(sock, SIOCGIFMTU, &ifr) < 0)
       {
-         #ifdef DEBUG
-            Debug_msg("Inet_GetIfaceInfo -- MTU FAILED... assuming 1500");
-         #endif
+         DEBUG_MSG("Inet_GetIfaceInfo -- MTU FAILED... assuming 1500");
          *MTU = 1500;
       }
       else
@@ -247,13 +267,13 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
       mib[5] = 0;
 
       if (sysctl(mib, 6, NULL, &len, NULL, 0) < 0)
-         Error_msg("ec_inet_macosx:%d sysctl() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("sysctl()");
 
       if ((buf = (char *)malloc(len)) == NULL )
-         Error_msg("ec_inet_macosx:%d malloc() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("malloc()");
 
       if (sysctl(mib, 6, buf, &len, NULL, 0) < 0)
-         Error_msg("ec_inet_macosx:%d sysctl() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("sysctl()");
 
       end = buf + len;
 
@@ -277,14 +297,14 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
    if (IP != NULL)
    {
       if ( ioctl(sock, SIOCGIFADDR, &ifr) < 0 )
-         Error_msg("ec_inet_macosx:%d ioctl(SIOCGIFADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFADDR)");
       memcpy((char *)IP, ifr.ifr_addr.sa_data+2, 4);
    }
 
    if (NetMask != NULL)
    {
       if ( ioctl(sock, SIOCGIFNETMASK, &ifr) < 0 )
-         Error_msg("ec_inet_macosx:%d ioctl(SIOCGIFNETMASK) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFNETMASK)");
       memcpy((char *)NetMask, ifr.ifr_addr.sa_data+2, 4);
       if (strcmp(Options.netmask, ""))       // specified on command line
          *NetMask = inet_addr(Options.netmask);
@@ -301,11 +321,9 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
 void Inet_CloseRawSock(int sock)
 {
 
-#ifdef DEBUG
-   Debug_msg("Inet_CloseRawSock \t fd = %d", sock);
-#endif
+   DEBUG_MSG("Inet_CloseRawSock \t wrappered to NULL");
 
-   close(sock);
+   //close(sock);    // the bpf is close when ettercap exits
 
 }
 
@@ -342,6 +360,12 @@ int Inet_OpenRawSock(char *iface)
     u_int spoof_eth_src = 1;
 #endif
 
+   if (bpf_in_use != 0) {
+      DEBUG_MSG("Inet_OpenRawSock %s", iface);
+      DEBUG_MSG("Inet_OpenRawSock \t bpf_in_use = %d ", bpf_in_use);
+      return bpf_in_use;
+   }
+
    Inet_GetIfaceInfo(iface, NULL, MyMAC, NULL, NULL);
 
    insns[1].k = htons(*(short *)MyMAC);         // put MyMac in the filter...
@@ -349,9 +373,7 @@ int Inet_OpenRawSock(char *iface)
    insns[5].k = htons(*(short *)(MyMAC+4));
 
 
-#ifdef DEBUG
-   Debug_msg("Inet_OpenRawSock %s", iface);
-#endif
+   DEBUG_MSG("Inet_OpenRawSock %s", iface);
 
 
    do    // find an available bpf device
@@ -363,12 +385,10 @@ int Inet_OpenRawSock(char *iface)
    if (fd < 0)
       Error_msg("ec_inet_macosx:%d  no /dev/bpf* available (tried to open %d) | ERRNO : %d | %s", __LINE__, i, errno, strerror(errno));
 
-#ifdef DEBUG
-   Debug_msg("Inet_OpenRawSock \t fd = %d -- /dev/bpf%d ", fd, i-1);
-#endif
+   DEBUG_MSG("Inet_OpenRawSock \t fd = %d -- /dev/bpf%d ", fd, i-1);
 
    if (ioctl(fd, BIOCVERSION, (caddr_t)&bv) < 0)      // get bpf version
-      Error_msg("ec_inet_macosx:%d  ioctl(BIOCVERSION) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG(" ioctl(BIOCVERSION)");
 
 
    if (bv.bv_major != BPF_MAJOR_VERSION || bv.bv_minor < BPF_MINOR_VERSION)
@@ -383,35 +403,35 @@ int Inet_OpenRawSock(char *iface)
          break;  /* that size worked; we're done */
 
       if (errno != ENOBUFS)
-         Error_msg("ec_inet_macosx:%d  ioctl(BIOCSETIF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG(" ioctl(BIOCSETIF)");
    }
 
    if (size == 0) Error_msg("BIOCSBLEN: No buffer size worked");
 
    if (ioctl(fd, BIOCGBLEN, (caddr_t)&size) < 0)
-     Error_msg("ec_inet_macosx:%d  ioctl(BIOCGBLEN) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+     ERROR_MSG(" ioctl(BIOCGBLEN)");
 
    if (ioctl(fd, BIOCGDLT, (caddr_t)&type) == -1)           // Get the data link layer type.
-      Error_msg("ec_inet_macosx:%d  ioctl(BIOCGDLT) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG(" ioctl(BIOCGDLT)");
 
    if (type != DLT_EN10MB)
       Error_msg("Interface not supported ( only DLT_EN10MB) | %d", type);
 
 #if defined(BIOCGHDRCMPLT) && defined(BIOCSHDRCMPLT)     // auto fill the source mac address now set OFF
     if (ioctl(fd, BIOCSHDRCMPLT, &spoof_eth_src) == -1)
-      Error_msg("ec_inet_macosx:%d  ioctl(BIOCSHDRCMPLT) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG(" ioctl(BIOCSHDRCMPLT)");
 #endif
 
    i = 1;
    if (ioctl(fd, BIOCIMMEDIATE, &i) < 0)                    // Set immediate mode so packets are processed as they arrive.
-      Error_msg("ec_inet_macosx:%d  ioctl(BIOCIMMEDIATE) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG(" ioctl(BIOCIMMEDIATE)");
 
 
    if (ioctl(fd, BIOCSETF, (caddr_t)&filter) < 0)           // Set filter program.
-      Error_msg("ec_inet_macosx:%d  ioctl(BIOCSETF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG(" ioctl(BIOCSETF)");
 
 
-   fdprom = fd;
+   bpf_in_use = fd;
 
    return fd;
 
@@ -515,12 +535,10 @@ int Inet_SendRawPacket(int sock, char *buffer, int len)
 int Inet_SetPromisc(char *iface)
 {
 
-#ifdef DEBUG
-   Debug_msg("Inet_SetPromisc %s %d", iface, fdprom);
-#endif
+   DEBUG_MSG("Inet_SetPromisc %s %d", iface, bpf_in_use);
 
-   if ( ioctl(fdprom, BIOCPROMISC, NULL) < 0 )
-      Error_msg("ec_inet_macosx:%d ioctl(BIOCPROMISC) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+   if ( ioctl(bpf_in_use, BIOCPROMISC, NULL) < 0 )
+      ERROR_MSG("ioctl(BIOCPROMISC)");
 
    return 0;
 }
@@ -552,11 +570,9 @@ void Inet_DisableForwarding(void)
    len = sizeof(IpForward_status);
 
    if( (sysctl(mib, 4, &IpForward_status, &len, &val, sizeof(val))) == -1)
-    Error_msg("ec_inet_macosx:%d sysctl() | net.inet.ip.forwarding | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+    ERROR_MSG("sysctl() | net.inet.ip.forwarding");
 
-#ifdef DEBUG
-   Debug_msg("Inet_DisableForwarding | net.inet.ip.forwarding = %d  old_value = %d\n", val, IpForward_status);
-#endif
+   DEBUG_MSG("Inet_DisableForwarding | net.inet.ip.forwarding = %d  old_value = %d\n", val, IpForward_status);
 
    atexit(Inet_RestoreForwarding);
 
@@ -577,11 +593,9 @@ void Inet_RestoreForwarding(void)
    if (strcmp(ECThread_getname(pthread_self()), PROGRAM)) return;
 
    if( (sysctl(mib, 4, NULL, NULL, &IpForward_status, sizeof(IpForward_status))) == -1)
-      Error_msg("ec_inet_macosx:%d sysctl() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("sysctl()");
 
-#ifdef DEBUG
-   Debug_msg("Inet_RestoreForwarding | net.inet.ip.forwarding = %d\n", IpForward_status);
-#endif
+   DEBUG_MSG("Inet_RestoreForwarding | net.inet.ip.forwarding = %d\n", IpForward_status);
 
 
 }
@@ -597,9 +611,7 @@ char *Inet_MacFromIP(unsigned long ip)
    struct sockaddr_dl *sdl;
    static char ETH_BROADCAST[6] = {0xFF,0xFF,0xFF,0xFF,0xFF,0xFF};
 
-#ifdef DEBUG
-   Debug_msg("Inet_MacFromIP");
-#endif
+   DEBUG_MSG("Inet_MacFromIP");
 
    mib[0] = CTL_NET;
    mib[1] = AF_ROUTE;
@@ -609,15 +621,15 @@ char *Inet_MacFromIP(unsigned long ip)
    mib[5] = RTF_LLINFO;
 
    if (sysctl(mib, 6, NULL, &len, NULL, 0) < 0)
-      Error_msg("ec_inet_macosx:%d sysctl() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("sysctl()");
 
    if ((buf = (char *)malloc(len)) == NULL)
-      Error_msg("ec_inet_macosx:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("malloc()");
 
    if (sysctl(mib, 6, buf, &len, NULL, 0) < 0)
    {
       free(buf);
-      Error_msg("ec_inet_macosx:%d sysctl() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("sysctl()");
    }
    end = buf + len;
 
@@ -640,9 +652,7 @@ char *Inet_MacFromIP(unsigned long ip)
          int MTU, sock;
          TIME_DECLARE;
 
-#ifdef DEBUG
-   Debug_msg("Inet_MacFromIP -- try to find it");
-#endif
+         DEBUG_MSG("Inet_MacFromIP -- try to find it");
 
          sock = Inet_OpenRawSock(Options.netiface);
 
@@ -650,9 +660,7 @@ char *Inet_MacFromIP(unsigned long ip)
 
          if (ip == MyIP)
          {
-            #ifdef DEBUG
-               Debug_msg("Inet_MacFromIP -- try to find me... ;)");
-            #endif
+            DEBUG_MSG("Inet_MacFromIP -- try to find me... ;)");
             memcpy(LLADDR(sdl), MyMAC, ETHER_ADDR_LEN);
             Inet_CloseRawSock(sock);
             return (char *) LLADDR(sdl);
@@ -708,3 +716,6 @@ char *Inet_MacFromIP(unsigned long ip)
 
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
