@@ -19,12 +19,48 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_inet_linux.c,v 1.7 2002/02/11 00:57:25 alor Exp $
+    $Id: ec_inet_linux.c,v 1.9 2002/04/07 22:37:31 alor Exp $
 */
 
-#include <ctype.h>
+#include "../../include/ec_main.h"
 
-// This file is included from ../ec_inet.c
+#include <ctype.h>
+#include <sys/ioctl.h>
+#include <fcntl.h>
+
+#include "../../include/ec_thread.h"
+#include "../../include/ec_inet_forge.h"
+#include "../../include/ec_inet_structures.h"
+
+struct ifreq old_ifr;      // old iface flags
+char IpForward_status;     // old ipforward status
+
+static char ETH_BROADCAST[6] = {0xFF,0xFF,0xFF,0xFF,0xFF,0xFF};
+static char ARP_BROADCAST[6] = {0x0,0x0,0x0,0x0,0x0,0x0};
+
+// protos...
+
+int Inet_FindIFace(char *iface);
+int Inet_CorrectIface(char *iface);
+int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, u_long *IP, u_long *NetMask);
+int Inet_SetPromisc(char *iface);
+int Inet_OpenRawSock(char *iface);
+void Inet_CloseRawSock(int sock);
+int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type);
+int Inet_SendRawPacket(int sock, char *buffer, int len);
+void Inet_Restore_ifr(void);
+void Inet_DisableForwarding(void);
+void Inet_RestoreForwarding(void);
+char *Inet_MacFromIP(unsigned long ip);
+#ifdef PERMIT_HTTPS
+   void Inet_UnSetARPEntry(void);
+   int Inet_SetARPEntry(unsigned long IP, char MAC[6]);
+   void Inet_UnsetRoute(void);
+   void Inet_SetRoute(void);
+#endif
+
+
+// ----------------------------------------------
 
 int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
 {
@@ -38,20 +74,20 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
 
    fd = socket(AF_INET, SOCK_DGRAM, 0);
    if (fd < 0)
-      Error_msg("ec_inet_linux:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("socket()");
 
    buf_size = 8192;
 
    for (;;) {
       buf = malloc (buf_size);
       if (buf == NULL)
-         Error_msg("ec_inet_linux:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG("malloc()");
 
       ifc.ifc_len = buf_size;
       ifc.ifc_buf = buf;
       memset (buf, 0, buf_size);
       if (ioctl(fd, SIOCGIFCONF, (char *)&ifc) < 0 && errno != EINVAL)
-         Error_msg("ec_inet_linux:%d ioctl(SIOCGIFCONF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFCONF)");
 
       if (ifc.ifc_len < buf_size)
          break;
@@ -88,19 +124,17 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
          if (errno == ENXIO)
             continue;
 
-         Error_msg("ec_inet_linux:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFFLAGS)");
       }
 
-#ifdef DEBUG
-   Debug_msg("Inet_FindIFace -- check for [%s]", ifr.ifr_name);
-#endif
+      DEBUG_MSG("Inet_FindIFace -- check for [%s]", ifr.ifr_name);
 
       /* Must be up and not the loopback */
       if ((ifr.ifr_flags & IFF_UP) == 0 || (ifr.ifr_flags & IFF_LOOPBACK) != 0)
          continue;
 
       if ( ioctl(fd, SIOCGIFHWADDR, &ifr) < 0 )
-         Error_msg("ec_inet_linux:%d ioctl(SIOCGIFHWADDR) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFHWADDR)");
 
       /* Must be ethernet */
       if ( ifr.ifr_hwaddr.sa_family != ARPHRD_ETHER )
@@ -133,9 +167,7 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
 
    free(buf);
 
-#ifdef DEBUG
-   Debug_msg("Inet_FindIFace\t\tIface: %s", iface);
-#endif
+   DEBUG_MSG("Inet_FindIFace\t\tIface: %s", iface);
 
    return 0;
 
@@ -147,13 +179,11 @@ int Inet_CorrectIface(char *iface)
    int sock;
    struct ifreq ifr;
 
-#ifdef DEBUG
-   Debug_msg("Inet_CorrectIface\t\tIface: %s", iface);
-#endif
+   DEBUG_MSG("Inet_CorrectIface\t\tIface: %s", iface);
 
    sock = socket(AF_INET, SOCK_DGRAM, 0);
    if (sock < 0)
-      Error_msg("ec_inet_linux:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("socket()");
 
    memset(&ifr, 0, sizeof(ifr));
    strncpy(ifr.ifr_name, iface, sizeof(ifr.ifr_name));
@@ -182,7 +212,7 @@ int Inet_CorrectIface(char *iface)
    }
 
    if ( ioctl(sock, SIOCGIFHWADDR, &ifr) < 0 )
-      Error_msg("ec_inet_linux:%d ioctl(SIOCGIFHWADDR) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("ioctl(SIOCGIFHWADDR)");
 
    switch (ifr.ifr_hwaddr.sa_family)
    {
@@ -214,9 +244,7 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
    {
       if ( ioctl(sock, SIOCGIFMTU, &ifr) < 0)
       {
-         #ifdef DEBUG
-            Debug_msg("Inet_IPBased_Run -- MTU FAILED... assuming 1500");
-         #endif
+         DEBUG_MSG("Inet_IPBased_Run -- MTU FAILED... assuming 1500");
          *MTU = 1500;
       }
       else
@@ -227,21 +255,21 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
    if (MyMAC != NULL)
    {
       if ( ioctl(sock, SIOCGIFHWADDR, &ifr) < 0 )
-         Error_msg("ec_inet_linux:%d ioctl(SIOCGIFHWADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFHWADDR)");
       memcpy(MyMAC, ifr.ifr_hwaddr.sa_data, 6);
    }
 
    if (IP != NULL)
    {
       if ( ioctl(sock, SIOCGIFADDR, &ifr) < 0 )
-         Error_msg("ec_inet_linux:%d ioctl(SIOCGIFADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFADDR)");
       memcpy((char *)IP, ifr.ifr_addr.sa_data+2, 4);
    }
 
    if (NetMask != NULL)
    {
       if ( ioctl(sock, SIOCGIFNETMASK, &ifr) < 0 )
-         Error_msg("ec_inet_linux:%d ioctl(SIOCGIFNETMASK) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFNETMASK)");
       memcpy((char *)NetMask, ifr.ifr_addr.sa_data+2, 4);
       if (strcmp(Options.netmask, ""))       // specified on command line
          *NetMask = inet_addr(Options.netmask);
@@ -257,9 +285,7 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
 void Inet_CloseRawSock(int sock)
 {
 
-#ifdef DEBUG
-   Debug_msg("Inet_CloseRawSock \t fd = %d", sock);
-#endif
+   DEBUG_MSG("Inet_CloseRawSock \t fd = %d", sock);
 
    close(sock);
 
@@ -270,32 +296,30 @@ void Inet_CloseRawSock(int sock)
 int Inet_OpenRawSock(char *iface)
 {
    int sock;
-#ifdef HAVE_PF_PACKET
+#if defined (HAVE_PF_PACKET) && defined (NETPACKET_PACKET_H)
    struct ifreq ifr;
    struct sockaddr_ll sll;
 #else
    struct sockaddr sa;
 #endif
 
-#ifdef HAVE_PF_PACKET
+#if defined (HAVE_PF_PACKET) && defined (NETPACKET_PACKET_H)
    sock = socket(PF_PACKET, SOCK_RAW, htons(ETH_P_ALL));
 #else
    sock = socket(PF_INET, SOCK_PACKET, htons(ETH_P_ALL));
 #endif
    if (sock < 0)
-      Error_msg("ec_inet_linux:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("socket()");
 
-#ifdef DEBUG
-   Debug_msg("Inet_OpenRawSock %s \t fd = %d", iface, sock);
-#endif
+   DEBUG_MSG("Inet_OpenRawSock %s \t fd = %d", iface, sock);
 
-#ifdef HAVE_PF_PACKET
+#if defined (HAVE_PF_PACKET) && defined (NETPACKET_PACKET_H)
 
    memset(&ifr, 0, sizeof(ifr));
    strncpy(ifr.ifr_name, iface, sizeof(ifr.ifr_name));
 
    if ( ioctl(sock, SIOCGIFINDEX, &ifr) < 0)
-      Error_msg("ec_inet_linux:%d ioctl(SIOCGIFINDEX) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("ioctl(SIOCGIFINDEX)");
 
    memset(&sll, 0, sizeof(sll));
    sll.sll_family = AF_PACKET;
@@ -303,13 +327,13 @@ int Inet_OpenRawSock(char *iface)
    sll.sll_protocol = htons(ETH_P_ALL);
 
    if ( bind(sock, (struct sockaddr *) &sll, sizeof(sll)) == -1)
-      Error_msg("ec_inet_linux:%d bind() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("bind()");
 #else
 
    memset(&sa, 0, sizeof(sa));
    strncpy(sa.sa_data, iface, sizeof(sa.sa_data));
    if ( bind(sock, &sa, sizeof(sa)) == -1)
-      Error_msg("ec_inet_linux:%d bind() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("bind()");
 
 #endif
 
@@ -322,12 +346,8 @@ int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type)
 {
    int len = 0;
    socklen_t fromlen;
-//#ifdef HAVE_PF_PACKET
-//   struct sockaddr_ll from;
-//#else
    struct sockaddr from;
    static char MyMAC[6]={0x65,0x74,0x74,0x65,0x72,0x63};
-//#endif
 
    fromlen = sizeof(from);
    len = recvfrom(sock, buffer, MTU+64, MSG_TRUNC, (struct sockaddr *)&from, &fromlen);
@@ -336,9 +356,6 @@ int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type)
                                                          // this kernel passes us the MTU + ETH_HEADER + FCS
                                                          // for a total of 1518 byte !!!
 
-//#ifdef HAVE_PF_PACKET
-//   if (type != NULL) *type = from.sll_pkttype;
-//#else
    // the address returned for SOCK_PACKET lacks the packet type information.
    if (type != NULL)
    {
@@ -349,7 +366,6 @@ int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type)
        else
            *type = 1; // !PACKET_HOST
    }
-//#endif
 
    // TODO
    // handle fragmented packets...
@@ -363,7 +379,7 @@ int Inet_SendRawPacket(int sock, char *buffer, int len)
 {
    int sent;
    static char first_time = 1;
-#ifdef HAVE_PF_PACKET
+#if defined (HAVE_PF_PACKET) && defined (NETPACKET_PACKET_H)
    static struct sockaddr_ll dest;
    static struct ifreq ifr;
 #else
@@ -375,13 +391,13 @@ int Inet_SendRawPacket(int sock, char *buffer, int len)
       memset(&dest, 0, sizeof (dest));
       first_time = 0;
 
-      #ifdef HAVE_PF_PACKET
+      #if defined (HAVE_PF_PACKET) && defined (NETPACKET_PACKET_H)
 
          memset(&ifr, 0, sizeof(ifr));
          strncpy(ifr.ifr_name, Options.netiface, sizeof(ifr.ifr_name));
 
          if ( ioctl(sock, SIOCGIFINDEX, &ifr) < 0)
-            Error_msg("ec_inet_linux:%d ioctl(SIOCGIFINDEX) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+            ERROR_MSG("ioctl(SIOCGIFINDEX)");
 
          dest.sll_family = AF_PACKET;
          dest.sll_ifindex = ifr.ifr_ifindex;
@@ -416,9 +432,7 @@ int Inet_SetPromisc(char *iface)
    int sock;
    struct ifreq ifr;
 
-#ifdef DEBUG
-   Debug_msg("Inet_SetPromisc\tiface: %s", iface);
-#endif
+   DEBUG_MSG("Inet_SetPromisc\tiface: %s", iface);
 
    sock = Inet_OpenRawSock(iface);
 
@@ -426,7 +440,7 @@ int Inet_SetPromisc(char *iface)
    strncpy(ifr.ifr_name, iface, sizeof(ifr.ifr_name));
 
    if ( ioctl(sock, SIOCGIFFLAGS, &ifr) < 0 )
-      Error_msg("ec_inet_linux:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("ioctl(SIOCGIFFLAGS)");
 
    memset(&old_ifr, 0, sizeof(old_ifr));
    old_ifr.ifr_flags = ifr.ifr_flags;              //save old flags
@@ -435,7 +449,7 @@ int Inet_SetPromisc(char *iface)
    {
       ifr.ifr_flags |= IFF_PROMISC;
       if ( ioctl(sock, SIOCSIFFLAGS, &ifr) < 0 )      // promisc mode
-         Error_msg("ec_inet_linux:%d ioctl(SIOCSIFFLAGS) | promisc on | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCSIFFLAGS) | promisc on");
       atexit(Inet_Restore_ifr);
    }
 
@@ -452,9 +466,7 @@ void Inet_Restore_ifr(void)
    int sock;
    struct ifreq ifr;
 
-#ifdef DEBUG
-   Debug_msg("Inet_Restore_ifr");
-#endif
+   DEBUG_MSG("Inet_Restore_ifr");
 
    sock = Inet_OpenRawSock(Options.netiface);
 
@@ -464,7 +476,7 @@ void Inet_Restore_ifr(void)
    ifr.ifr_flags = old_ifr.ifr_flags;
 
    if ( ioctl(sock, SIOCSIFFLAGS, &ifr) < 0 )     // flag restoring
-      Error_msg("ec_inet_linux:%d ioctl(SIOCSIFFLAGS) | flag restoring | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("ioctl(SIOCSIFFLAGS) | flag restoring");
 
    Inet_CloseRawSock(sock);
 }
@@ -477,27 +489,21 @@ void Inet_DisableForwarding(void)
    fd = fopen("/proc/sys/net/ipv4/ip_forward", "r");
    if (fd < 0 )
    {
-      #ifdef DEBUG
-         Debug_msg("ec_inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, sys_errlist[errno]);
-      #endif
+      DEBUG_MSG("fopen(/proc/sys/net/ipv4/ip_forward)");
       return;
    }
 
    fscanf(fd, "%c", &IpForward_status);
    fclose(fd);
 
-#ifdef DEBUG
-   Debug_msg("Inet_DisableForwarding from %c", IpForward_status);
-#endif
+   DEBUG_MSG("Inet_DisableForwarding from %c", IpForward_status);
 
    atexit(Inet_RestoreForwarding);
 
    fd = fopen("/proc/sys/net/ipv4/ip_forward", "w");
    if (fd < 0 )
    {
-      #ifdef DEBUG
-         Debug_msg("ec_inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, sys_errlist[errno]);
-      #endif
+      DEBUG_MSG("fopen(/proc/sys/net/ipv4/ip_forward)");
       return;
    }
 
@@ -516,15 +522,11 @@ void Inet_RestoreForwarding(void)
    fd = fopen("/proc/sys/net/ipv4/ip_forward", "w");
    if (fd < 0 )
    {
-      #ifdef DEBUG
-         Debug_msg("ec_inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, sys_errlist[errno]);
-      #endif
+      DEBUG_MSG("fopen(/proc/sys/net/ipv4/ip_forward)");
       return;
    }
 
-#ifdef DEBUG
-   Debug_msg("Inet_RestoreForwarding to %c", IpForward_status);
-#endif
+   DEBUG_MSG("Inet_RestoreForwarding to %c", IpForward_status);
 
    fprintf(fd, "%c", IpForward_status );
    fclose(fd);
@@ -538,9 +540,7 @@ char *Inet_MacFromIP(unsigned long ip)
    static struct arpreq ar;
    struct sockaddr_in *sa_in;
 
-#ifdef DEBUG
-   Debug_msg("Inet_MacFromIP");
-#endif
+   DEBUG_MSG("Inet_MacFromIP");
 
    memset((char *)&ar, 0, sizeof(ar));
    strncpy(ar.arp_dev, Options.netiface, sizeof(ar.arp_dev));
@@ -558,18 +558,16 @@ char *Inet_MacFromIP(unsigned long ip)
       int MTU, sock;
       TIME_DECLARE;
 
-#ifdef DEBUG
-   Debug_msg("Inet_MacFromIP -- try to find it");
-#endif
+      DEBUG_MSG("Inet_MacFromIP -- try to find it");
+
       sock = Inet_OpenRawSock(Options.netiface);
 
       Inet_GetIfaceInfo(Options.netiface, &MTU, MyMAC, &MyIP, NULL);
 
       if (ip == MyIP)
       {
-         #ifdef DEBUG
-            Debug_msg("Inet_MacFromIP -- try to find me... ;)");
-         #endif
+         DEBUG_MSG("Inet_MacFromIP -- try to find me... ;)");
+
          memcpy(&ar.arp_ha.sa_data, MyMAC, ETHER_ADDR_LEN);
          Inet_CloseRawSock(sock);
          Inet_CloseRawSock(sock_raw);
@@ -636,62 +634,58 @@ unsigned char SavedMAC[6];
 
 void Inet_UnSetARPEntry(void)
 {
-    struct arpreq req;
-    int sockfd;
-    struct sockaddr_in *sa_in;
+   struct arpreq req;
+   int sockfd;
+   struct sockaddr_in *sa_in;
 
-#ifdef DEBUG
-   Debug_msg("Inet_UnSetARPEntry");
-#endif
+   DEBUG_MSG("Inet_UnSetARPEntry");
 
-    sockfd = socket(AF_INET, SOCK_DGRAM, 0);
+   sockfd = socket(AF_INET, SOCK_DGRAM, 0);
 
-    memset((char *) &req, 0, sizeof(req));
-    sa_in = (struct sockaddr_in *)&req.arp_pa;
-    sa_in->sin_family = AF_INET;
-    sa_in->sin_addr.s_addr = SavedIP;
-    req.arp_flags = ATF_PERM | ATF_COM;
+   memset((char *) &req, 0, sizeof(req));
+   sa_in = (struct sockaddr_in *)&req.arp_pa;
+   sa_in->sin_family = AF_INET;
+   sa_in->sin_addr.s_addr = SavedIP;
+   req.arp_flags = ATF_PERM | ATF_COM;
 
-    memcpy(req.arp_ha.sa_data, SavedMAC, 6);
-    strlcpy(req.arp_dev, Options.netiface, sizeof(req.arp_dev));
+   memcpy(req.arp_ha.sa_data, SavedMAC, 6);
+   strlcpy(req.arp_dev, Options.netiface, sizeof(req.arp_dev));
 
-    ioctl(sockfd, SIOCDARP, &req);
+   ioctl(sockfd, SIOCDARP, &req);
 
-    close(sockfd);
+   close(sockfd);
 }
 
 
 int Inet_SetARPEntry(unsigned long IP, char MAC[6])
 {
-    struct arpreq req;
-    int sockfd;
-    struct sockaddr_in *sa_in;
-    int retval;
+   struct arpreq req;
+   int sockfd;
+   struct sockaddr_in *sa_in;
+   int retval;
 
-#ifdef DEBUG
-   Debug_msg("Inet_SetARPEntry");
-#endif
+   DEBUG_MSG("Inet_SetARPEntry");
 
-    sockfd = socket(AF_INET, SOCK_DGRAM, 0);
+   sockfd = socket(AF_INET, SOCK_DGRAM, 0);
 
-    memset((char *) &req, 0, sizeof(req));
-    sa_in = (struct sockaddr_in *)&req.arp_pa;
-    sa_in->sin_family = AF_INET;
-    sa_in->sin_addr.s_addr = IP;
-    req.arp_flags = ATF_PERM | ATF_COM;
+   memset((char *) &req, 0, sizeof(req));
+   sa_in = (struct sockaddr_in *)&req.arp_pa;
+   sa_in->sin_family = AF_INET;
+   sa_in->sin_addr.s_addr = IP;
+   req.arp_flags = ATF_PERM | ATF_COM;
 
-    memcpy(req.arp_ha.sa_data, MAC, 6);
-    strlcpy(req.arp_dev, Options.netiface, sizeof(req.arp_dev));
+   memcpy(req.arp_ha.sa_data, MAC, 6);
+   strlcpy(req.arp_dev, Options.netiface, sizeof(req.arp_dev));
 
-    retval = ioctl(sockfd, SIOCSARP, &req);
+   retval = ioctl(sockfd, SIOCSARP, &req);
 
-    close(sockfd);
+   close(sockfd);
 
-    SavedIP=IP;
-    memcpy(SavedMAC, MAC, 6);
-    atexit(Inet_UnSetARPEntry);
+   SavedIP=IP;
+   memcpy(SavedMAC, MAC, 6);
+   atexit(Inet_UnSetARPEntry);
 
-    return retval;
+   return retval;
 }
 
 // ROUTE MANAGEMENT ---------------------------
@@ -720,9 +714,7 @@ void Inet_UnsetRoute(void)
     int skfd;
     struct rtentry rt;
 
-#ifdef DEBUG
-   Debug_msg("Inet_UnsetRoute");
-#endif
+    DEBUG_MSG("Inet_UnsetRoute");
 
     skfd = socket(AF_INET, SOCK_DGRAM, 0);
 
@@ -753,9 +745,7 @@ void Inet_SetRoute(void)
     int skfd;
     struct rtentry rt;
 
-#ifdef DEBUG
-   Debug_msg("Inet_SetRoute");
-#endif
+    DEBUG_MSG("Inet_SetRoute");
 
     skfd = socket(AF_INET, SOCK_DGRAM, 0);
 
@@ -786,3 +776,6 @@ void Inet_SetRoute(void)
 #endif
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
