@@ -17,12 +17,19 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_inet_solaris.c,v 1.9 2002/02/11 01:15:48 alor Exp $
+    $Id: ec_inet_solaris.c,v 1.15 2002/04/13 14:51:24 alor Exp $
 */
 
+#include "../../include/ec_main.h"
 
-// This file is included from ../ec_inet.c
+#include "../../include/ec_thread.h"
+#include "../../include/ec_buffer.h"
+#include "../../include/ec_inet_forge.h"
+#include "../../include/ec_inet_structures.h"
 
+#include <ctype.h>
+#include <sys/ioctl.h>
+#include <fcntl.h>
 
 #include <sys/ioctl.h>
 #include <sys/sockio.h>
@@ -63,28 +70,8 @@ struct ether_addr
 
 #define  MAXDLBUF 8192
 
-/* protos... */
-static int dlattachreq(int, u_int, char *);
-static int dlbindack(int, char *, char *);
-static int dlbindreq(int, u_int, char *);
-static int dlinfoack(int, char *, char *);
-static int dlinforeq(int, char *);
-static int dlokack(int, const char *, char *, char *);
-static int send_request(int, char *, int, char *, char *);
-static int recv_ack(int, int, const char *, char *, char *);
-static int dlpromisconreq(int, u_int, char *);
-#if defined(SOLARIS) && defined(HAVE_SYS_BUFMOD_H)
-static char *get_release(u_int *, u_int *, u_int *);
-#endif
-#ifdef HAVE_SYS_BUFMOD_H
-static int strioctl(int, int, int, char *);
-#endif
-#ifdef HAVE_DEV_DLPI
-static int get_dlpi_ppa(int, const char *, int, char *);
-#endif
-static char * split_dname(char *device, int *unitp);
+int IpForward_status;      // old ipforward status
 
-int fdprom;
 static u_int ctlbuf[MAXDLBUF];
 static struct strbuf ctl = {
    MAXDLBUF,
@@ -95,6 +82,42 @@ char ebuf[100];
 
 int bufsize, offset;
 int SocketBuffer = -1;
+int dlpi_in_use;
+
+// protos...
+
+int Inet_FindIFace(char *iface);
+int Inet_CorrectIface(char *iface);
+int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, u_long *IP, u_long *NetMask);
+int Inet_SetPromisc(char *iface);
+int Inet_OpenRawSock(char *iface);
+void Inet_CloseRawSock(int sock);
+int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type);
+int Inet_SendRawPacket(int sock, char *buffer, int len);
+void Inet_Restore_ifr(void);
+void Inet_DisableForwarding(void);
+void Inet_RestoreForwarding(void);
+char *Inet_MacFromIP(unsigned long ip);
+/* protos... */
+static int dlattachreq(int, u_int, char *);
+static int dlbindack(int, char *, char *);
+static int dlbindreq(int, u_int, char *);
+static int dlinfoack(int, char *, char *);
+static int dlinforeq(int, char *);
+static int dlokack(int, const char *, char *, char *);
+static int send_request(int, char *, int, char *, char *);
+static int recv_ack(int, int, const char *, char *, char *);
+//static int dlpromisconreq(int, u_int, char *);
+#if defined(SOLARIS) && defined(HAVE_SYS_BUFMOD_H)
+static char *get_release(u_int *, u_int *, u_int *);
+#endif
+#ifdef HAVE_SYS_BUFMOD_H
+static int strioctl(int, int, int, char *);
+#endif
+#ifdef HAVE_DEV_DLPI
+static int get_dlpi_ppa(int, const char *, int, char *);
+#endif
+static char * split_dname(char *device, int *unitp);
 
 // ==============================================
 
@@ -110,20 +133,20 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
 
    fd = socket(AF_INET, SOCK_DGRAM, 0);
    if (fd < 0)
-      Error_msg("ec_inet_solaris:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("socket()");
 
    buf_size = 8192;
 
    for (;;) {
       buf = malloc (buf_size);
       if (buf == NULL)
-         Error_msg("ec_inet_solaris:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG("malloc()");
 
       ifc.ifc_len = buf_size;
       ifc.ifc_buf = buf;
       memset (buf, 0, buf_size);
       if (ioctl(fd, SIOCGIFCONF, (char *)&ifc) < 0 && errno != EINVAL)
-         Error_msg("ec_inet_solaris:%d ioctl(SIOCGIFCONF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFCONF)");
 
       if (ifc.ifc_len < buf_size)
          break;
@@ -159,12 +182,10 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
       {
          if (errno == ENXIO)
             continue;
-         Error_msg("ec_inet_solaris:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFFLAGS)");
       }
 
-#ifdef DEBUG
-   Debug_msg("Inet_FindIFace -- check for [%s]", ifr.ifr_name);
-#endif
+      DEBUG_MSG("Inet_FindIFace -- check for [%s]", ifr.ifr_name);
 
       /* Must be up and not the loopback */
       if ((ifr.ifr_flags & IFF_UP) == 0 || (ifr.ifr_flags & IFF_LOOPBACK) != 0)
@@ -197,9 +218,7 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
 
    free(buf);
 
-#ifdef DEBUG
-   Debug_msg("Inet_FindIFace -- %s found !!", iface);
-#endif
+   DEBUG_MSG("Inet_FindIFace -- %s found !!", iface);
 
    return 0;
 
@@ -211,13 +230,11 @@ int Inet_CorrectIface(char *iface)
    int sock;
    struct ifreq ifr;
 
-#ifdef DEBUG
-   Debug_msg("Inet_CorrectIface\t\tIface: %s", iface);
-#endif
+   DEBUG_MSG("Inet_CorrectIface\t\tIface: %s", iface);
 
    sock = socket(AF_INET, SOCK_DGRAM, 0);
    if (sock < 0)
-      Error_msg("ec_inet_solaris:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      ERROR_MSG("socket()");
 
    memset(&ifr, 0, sizeof(ifr));
    strncpy(ifr.ifr_name, iface, sizeof(ifr.ifr_name));
@@ -269,15 +286,13 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
    {
       if ( ioctl(sock, SIOCGIFMTU, &ifr) < 0)
       {
-         #ifdef DEBUG
-            Debug_msg("Inet_GetIfaceInfo -- MTU FAILED... assuming 1500");
-         #endif
+         DEBUG_MSG("Inet_GetIfaceInfo -- MTU FAILED... assuming 1500");
          *MTU = 1500;
       }
       else
 // FIXME
          //*MTU = ifr.ifr_mtu;
-         *MTU = ifr.ifr_metric;  // ?? possible ?? i've found this example on the web...
+         *MTU = 1500;
    }
 
    if (MyMAC != NULL)
@@ -291,10 +306,10 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
       dlp->physaddr_req.dl_addr_type = DL_CURR_PHYS_ADDR;
 
       if (send_request(dlpi, (char *)dlp, DL_PHYS_ADDR_REQ_SIZE, "physaddr", ebuf) < 0)
-         Error_msg("ec_inet_solaris:%d send_request(DL_PHYS_ADDR_REQ_SIZE) | %s \n", __LINE__, ebuf);
+         Error_msg("send_request(DL_PHYS_ADDR_REQ_SIZE) | %s \n", ebuf);
 
       if (recv_ack(dlpi, DL_PHYS_ADDR_ACK_SIZE, "physaddr", (char *)dlp, ebuf) < 0)
-         Error_msg("ec_inet_solaris:%d recv_ack(DL_PHYS_ADDR_ACK_SIZE) | %s \n", __LINE__, ebuf);
+         Error_msg("recv_ack(DL_PHYS_ADDR_ACK_SIZE) | %s \n", ebuf);
 
       memcpy( MyMAC,(struct ether_addr *) ((char *) dlp + dlp->physaddr_ack.dl_addr_offset), ETHER_ADDR_LEN);
 
@@ -304,14 +319,14 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
    if (IP != NULL)
    {
       if ( ioctl(sock, SIOCGIFADDR, &ifr) < 0 )
-         Error_msg("ec_inet_solaris:%d ioctl(SIOCGIFADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFADDR)");
       memcpy((char *)IP, ifr.ifr_addr.sa_data+2, 4);
    }
 
    if (NetMask != NULL)
    {
       if ( ioctl(sock, SIOCGIFNETMASK, &ifr) < 0 )
-         Error_msg("ec_inet_solaris:%d ioctl(SIOCGIFNETMASK) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("ioctl(SIOCGIFNETMASK)");
       memcpy((char *)NetMask, ifr.ifr_addr.sa_data+2, 4);
       if (strcmp(Options.netmask, ""))       // specified on command line
          *NetMask = inet_addr(Options.netmask);
@@ -327,11 +342,9 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
 void Inet_CloseRawSock(int sock)
 {
 
-#ifdef DEBUG
-   Debug_msg("Inet_CloseRawSock \t fd = %d", sock);
-#endif
+   DEBUG_MSG("Inet_CloseRawSock \t wrappered to NULL");
 
-   close(sock);
+   //close(sock);    // the bpf is close when ettercap exits
 
 }
 
@@ -355,6 +368,11 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
    char dname2[100];
 #endif
 
+   if (dlpi_in_use != 0) {
+      DEBUG_MSG("Inet_OpenRawSock %s", iface);
+      DEBUG_MSG("Inet_OpenRawSock \t dlpi_in_use = %d ", dlpi_in_use);
+      return dpli_in_use;
+   }
 
 #ifdef HAVE_DEV_DLPI
    /*
@@ -384,7 +402,7 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
 
    cp = "/dev/dlpi";
    if ((fd = open(cp, O_RDWR)) < 0)
-      Error_msg("ec_inet_solaris:%d open() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("open()");
 
    /*
     * Get a table of all PPAs for that device, and search that
@@ -392,7 +410,7 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
     */
    ppa = get_dlpi_ppa(fd, dname, ppa, ebuf);
    if (ppa < 0)
-      Error_msg("ec_inet_solaris:%d get_dlpi_ppa() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("get_dlpi_ppa()");
 
 #else
    /*
@@ -415,11 +433,11 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
    if ((fd = open(dname, O_RDWR)) < 0)
    {
       if (errno != ENOENT)
-         Error_msg("ec_inet_solaris:%d open() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("open()");
 
       /* Try again with unit number */
       if ((fd = open(dname2, O_RDWR)) < 0)
-         Error_msg("ec_inet_solaris:%d open() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         ERROR_MSG("open()");
 
       /* XXX Assume unit zero */
       ppa = 0;
@@ -430,25 +448,25 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
    ** Attach if "style 2" provider
    */
    if (dlinforeq(fd, ebuf) < 0 || dlinfoack(fd, (char *)buf, ebuf) < 0)
-      Error_msg("ec_inet_solaris:%d dlinforeq() || dlinfoack() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("dlinforeq() || dlinfoack()");
 
    infop = &((union DL_primitives *)buf)->info_ack;
    if (infop->dl_provider_style == DL_STYLE2 && (dlattachreq(fd, ppa, ebuf) < 0 ||
        dlokack(fd, "attach", (char *)buf, ebuf) < 0))
-      Error_msg("ec_inet_solaris:%d dlattachreq() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("dlattachreq()");
 
    /*
    ** Bind
    */
    if (dlbindreq(fd, 0, ebuf) < 0 || dlbindack(fd, (char *)buf, ebuf) < 0)
-      Error_msg("ec_inet_solaris:%d dlbindreq() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("dlbindreq()");
 
 
    /*
    ** Determine link type
    */
    if (dlinforeq(fd, ebuf) < 0 || dlinfoack(fd, (char *)buf, ebuf) < 0)
-      Error_msg("ec_inet_solaris:%d dlinforeq() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("dlinforeq()");
 
    infop = &((union DL_primitives *)buf)->info_ack;
    switch (infop->dl_mac_type)
@@ -467,7 +485,7 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
    ** This is a non standard SunOS hack to get the ethernet header.
    */
    if (strioctl(fd, DLIOCRAW, 0, NULL) < 0)
-      Error_msg("ec_inet_solaris:%d strioctl(DLIOCRAW) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("strioctl(DLIOCRAW)");
 
 #endif
 
@@ -476,7 +494,7 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
    ** Another non standard call to get the data nicely buffered
    */
    if (ioctl(fd, I_PUSH, "bufmod") != 0)
-      Error_msg("ec_inet_solaris:%d ioclt(I_PUSH) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("ioclt(I_PUSH)");
 
    /*
    ** Now that the bufmod is pushed lets configure it.
@@ -499,17 +517,17 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
    }
 
    if (ss > 0 && strioctl(fd, SBIOCSSNAP, sizeof(ss), (char *)&ss) != 0)
-      Error_msg("ec_inet_solaris:%d strioctl(SBIOCSSNAP) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("strioctl(SBIOCSSNAP)");
 
    /*
    ** Set up the bufmod flags
    */
    if (strioctl(fd, SBIOCGFLAGS, sizeof(flag), (char *)&flag) < 0)
-      Error_msg("ec_inet_solaris:%d strioctl(SBIOCGFLAGS) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("strioctl(SBIOCGFLAGS)");
 
    flag |= SB_NO_DROPS;
    if (strioctl(fd, SBIOCSFLAGS, sizeof(flag), (char *)&flag) != 0)
-      Error_msg("ec_inet_solaris:%d strioctl(SBIOCSFLAGS) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("strioctl(SBIOCSFLAGS)");
 
 #endif
 
@@ -517,11 +535,13 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
    ** As the last operation flush the read side.
    */
    if (ioctl(fd, I_FLUSH, FLUSHR) != 0)
-      Error_msg("ec_inet_solaris:%d ioctl(I_FLUSH) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("ioctl(I_FLUSH)");
 
    bufsize = MAXDLBUF * sizeof(u_int);             // global var...
 
-   fdprom = fd;   // for later use in the Set_Promisc
+   DEBUG_MSG("Inet_OpenRawSock \t fd = %d", fd);
+
+   dlpi_in_use = fd;   // for later use in the Set_Promisc
 
    return (fd);
 
@@ -548,9 +568,11 @@ int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type)
    static char MyMAC[6]={0x65,0x74,0x74,0x65,0x72,0x63};
 
 
-   if (SocketBuffer == -1)                   // only the first time
+   if (SocketBuffer == -1) {                  // only the first time
       SocketBuffer = Buffer_Create(1.0e5);   // 100 K buffer
-
+      DEBUG_MSG("Inet_GetRawPacket creates the buffer for the first time -- buf id = %d", SocketBuffer);
+   }
+   
    Buffer_Get(SocketBuffer, &pktlen, sizeof(u_int));
    len = Buffer_Get(SocketBuffer, buffer, pktlen );
 
@@ -592,6 +614,9 @@ int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type)
 // } else
 //    bp = p->bp;
 
+ 	if (data.len > 0) 
+      DEBUG_MSG("Inet_GetRawPacket \t data.len = %d", data.len);
+
    bp = buf + offset;
 
  /* Loop through packets */
@@ -703,7 +728,7 @@ int Inet_SendRawPacket(int sock, char *buffer, int len)
 
    c = putmsg(sock, NULL, &data, 0);
    if (c == -1)
-      Error_msg("ec_inet_solaris:%d putmsg() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      ERROR_MSG("putmsg()");
 
    return (len);
 
@@ -713,14 +738,16 @@ int Inet_SendRawPacket(int sock, char *buffer, int len)
 
 int Inet_SetPromisc(char *iface)
 {
-   int fd = fdprom;  // fdprom is global and set by Inet_OpenRawSock. it is the last opened socket
+   int fd = dlpi_in_use;  // dlpi_in_use is global and set by Inet_OpenRawSock. it is the last opened socket
    u_long buf[MAXDLBUF];
 
+   DEBUG_MSG("Inet_SetPromisc \t fd = %d", fd);
+
    /*
    ** Enable promiscuous
    */
-   if (dlpromisconreq(fd, DL_PROMISC_PHYS, ebuf) < 0 || dlokack(fd, "promisc_phys", (char *)buf, ebuf) < 0)
-      Error_msg("ec_inet_solaris:%d dlpromisconreq() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+   if (dlpromisconreq(dlpi_in_use, DL_PROMISC_PHYS, ebuf) < 0 || dlokack(dlpi_in_use, "promisc_phys", (char *)buf, ebuf) < 0)
+      ERROR_MSG("dlpromisconreq()");
 
    return 0;
 }
@@ -739,20 +766,20 @@ void Inet_Restore_ifr(void)
 
 void Inet_DisableForwarding(void)
 {
-   Error_msg("SOLARIS PORTING NOT YET FINISHED...\n");
+   ERROR_MSG("SOLARIS PORTING NOT YET FINISHED...\n");
 }
 
 
 
 void Inet_RestoreForwarding(void)
 {
-   Error_msg("SOLARIS PORTING NOT YET FINISHED...\n");
+   ERROR_MSG("SOLARIS PORTING NOT YET FINISHED...\n");
 }
 
 
 char *Inet_MacFromIP(unsigned long ip)
 {
-   Error_msg("SOLARIS PORTING NOT YET FINISHED...\n");
+   ERROR_MSG("SOLARIS PORTING NOT YET FINISHED...\n");
    return "";
 }
 
@@ -858,7 +885,7 @@ dlpromiscoffreq(int fd, u_int level, char *ebuf)
     return (send_request(fd, (char *)&req, sizeof(req), "promiscoff", ebuf));
 }
 */
-
+/*
 static int
 dlpromisconreq(int fd, u_int level, char *ebuf)
 {
@@ -869,7 +896,7 @@ dlpromisconreq(int fd, u_int level, char *ebuf)
 
     return (send_request(fd, (char *)&req, sizeof(req), "promiscon", ebuf));
 }
-
+*/
 
 static int
 dlattachreq(int fd, u_int ppa, char *ebuf)
@@ -994,14 +1021,9 @@ split_dname(char *device, int *unitp)
 	 */
 	cp = device + strlen(device) - 1;
 
-#ifdef DEBUG
-	Debug_msg("split_dname --> [%s] [%c]", device, *cp);
-#endif
-
 	if (*cp < '0' || *cp > '9')
 		return (NULL);
 
-
 	/* Digits at end of string are unit number */
 	while (cp-1 >= device && *(cp-1) >= '0' && *(cp-1) <= '9')
 		cp--;
@@ -1017,3 +1039,6 @@ split_dname(char *device, int *unitp)
 
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
