@@ -17,11 +17,10 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_buffer.c,v 1.5 2001/12/08 16:38:43 alor Exp $
+    $Id: ec_buffer.c,v 1.7 2002/03/08 08:49:55 alor Exp $
 */
 
 #include "include/ec_main.h"
-#include "include/ec_error.h"
 
 #define MAX_BUFFERS 10
 #define HEAD_LEN 8
@@ -29,7 +28,7 @@
 typedef struct {
     char *data;
     int len;
-}Buffer_Data;
+} Buffer_Data;
 
 // global data
 
@@ -53,10 +52,8 @@ int Buffer_Create(int len)
 {
    int i;
 
-   for (i=0; i<MAX_BUFFERS; i++)
-   {
-      if (!Buffer_List[i].data)
-      {
+   for (i=0; i<MAX_BUFFERS; i++) {
+      if (!Buffer_List[i].data) {
          Buffer_List[i].data = (char *) calloc(len+HEAD_LEN, sizeof(char));
          Buffer_List[i].len = len;
          break;
@@ -65,9 +62,7 @@ int Buffer_Create(int len)
 
    if (i == MAX_BUFFERS) i=-1;
 
-#ifdef DEBUG
-   Debug_msg("Buffer_Create -- [%d] len %d", i, len);
-#endif
+   DEBUG_MSG("Buffer_Create -- [%d] len %d", i, len);
 
    return i;
 }
@@ -103,16 +98,14 @@ int Buffer_Get(int ID, void *to_read, int size)
 
    reprise =- Buffer_List[ID].len+(*R_Offset)+size;
 
-   if (reprise>(long)W_Offset)
-   {
+   if (reprise>(long)W_Offset) {
        size -= reprise-(W_Offset);
        reprise = W_Offset;
    }
 
    if (reprise<0)
        memcpy((char *)to_read, data+(*R_Offset), size);
-   else
-   {
+   else {
        memcpy((char *)to_read, data+(*R_Offset), size-reprise);
        memcpy(((char *)to_read)+size-reprise, data, reprise);
    }
@@ -142,13 +135,11 @@ int Buffer_Put(int ID, void *to_write, int size)
 
    reprise  =- Buffer_List[ID].len + (*W_Offset) + size;
 
-   while((*W_Offset<*R_Offset && *W_Offset+size>=*R_Offset) || reprise>=(long)*R_Offset)
-   {
-      #ifdef DEBUG
-         Debug_msg("Buffer_Put -- %d BUFFER FULL !! buff len [%d] byte lost [%d]", ID, Buffer_List[ID].len, size);
-      #endif
-      if (retry >= 2)
-      {
+   while((*W_Offset<*R_Offset && *W_Offset+size>=*R_Offset) || reprise>=(long)*R_Offset) {
+      
+      DEBUG_MSG("Buffer_Put -- %d BUFFER FULL !! buff len [%d] byte lost [%d]", ID, Buffer_List[ID].len, size);
+      
+      if (retry >= 2) {
          retry = 0;
          return 0;
       }
@@ -160,8 +151,7 @@ int Buffer_Put(int ID, void *to_write, int size)
 
    if (reprise<=0)
        memcpy(data+*W_Offset, (char *)to_write, size);
-   else
-   {
+   else {
        memcpy(data+*W_Offset, (char *)to_write, size-reprise);
        memcpy(data, ((char *)to_write)+size-reprise ,reprise);
    }
@@ -175,3 +165,6 @@ int Buffer_Put(int ID, void *to_write, int size)
 
 /* EOF */
 
+
+// vim:ts=3:expandtab
+
