@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_debug.c,v 1.5 2001/12/08 11:22:20 alor Exp $
+    $Id: ec_debug.c,v 1.13 2002/04/07 22:36:37 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -39,6 +39,10 @@
    #endif
 #endif
 
+#ifdef CYGWIN
+	#include <Packet32.h>
+#endif
+
 #ifndef DEBUG_FILE
    #define DEBUG_FILE "ettercap_debug.log"
 #endif
@@ -47,24 +51,31 @@
 
 FILE *debug_dev;
 
-void Debug_Init(void);
-void Debug_Close(void);
-void Debug_msg(char *message, ...);
+void debug_init(void);
+void debug_close(void);
+
+#ifdef MACOSX
+void DEBUG_MSG(char *message, ...);
+#else
+void debug_msg(char *message, ...);
+#endif
 
 //----------------------------
 
-void Debug_Init(void)
+void debug_init(void)
 {
+#ifdef HAVE_SYS_UTSNAME_H
    struct utsname buf;
+#endif
 
-   if ((debug_dev = fopen (DEBUG_FILE, "a")) < 0)
-   {
-      fprintf(stderr, "Couldn't open DEBUG FILE!\n");
-      exit(0);
-   }
-   else
-   {
-      fprintf (debug_dev, "\n\n-> %s %s\n\n", PROGRAM, VERSION);
+   if ((debug_dev = fopen (DEBUG_FILE, "w")) == NULL) {
+      ERROR_MSG("Couldn't open DEBUG FILE!");
+   } else {
+   	#ifdef DEVEL_RELEASE
+      	fprintf (debug_dev, "\n\n-> %s %s %s\n\n", PROGRAM, VERSION, RELEASE_DATE);
+      #else
+      	fprintf (debug_dev, "\n\n-> %s %s\n\n", PROGRAM, VERSION);
+      #endif
       #ifdef HAVE_SYS_UTSNAME_H
          uname(&buf);
          #if defined (__GLIBC__) && defined (__GLIBC_MINOR__)
@@ -73,21 +84,28 @@ void Debug_Init(void)
             fprintf (debug_dev, "-> running on %s %s\n", buf.sysname, buf.release);
          #endif
       #endif
+      #ifdef CYGWIN
+      	fprintf (debug_dev, "-> packet driver version %s\n", PacketGetVersion());
+      #endif
       #if defined (__GNUC__) && defined (__GNUC_MINOR__)
          fprintf (debug_dev, "-> compiled with gcc %d.%d\n", __GNUC__, __GNUC_MINOR__);
       #endif
       #ifdef HAVE_NCURSES
-         fprintf (debug_dev, "-> %s\n", curses_version());
+      	#ifdef CYGWIN
+      		fprintf (debug_dev, "-> pdcurses %d \n", PDC_BUILD);
+      	#else
+      		fprintf (debug_dev, "-> %s\n", curses_version());
+      	#endif
       #endif
       fprintf (debug_dev, "\n\nDEVICE OPENED FOR %s DEBUGGING\n\n", PROGRAM);
       fflush(debug_dev);
-      atexit(Debug_Close);
+      atexit(debug_close);
    }
 }
 
 
 
-void Debug_Close(void)
+void debug_close(void)
 {
    fprintf (debug_dev, "\n\nDEBUGGING DEVICE FOR %s WAS CLOSED\n\n", ECThread_getname(pthread_self()));
    fclose (debug_dev);
@@ -95,15 +113,18 @@ void Debug_Close(void)
 
 
 
-void Debug_msg(char *message, ...)
+#ifdef MACOSX
+void DEBUG_MSG(char *message, ...)
+#else
+void debug_msg(char *message, ...)
+#endif
 {
-
    va_list ap;
    char debug_message[strlen(message)+2];
 
    fprintf (debug_dev, "%-10s\t", ECThread_getname(pthread_self()));
 
-   strlcpy(debug_message, message, sizeof(debug_message)); // for backward compatibility
+   strlcpy(debug_message, message, sizeof(debug_message));
    strlcat(debug_message, "\n", sizeof(debug_message));
 
    va_start(ap, message);
@@ -114,6 +135,25 @@ void Debug_msg(char *message, ...)
 
 }
 
+#else /* not defined DEBUG */
+
+#ifdef MACOSX
+   /*
+    * damned MACOSX  cc compiler !!
+    * it doesn't support our macro DEBUG_MSG(x, args...)
+    */
+
+   void DEBUG_MSG(char *message, ...);
+
+   void DEBUG_MSG(char *message, ...)
+   {
+      return;
+   }
 #endif
 
+#endif /* DEBUG */
+
 /* EOF */
+
+// vim:ts=3:expandtab
+
