@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_decodedata.c,v 1.18 2001/12/09 20:24:51 alor Exp $
+    $Id: ec_decodedata.c,v 1.22 2002/04/11 20:16:36 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -28,7 +28,6 @@
 
 #include "include/ec_inet_structures.h"
 #include "include/ec_inet.h"
-#include "include/ec_error.h"
 #include "include/ec_parser.h"
 
 
@@ -77,6 +76,7 @@ int Decodedata_GetArrayIndex(CONNECTION *data);
 void Decodedata_SetArrayIndex(CONNECTION *data, int index);
 int Decodedata_MakeConnectionList(CONNECTION *data);
 int Decodedata_RefreshConnectionList(void);
+void * DecodeData_Connection_Timeouter(void *dummy);
 void Decodedata_UpdateInfo(CONNECTION *ptr, CONNECTION *data);
 
 int Decodedata_MakePassiveList(PASSIVE_DATA *data);
@@ -189,10 +189,8 @@ int Decodedata_MakeConnectionList(CONNECTION *data)
       else
          number_of_connections++;
 
-      #ifdef DEBUG
-         Debug_msg("Decodedata_MakeConnectionList - new node ! %d ! %c %s:%d - %s:%d ", number_of_connections,
+      DEBUG_MSG("Decodedata_MakeConnectionList - new node ! %d ! %c %s:%d - %s:%d ", number_of_connections,
                    data->proto, data->source_ip, data->source_port, data->dest_ip, data->dest_port);
-      #endif
 
       Conn_Between_Hosts = (CONNECTION *)realloc(Conn_Between_Hosts, number_of_connections*sizeof(CONNECTION));
       if ( Conn_Between_Hosts == NULL )
@@ -339,15 +337,52 @@ void Decodedata_UpdateInfo(CONNECTION *ptr, CONNECTION *data)
 }
 
 
+void * DecodeData_Connection_Timeouter(void *dummy)      // Timeouter thread
+{
+   int i;
+   time_t now;
+   extern pthread_mutex_t connection_mutex;
+
+   loop
+   {
+      pthread_testcancel();
+
+      if (number_of_connections <= 0)
+      {
+         usleep(5000);
+         continue;
+      }
+
+      now = time(NULL);
+
+      pthread_mutex_lock(&connection_mutex);
+
+      for (i = 0; i < number_of_connections; i++)
+      {
+         if (Conn_Between_Hosts[i].proto == 'T')
+         {
+            if (!strcmp(Conn_Between_Hosts[i].status, "ACTIVE") && Conn_Between_Hosts[i].timestamp <= now - CONN_TIME_SILENT)
+               strcpy(Conn_Between_Hosts[i].status, "silent");
+
+            if (strcmp(Conn_Between_Hosts[i].status, "KILLED") &&
+                strcmp(Conn_Between_Hosts[i].status, "CLOSED") && Conn_Between_Hosts[i].timestamp <= now - CONN_TIME_TIMEOUT) // 10 min of timeout
+               strcpy(Conn_Between_Hosts[i].status, "timeout");
+         }
+      }
+
+      pthread_mutex_unlock(&connection_mutex);
+
+      sleep(2);
+   }
+}
+
 
 int Decodedata_RefreshConnectionList(void)
 {
    struct conn_hash_list *current;
    int i;
 
-#ifdef DEBUG
-   Debug_msg("Decodedata_RefreshConnectionList");
-#endif
+   DEBUG_MSG("Decodedata_RefreshConnectionList");
 
    pthread_mutex_trylock(&connection_mutex);
 
@@ -395,9 +430,7 @@ void Decodedata_UpdatePassiveInfo(PASSIVE_DATA *ptr, PASSIVE_DATA *data)
       {
          strlcpy(ptr->fingerprint, data->fingerprint, sizeof(ptr->fingerprint));
 
-         #ifdef DEBUG
-            Debug_msg("Decodedata_UpdatePassiveInfo -- %15s %25s", data->ip, data->fingerprint);
-         #endif
+         DEBUG_MSG("Decodedata_UpdatePassiveInfo -- %15s %25s", data->ip, data->fingerprint);
 
          if (Decodedata_GetPassiveOS(data->fingerprint, OS) == 0)
             strlcpy(ptr->os, OS, sizeof(ptr->os));
@@ -516,9 +549,7 @@ int Decodedata_MakePassiveList(PASSIVE_DATA *data)
       int j;
       struct open_ports *cur;
 
-      #ifdef DEBUG
-         Debug_msg("Decodedata_MakePassiveList - new node ! %d ! %s - %s", num_conn, data->ip, data->fingerprint);
-      #endif
+      DEBUG_MSG("Decodedata_MakePassiveList - new node ! %d ! %s - %s", num_conn, data->ip, data->fingerprint);
 
       Passive_Host = (PASSIVE_DATA *)realloc(Passive_Host, num_conn*sizeof(PASSIVE_DATA));
       if ( Passive_Host == NULL )
@@ -553,9 +584,7 @@ int Decodedata_FreePassiveList(void)
    int i;
    struct open_ports *cur;
 
-#ifdef DEBUG
-   Debug_msg("Decodedata_FreePassiveList");
-#endif
+   DEBUG_MSG("Decodedata_FreePassiveList");
 
    pthread_mutex_lock(&passive_mutex);
 
@@ -738,9 +767,7 @@ char * Decodedata_GetType(char proto, int port1, int port2)
       char line[1024], desc[18], stype[4];
       int port;
 
-#ifdef DEBUG
-   Debug_msg("Decodedata_GetType - loading from /etc/services");
-#endif
+      DEBUG_MSG("Decodedata_GetType - loading from /etc/services");
 
       if ( (d_index = (database *)calloc(1,sizeof(database))) == NULL)
          ERROR_MSG("calloc()");
@@ -748,7 +775,9 @@ char * Decodedata_GetType(char proto, int port1, int port2)
       d_list = d_index;
 
       if (!(f_ser = fopen ("/etc/services", "r")))
-         ERROR_MSG("fopen(\"/etc/services\")");
+         if (!(f_ser = fopen ("./share/services", "r")))
+            if (!(f_ser = fopen (DATA_PATH "/services", "r")))
+               return "";
 
       while (fgets (line, 1024, f_ser))
       {
@@ -816,16 +845,12 @@ int Decodedata_GetPassiveOS(char *fingerprint, char *os)
             Error_msg("\nCan't find " OS_FILE " in ./ or " DATA_PATH);
          else
          {
-            #ifdef DEBUG
-               Debug_msg("Decodedata_GetPassiveOS - loading from " DATA_PATH "/" OS_FILE);
-            #endif
+            DEBUG_MSG("Decodedata_GetPassiveOS - loading from " DATA_PATH "/" OS_FILE);
          }
       }
       else
       {
-         #ifdef DEBUG
-            Debug_msg("Decodedata_GetPassiveOS - loading from ./" OS_FILE);
-         #endif
+         DEBUG_MSG("Decodedata_GetPassiveOS - loading from ./" OS_FILE);
       }
 
       while (fgets (line, 1024, f_os))
@@ -885,9 +910,7 @@ int Decodedata_GetPassiveOS(char *fingerprint, char *os)
       }
    }
 
-   #ifdef DEBUG
-      Debug_msg("Decodedata_GetPassiveOS - result: %d %s", ret, os);
-   #endif
+   DEBUG_MSG("Decodedata_GetPassiveOS - result: %d %s", ret, os);
 
    return ret;
 }
@@ -900,9 +923,7 @@ void Decodedata_ConvertPassiveToHost(void)
    int num_conn = 1;
    PASSIVE_DATA *ptr;
 
-#ifdef DEBUG
-   Debug_msg("Decodedata_ConvertPassiveToHost -- %d", number_of_hosts_in_lan);
-#endif
+   DEBUG_MSG("Decodedata_ConvertPassiveToHost -- %d", number_of_hosts_in_lan);
 
    pthread_mutex_lock(&passive_mutex);
 
@@ -932,9 +953,7 @@ void Decodedata_ConvertPassiveToHost(void)
 
    pthread_mutex_unlock(&passive_mutex);
 
-#ifdef DEBUG
-   Debug_msg("Decodedata_ConvertPassiveToHost -- %d host(s) converted ", number_of_hosts_in_lan );
-#endif
+   DEBUG_MSG("Decodedata_ConvertPassiveToHost -- %d host(s) converted ", number_of_hosts_in_lan );
 }
 
 
@@ -959,9 +978,7 @@ void Decodedata_Passive_SortList(void)
    int i;
    struct open_ports *cur;
 
-#ifdef DEBUG
-   Debug_msg("Decodedata_Passive_SortList");
-#endif
+   DEBUG_MSG("Decodedata_Passive_SortList");
 
    pthread_mutex_lock(&passive_mutex);
 
@@ -982,3 +999,6 @@ void Decodedata_Passive_SortList(void)
 
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
