@@ -17,14 +17,13 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_ftp.c,v 1.5 2001/12/09 20:24:51 alor Exp $
+    $Id: ec_dissector_ftp.c,v 1.6 2002/03/08 08:49:55 alor Exp $
 */
 
 #include "include/ec_main.h"
 
 #include "include/ec_dissector.h"
 #include "include/ec_inet_structures.h"
-#include "include/ec_error.h"
 
 // protos
 
@@ -49,18 +48,14 @@ FUNC_DISSECTOR(Dissector_ftp)
 
    if ( !strncasecmp(payload, "USER", 4) )
    {
-      #ifdef DEBUG
-         Debug_msg("\tDissector_FTP USER");
-      #endif
+      DEBUG_MSG("\tDissector_FTP USER");
       strlcpy(data_to_ettercap->user, payload + strlen("USER "), sizeof(data_to_ettercap->user));
       return 0;
    }
 
    if ( !strncasecmp(payload, "PASS", 4) )
    {
-      #ifdef DEBUG
-         Debug_msg("\tDissector_FTP PASS");
-      #endif
+      DEBUG_MSG("\tDissector_FTP PASS");
       strlcpy(data_to_ettercap->pass, payload + strlen("PASS "), sizeof(data_to_ettercap->pass));
       return 0;
    }
@@ -70,3 +65,6 @@ FUNC_DISSECTOR(Dissector_ftp)
 
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
