@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_http.c,v 1.11 2001/12/13 17:05:20 alor Exp $
+    $Id: ec_dissector_http.c,v 1.15 2002/04/18 19:23:54 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -26,7 +26,6 @@
 
 #include "include/ec_dissector.h"
 #include "include/ec_inet_structures.h"
-#include "include/ec_error.h"
 
 
 #define USER 1
@@ -71,13 +70,12 @@ FUNC_DISSECTOR(Dissector_http)
       char *host = NULL;
       char *url = NULL;
       char *q;
-      char user[25];
-      char pass[25];
+      char user[sizeof(data_to_ettercap->user)-5];
+      char pass[sizeof(data_to_ettercap->pass)-5];
       size_t len;
 
-      #ifdef DEBUG
-         Debug_msg("\tDissector_HTTP %d -- method GET -- \n\n%s\n\n", SERV_PORT, collector);
-      #endif
+      //DEBUG_MSG("\tDissector_HTTP %d -- method GET -- \n\n%s\n\n", SERV_PORT, collector);
+      DEBUG_MSG("\tDissector_HTTP %d -- method GET -- ", SERV_PORT);
 
       to_parse = strdup(fromhere);
       if ((q = strstr(to_parse, "HTTP")))
@@ -96,9 +94,7 @@ FUNC_DISSECTOR(Dissector_http)
          {
             url = strdup(fromhere + strlen("Referer: "));
             strtok(url, "\r\n");
-            #ifdef DEBUG
-               Debug_msg("\tDissector_HTTP -- referer: [%s]", url);
-            #endif
+            DEBUG_MSG("\tDissector_HTTP -- referer: [%s]", url);
          }
          else                                               // get the page from other header
          {
@@ -127,14 +123,10 @@ FUNC_DISSECTOR(Dissector_http)
 
             free(page);
             free(host);
-            #ifdef DEBUG
-               Debug_msg("\tDissector_HTTP -- host + page : [%s]", url);
-            #endif
+            DEBUG_MSG("\tDissector_HTTP -- host + page : [%s]", url);
          }
 
-         #ifdef DEBUG
-            Debug_msg("\tDissector_HTTP -- after page [%s]", url);
-         #endif
+         //DEBUG_MSG("\tDissector_HTTP -- after page [%s]", url);
 
          decode_url(url);
          snprintf(data_to_ettercap->info, sizeof(data_to_ettercap->info), "%s\n", url);
@@ -152,21 +144,18 @@ FUNC_DISSECTOR(Dissector_http)
       char *page = NULL;
       char *host = NULL;
       char *url = NULL;
-      char user[25];
-      char pass[25];
+      char user[sizeof(data_to_ettercap->user)-5];
+      char pass[sizeof(data_to_ettercap->pass)-5];
       size_t len;
 
-      #ifdef DEBUG
-         Debug_msg("\tDissector_HTTP %d -- method POST -- \n\n%s\n\n", SERV_PORT, collector);
-      #endif
+      //DEBUG_MSG("\tDissector_HTTP %d -- method POST -- \n\n%s\n\n", SERV_PORT, collector);
+      DEBUG_MSG("\tDissector_HTTP %d -- method POST -- ", SERV_PORT);
 
       if ((fromhere = strstr(collector, "Referer:")))    // if exist the referer
       {
          url = strdup(fromhere + strlen("Referer: "));
          strtok(url, "\r\n");
-         #ifdef DEBUG
-            Debug_msg("\tDissector_HTTP -- referer: [%s]", url);
-         #endif
+         DEBUG_MSG("\tDissector_HTTP -- referer: [%s]", url);
       }
       else                                               // get the page from other header
       {
@@ -192,21 +181,17 @@ FUNC_DISSECTOR(Dissector_http)
          snprintf(url, len, "%s%s", host, page);
          free(page);
          free(host);
-         #ifdef DEBUG
-            Debug_msg("\tDissector_HTTP -- host + page : [%s]", url);
-         #endif
+         DEBUG_MSG("\tDissector_HTTP -- host + page : [%s]", url);
       }
 
-      #ifdef DEBUG
-         Debug_msg("\tDissector_HTTP -- after page [%s]", url);
-      #endif
+      //DEBUG_MSG("\tDissector_HTTP -- after page [%s]", url);
 
       if (strstr(collector, "User-Agent: Mozilla") && !strstr(collector, "MSIE")
           && !strstr(collector,"Opera"))                                            // if user-agent is Netscape
       {                                                                             // it posts the data in the
-         #ifdef DEBUG                                                               // second packet, so we set
-            Debug_msg("\tDissector_HTTP -- method POST -- mozilla");                // the state to catch them
-         #endif                                                                     // later
+                                                                                    // second packet, so we set
+         DEBUG_MSG("\tDissector_HTTP -- method POST -- mozilla");                   // the state to catch them
+                                                                                    // later
          Dissector_StateMachine_SetStatus(data_to_ettercap, 1, NULL);
          decode_url(url);
          snprintf(data_to_ettercap->info, sizeof(data_to_ettercap->info), "%s\n", url);
@@ -214,9 +199,7 @@ FUNC_DISSECTOR(Dissector_http)
          return 0;
       }
 
-      #ifdef DEBUG
-         Debug_msg("\tDissector_HTTP -- after netscape");
-      #endif
+      //DEBUG_MSG("\tDissector_HTTP -- after netscape");
 
       if (!strstr(collector, "application/x-www-form-urlencoded"))
          return 0;
@@ -227,9 +210,7 @@ FUNC_DISSECTOR(Dissector_http)
       else
          to_parse += 4;
 
-      #ifdef DEBUG
-         Debug_msg("\tDissector_HTTP -- after to_parse -- [%s]", to_parse);
-      #endif
+      //DEBUG_MSG("\tDissector_HTTP -- after to_parse -- [%s]", to_parse);
 
       if (parse_form(to_parse, user, USER) && parse_form(to_parse, pass, PASS))
       {
@@ -249,14 +230,12 @@ FUNC_DISSECTOR(Dissector_http)
    if (Dissector_StateMachine_GetStatus(data_to_ettercap, NULL) >= 1)   // Netscape
    {
       char *to_parse;
-      char user[25];
-      char pass[25];
+      char user[sizeof(data_to_ettercap->user)-5];
+      char pass[sizeof(data_to_ettercap->pass)-5];
 
 
-      #ifdef DEBUG
-         Debug_msg("\tDissector_HTTP %d -- mozilla -- second packet", SERV_PORT);
-      #endif
-
+      DEBUG_MSG("\tDissector_HTTP %d -- mozilla -- second packet", SERV_PORT);
+/*
       if (Dissector_StateMachine_GetStatus(data_to_ettercap, NULL) == 1)
       {
          if (!strstr(collector, "Content-type: application/x-www-form-urlencoded"))
@@ -266,15 +245,19 @@ FUNC_DISSECTOR(Dissector_http)
          }
          Dissector_StateMachine_SetStatus(data_to_ettercap, 2, NULL);
       }
+*/
+
+      if (Dissector_StateMachine_GetStatus(data_to_ettercap, NULL) == 2)
+         Dissector_StateMachine_SetStatus(data_to_ettercap, 0, NULL);
+      else if (strstr(collector,"\r\n\r\n"))
+         Dissector_StateMachine_SetStatus(data_to_ettercap, 2, NULL);
 
       if ((to_parse = strstr(collector, "\r\n\r\n")))
          to_parse += 4;
       else
          to_parse = collector;
 
-      #ifdef DEBUG
-         Debug_msg("\tDissector_HTTP - Mozilla - [%s]", to_parse);
-      #endif
+      //DEBUG_MSG("\tDissector_HTTP - Mozilla - [%s]", to_parse);
 
       if (parse_form(to_parse, user, USER) && parse_form(to_parse, pass, PASS))
       {
@@ -295,17 +278,15 @@ FUNC_DISSECTOR(Dissector_http)
 
    if ( (fromhere = strstr(collector, "Authorization: Basic")) || (fromhere = strstr(collector, "Proxy-authorization: Basic")) )
    {
-      char user[25] = "";
-      char pass[25] = "";
+      char user[sizeof(data_to_ettercap->user)-5] = "";
+      char pass[sizeof(data_to_ettercap->pass)-5] = "";
       char *decoded;
       char *to_be_decoded;
       char *token;
       char *page = NULL;
       char *host = NULL;
 
-      #ifdef DEBUG
-         Debug_msg("\tDissector_HTTP -- Authorization -- %s", fromhere);
-      #endif
+      DEBUG_MSG("\tDissector_HTTP -- Authorization --");
 
       if (strstr(collector, "GET"))
       {
@@ -337,9 +318,7 @@ FUNC_DISSECTOR(Dissector_http)
 
       Dissector_base64decode(decoded, to_be_decoded);
 
-      #ifdef DEBUG
-         Debug_msg("\tDissector_HTTP - decoding - [%s] [%s]", to_be_decoded, decoded);
-      #endif
+      DEBUG_MSG("\tDissector_HTTP - decoding - [%s] [%s]", to_be_decoded, decoded);
 
       if ( (token = strsep(&decoded, ":")) != NULL)
       {
@@ -359,9 +338,7 @@ FUNC_DISSECTOR(Dissector_http)
 
       snprintf(data_to_ettercap->info, sizeof(data_to_ettercap->info), "http://%s%s\n", host, page);
 
-      #ifdef DEBUG
-         Debug_msg("\tDissector_HTTP -- [%s][%s]", host, page);
-      #endif
+      DEBUG_MSG("\tDissector_HTTP -- [%s][%s]", host, page);
 
       free(page);
       free(host);
@@ -398,15 +375,15 @@ int parse_form(char *to_parse, char *ret, char mode)
 
    if (to_parse[0] == '?') to_parse++;    // strip the '?' from a GET method
 
+	if (!strncmp(to_parse, " ", 1)) return 0;
+
    tmp = strdup(to_parse);
 
    ptr = user_field;
    if (mode == PASS)
       ptr = pass_field;
 
-#ifdef DEBUG
-   Debug_msg("\tHTTP_dissector -- parse_form -- [%s]", to_parse);
-#endif
+   //DEBUG_MSG("\tHTTP_dissector -- parse_form -- [%s]", to_parse);
 
    for (i=0; strcmp(ptr[i], ""); i++)
    {
@@ -460,3 +437,6 @@ void decode_url(char *src)
 
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
