@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_mysql.c,v 1.6 2001/12/09 20:24:51 alor Exp $
+    $Id: ec_dissector_mysql.c,v 1.8 2002/04/18 19:23:54 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -25,7 +25,6 @@
 #include "include/ec_dissector.h"
 #include "include/ec_decodedata.h"
 #include "include/ec_inet_structures.h"
-#include "include/ec_error.h"
 
 // protos
 
@@ -61,9 +60,7 @@ FUNC_DISSECTOR(Dissector_mysql)
          )
          return 0;
 
-      #ifdef DEBUG
-         Debug_msg("\tDissector_MySQL server");
-      #endif
+      DEBUG_MSG("\tDissector_MySQL server");
 
       while(collector[i] != collector[i-1] != collector[i-2] != 0)   // search for 000 padding
          i++;
@@ -77,7 +74,7 @@ FUNC_DISSECTOR(Dissector_mysql)
 
    if ( (Dissector_StateMachine_GetStatus(data_to_ettercap, NULL) == 1) && ntohs(tcp->dest) == SERV_PORT)  // client response crypt pass with seed
    {
-      char pass[25];
+      char pass[sizeof(data_to_ettercap->pass)-1];
 
       snprintf(data_to_ettercap->user, sizeof(data_to_ettercap->user), "%s", collector + 9);
       strlcat(data_to_ettercap->user, "\n", sizeof(data_to_ettercap->user));
@@ -99,3 +96,6 @@ FUNC_DISSECTOR(Dissector_mysql)
 }
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
