@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_rlogin.c,v 1.4 2001/12/09 20:24:51 alor Exp $
+    $Id: ec_dissector_rlogin.c,v 1.5 2002/03/08 08:49:55 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -28,7 +28,6 @@
 
 #include "include/ec_dissector.h"
 #include "include/ec_inet_structures.h"
-#include "include/ec_error.h"
 
 // protos
 
@@ -102,3 +101,6 @@ FUNC_DISSECTOR(Dissector_rlogin)
 
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
