@@ -3,7 +3,7 @@
 
     Copyright (C) 2001  ALoR <alor@users.sourceforge.net>, NaGA <crwm@freemail.it>
 
-    Additional Copyright for this file: LnZ Lorenzo Porro
+    Additional Copyright for this file: LnZ Lorenzo Porro <lporro@libero.it>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
     USA.
 
-    $Id: ec_dissector_snmp.c,v 1.5 2001/12/09 20:24:51 alor Exp $
+    $Id: ec_dissector_snmp.c,v 1.7 2002/04/18 17:03:17 alor Exp $
 */
 
 
@@ -28,7 +28,6 @@
 
 #include "include/ec_dissector.h"
 #include "include/ec_inet_structures.h"
-#include "include/ec_error.h"
 
 /* Protocol version numbers */
 /* for further implementation
@@ -99,9 +98,7 @@ FUNC_DISSECTOR(Dissector_snmp)
    udp = (UDP_header *) data;
    payload = (char *) ((int)udp + UDP_HEADER);
 
-#ifdef DEBUG
-   Debug_msg("\tDissector_SNMP");
-#endif
+   DEBUG_MSG("\tDissector_SNMP");
 
    if (data_to_ettercap->datalen == 0) return 0; // No data...
 
@@ -119,3 +116,6 @@ FUNC_DISSECTOR(Dissector_snmp)
 }
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
