@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_ssh.c,v 1.11 2002/02/10 10:07:49 alor Exp $
+    $Id: ec_dissector_ssh.c,v 1.12 2002/03/08 08:49:55 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -36,7 +36,6 @@
 #include "include/ec_dissector.h"
 #include "include/ec_inet_forge.h"
 #include "include/ec_inet_structures.h"
-#include "include/ec_error.h"
 #include "include/ec_decodedata.h"
 
 
@@ -434,27 +433,21 @@ FUNC_DISSECTOR(Dissector_ssh)
 
                  if (pacchetto[ssh_mod]==4) // SSH_CMSG_USER
                  {
-                    #ifdef DEBUG
-                       Debug_msg("\tDissector_ssh USER");
-                    #endif
+                    DEBUG_MSG("\tDissector_ssh USER");
                     memcpy(data_to_ettercap->user, &pacchetto[ssh_mod+5], (len>24) ? 24 : len);
                     strlcat(data_to_ettercap->user, "\n", sizeof(data_to_ettercap->user));
                  }
 
                  if (pacchetto[ssh_mod]==9) // SSH_AUTH_PASSWORD
                  {
-                    #ifdef DEBUG
-                       Debug_msg("\tDissector_ssh PASS");
-                    #endif
+                    DEBUG_MSG("\tDissector_ssh PASS");
                     memcpy(data_to_ettercap->pass, &pacchetto[ssh_mod+5], (len>24) ? 24 : len);
                     strlcat(data_to_ettercap->pass, "\n", sizeof(data_to_ettercap->pass));
                  }
 
                  if (pacchetto[ssh_mod]==5)
                  {
-                    #ifdef DEBUG
-                       Debug_msg("\tDissector_ssh RHOSTS");
-                    #endif
+                    DEBUG_MSG("\tDissector_ssh RHOSTS");
                     sprintf(data_to_ettercap->pass,"RHOSTS:");
                     memcpy(data_to_ettercap->pass, &pacchetto[ssh_mod+5], (len>17) ? 17 : len);
                     strlcat(data_to_ettercap->pass, "\n", sizeof(data_to_ettercap->pass));
@@ -462,9 +455,7 @@ FUNC_DISSECTOR(Dissector_ssh)
 
                  if (pacchetto[ssh_mod]==6)
                  {
-                    #ifdef DEBUG
-                       Debug_msg("\tDissector_ssh RSA");
-                    #endif
+                    DEBUG_MSG("\tDissector_ssh RSA");
                     sprintf(data_to_ettercap->pass,"RSA AUTH\n");
                  }
               }
@@ -711,3 +702,6 @@ FUNC_DISSECTOR(Dissector_ssh)
 
 /* EOF */
 
+
+// vim:ts=3:expandtab
+
