@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_doppleganger.c,v 1.7 2002/02/10 10:07:49 alor Exp $
+    $Id: ec_doppleganger.c,v 1.10 2002/04/22 09:12:00 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -28,7 +28,6 @@
 #include "include/ec_inet.h"
 #include "include/ec_inet_forge.h"
 #include "include/ec_inet_structures.h"
-#include "include/ec_error.h"
 #include "include/ec_thread.h"
 
 
@@ -64,9 +63,7 @@ void Doppleganger_reARP(void *dummy)        // turns back the ARP cache...
 {
    int i, j;
 
-#ifdef DEBUG
-   Debug_msg("Doppleganger_reARP");
-#endif
+   DEBUG_MSG("Doppleganger_reARP");
 
    // legal ARP reply :)
    for(j=0; j<3; j++)
@@ -100,9 +97,9 @@ void Doppleganger_reARP(void *dummy)        // turns back the ARP cache...
                }
             }
             usleep(Options.storm_delay);
-//            #ifdef DEBUG
-//               Debug_msg("Doppleganger_reARP -- rearping %d %d ", i, j);
-//            #endif
+          
+//          DEBUG_MSG("Doppleganger_reARP -- rearping %d %d ", i, j);
+
          }
        }
 
@@ -125,10 +122,11 @@ void Doppleganger_reARP(void *dummy)        // turns back the ARP cache...
        sleep(1);
    }
 
-#ifdef DEBUG
-   Debug_msg("Doppleganger_reARP -- END");
-#endif
+   DEBUG_MSG("Doppleganger_reARP -- END");
 
+   if (buf1) Inet_Forge_packet_destroy(buf1);
+   if (buf2) Inet_Forge_packet_destroy(buf2);
+   buf1 = buf2 = NULL;
 }
 
 
@@ -246,9 +244,7 @@ void * Doppleganger_Main(void *param)
 
    if ( ((buf1 && !buf2) || (!buf1 && buf2)) && number_of_hosts_in_lan > 1 )  // smart ARP
    {
-      #ifdef DEBUG
-         Debug_msg("Doppleganger_Run -- SMART ARPing... [delay = %d]", Options.delay);
-      #endif
+      DEBUG_MSG("Doppleganger_Run -- SMART ARPing... [delay = %d]", Options.delay);
 
       exit_func(Doppleganger_reARP);
 
@@ -313,31 +309,31 @@ void * Doppleganger_Main(void *param)
    {
       #ifdef DEBUG
          if ((buf1 && !buf2) || (!buf1 && buf2))
-            Debug_msg("Doppleganger_Run -- PUBLIC ARPing... [delay = %d]", Options.delay);
+            DEBUG_MSG("Doppleganger_Run -- PUBLIC ARPing... [delay = %d]", Options.delay);
          else
-            Debug_msg("Doppleganger_Run -- ARP POISONing... [delay = %d]", Options.delay);
+            DEBUG_MSG("Doppleganger_Run -- ARP POISONing... [delay = %d]", Options.delay);
       #endif
 
-      if (buf1)
-      {
-          Inet_Forge_ethernet( buf1, MyMAC, PoorMAC2, ETH_P_ARP );
-          Inet_Forge_arp( buf1+ETH_HEADER, (replies%2) ? ARPOP_REQUEST : ARPOP_REPLY,
-                          MyMAC, inet_addr(PoorIP1),
-                          PoorMAC2, inet_addr(PoorIP2) );
-      }
-
-      if (buf2)
-      {
-          Inet_Forge_ethernet( buf2, MyMAC, PoorMAC1, ETH_P_ARP );
-          Inet_Forge_arp( buf2+ETH_HEADER, (replies%2) ? ARPOP_REQUEST : ARPOP_REPLY,
-                          MyMAC, inet_addr(PoorIP2),
-                          PoorMAC1, inet_addr(PoorIP1) );
-      }
-
       exit_func(Doppleganger_reARP);
-
+      
       loop
       {
+         if (buf1)
+         {
+             Inet_Forge_ethernet( buf1, MyMAC, PoorMAC2, ETH_P_ARP );
+             Inet_Forge_arp( buf1+ETH_HEADER, (replies%2) ? ARPOP_REQUEST : ARPOP_REPLY,
+                             MyMAC, inet_addr(PoorIP1),
+                             PoorMAC2, inet_addr(PoorIP2) );
+         }
+
+         if (buf2)
+         {
+             Inet_Forge_ethernet( buf2, MyMAC, PoorMAC1, ETH_P_ARP );
+             Inet_Forge_arp( buf2+ETH_HEADER, (replies%2) ? ARPOP_REQUEST : ARPOP_REPLY,
+                             MyMAC, inet_addr(PoorIP2),
+                             PoorMAC1, inet_addr(PoorIP1) );
+         }
+
          pthread_testcancel();
 
          if (buf1) Inet_SendRawPacket(dopple_sock, buf1, ETH_HEADER + ARP_HEADER);
@@ -362,9 +358,7 @@ pthread_t Doppleganger_Run(char *iface, char *IP1, char *IP2, char *MAC1, char *
 {
    static dopple_param param;
 
-#ifdef DEBUG
-       Debug_msg("Doppleganger_Run -- [%s] [%s] [%s] [%s]", IP1, IP2, MAC1, MAC2);
-#endif
+   DEBUG_MSG("Doppleganger_Run -- [%s] [%s] [%s] [%s]", IP1, IP2, MAC1, MAC2);
 
    strlcpy(param.iface, iface, sizeof(param.iface));
    strlcpy(param.IP1, IP1, sizeof(param.IP1));
@@ -376,3 +370,6 @@ pthread_t Doppleganger_Run(char *iface, char *IP1, char *IP2, char *MAC1, char *
 }
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
