@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dryad.c,v 1.14 2002/02/10 10:07:49 alor Exp $
+    $Id: ec_dryad.c,v 1.24 2002/04/18 17:03:17 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -30,16 +30,18 @@
 #include "include/ec_inet_forge.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_buffer.h"
-#include "include/ec_error.h"
 #include "include/ec_dissector.h"
 #include "include/ec_thread.h"
 #include "include/ec_decodedata.h"
+#include "include/ec_plugins.h"
+#include "include/ec_pcapfile.h"
 
 // protos
 
 pthread_t Dryad_Run(void);
 void * Dryad_Main(void *);
 void Dryad_Get_Banner(PASSIVE_DATA *, CONNECTION *, u_char, u_char *, int);
+u_char TTL_PREDICTOR(unsigned char x);
 
 //----------------------------------------
 
@@ -47,9 +49,7 @@ void Dryad_Get_Banner(PASSIVE_DATA *, CONNECTION *, u_char, u_char *, int);
 pthread_t Dryad_Run(void)
 {
 
-#ifdef DEBUG
-   Debug_msg("Dryad_Run");
-#endif
+   DEBUG_MSG("Dryad_Run");
 
    return ECThread_create("dryad", &Dryad_Main, NULL);
 
@@ -73,16 +73,15 @@ void * Dryad_Main(void *dummy)
    PASSIVE_DATA data_to_ettercap;
    CONNECTION state_machine_data;
 
-#ifdef DEBUG
-   Debug_msg("Dryad_Main");
-#endif
+   DEBUG_MSG("Dryad_Main");
 
    sock = Inet_OpenRawSock(Options.netiface);
    Inet_GetIfaceInfo(Options.netiface, &MTU, NULL, &MyIP, &NetMask);
 
    MyIP = MyIP & NetMask;  // prepare it for later comparison...
 
-   if (number_of_connections == -1) Inet_SetPromisc(Options.netiface);  // promisc mode only from interface 1
+   if (number_of_connections == -1 && (!Options.dumpfile || Options.writedump))
+   	Inet_SetPromisc(Options.netiface);  // promisc mode only from interface 1
 
    buf = Inet_Forge_packet( MTU );
 
@@ -90,14 +89,18 @@ void * Dryad_Main(void *dummy)
 
    loop
    {
-      short len=0;
+      int len = 0;
       char goodpkt = 0;
 
       pthread_testcancel();
 
       memset(buf, 0, MTU);
 
-      len = Inet_GetRawPacket(sock, buf, MTU, NULL);
+      if (!Options.writedump && Options.dumpfile) {
+         len = Pcapfile_Read(buf, MTU);
+      } else {
+         len = Inet_GetRawPacket(sock, buf, MTU, NULL);
+      }
 
       if (len > 0)
       {
@@ -146,12 +149,14 @@ void * Dryad_Main(void *dummy)
             if ((ip->source_ip & NetMask) != MyIP)    // Non Local IP
                sprintf(data_to_ettercap.type, "NL");
 
-            #define UPPER_LIMIT(x,y) ((x<y) ? x : y)
-            TTL = UPPER_LIMIT(255, pow(2, ceil(log(ip->ttl)/log(2))));   // round the TTL to the nearest power of 2 (ceiling)
+//            #define UPPER_LIMIT(x,y) ((x<y) ? x : y)
+//            TTL = UPPER_LIMIT(255, pow(2, ceil(log(ip->ttl)/log(2))));   // round the TTL to the nearest power of 2 (ceiling)
+//            #undef UPPER_LIMIT
+            TTL = TTL_PREDICTOR(ip->ttl);	// round the TTL to the nearest power of 2 (ceiling)
             data_to_ettercap.hop = TTL - ip->ttl + 1;
             if (ip->source_ip == inet_addr(Host_In_LAN[0].ip))    // Our IP is at distance ZERO !
                data_to_ettercap.hop = 0;
-            #undef UPPER_LIMIT
+
 
             goodpkt = 1;
 
@@ -179,7 +184,7 @@ void * Dryad_Main(void *dummy)
                udp = (UDP_header *) ((int)ip + ip->h_len * 4);
 
                if (ntohs(udp->source) >= 1024) continue;       // skip unusual port, because ports used
-                                                               // from client side can be midetected as open
+                                                               // from client side can be misdetected as open
 
                data_to_ettercap.port = ntohs(udp->source);     // STORE THE UDP OPEN PORT
                data_to_ettercap.proto = 'U';
@@ -264,7 +269,7 @@ void * Dryad_Main(void *dummy)
                   if (tcp->flags & TH_ACK)
                   {
 
-// TODO: dont show FPT passive port as opened
+// TODO: dont show FTP passive port as opened
 
                      if (ntohs(tcp->dest) != 20)   // skip ports opened by ftp channel
                         data_to_ettercap.port = ntohs(tcp->source);     // STORE THE TCP OPEN PORT
@@ -290,6 +295,23 @@ void * Dryad_Main(void *dummy)
 }
 
 
+u_char TTL_PREDICTOR(u_char x)		// coded by awgn <awgn@antifork.org>
+{												// round the TTL to the nearest power of 2 (ceiling)
+   register u_char i = x;
+   register u_char j = 1;
+   register u_char c = 0;
+   
+   do {
+   	c += i & 1;
+      j <<= 1;
+  	} while ( i >>= 1 );
+   
+   if ( c == 1 )
+   	return x;
+   else
+   	return ( j ? j : 0xff );
+}
+
 
 void Dryad_Get_Banner(PASSIVE_DATA *data_to_ettercap, CONNECTION *state_machine_data, u_char flags, u_char *data, int datalen)
 {
@@ -374,3 +396,6 @@ void Dryad_Get_Banner(PASSIVE_DATA *data_to_ettercap, CONNECTION *state_machine_
 }
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
