@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_error.c,v 1.6 2001/12/08 11:22:20 alor Exp $
+    $Id: ec_error.c,v 1.7 2002/03/08 08:49:55 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -46,12 +46,10 @@ void Error_msg(char *message, ...)
    vsnprintf(errmsg, 200, message, ap);
    va_end(ap);
 
-#ifdef DEBUG
-   Debug_msg("Error_msg -- %s", errmsg);
-#endif
+   DEBUG_MSG("Error_msg -- %s", errmsg);
 
 #ifdef HAVE_NCURSES
-   if (!Options.normal)
+   if (Options.onscreen)
       Interface_WExit(errmsg);
 #endif
 
@@ -67,12 +65,10 @@ void Error_critical_msg(char *file, char *function, int line, char *message)
    snprintf(err, 200, "[%s:%s:%d] %s | ERRNO %d | %s", file, function, line, message, errno, strerror(errno));
    err[200] = 0;
 
-#ifdef DEBUG
-      Debug_msg("Error_msg -- %s",  err);
-#endif
+   DEBUG_MSG("Error_msg -- %s",  err);
 
 #ifdef HAVE_NCURSES
-   if (!Options.normal)
+   if (Options.onscreen)
       Interface_WExit(err);
 #endif
 
@@ -82,3 +78,6 @@ void Error_critical_msg(char *file, char *function, int line, char *message)
 
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
