@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_fingerprint.c,v 1.8 2002/02/10 10:07:49 alor Exp $
+    $Id: ec_fingerprint.c,v 1.9 2002/03/08 08:49:55 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -28,7 +28,6 @@
 #include "include/ec_inet.h"
 #include "include/ec_inet_forge.h"
 #include "include/ec_decodedata.h"
-#include "include/ec_error.h"
 
 #ifdef HAVE_SYS_UTSNAME_H
    #include <sys/utsname.h>
@@ -386,9 +385,7 @@ char * Fingerprint_OS(char *IP)
 {
    char *res_name;
 
-#ifdef DEBUG
-   Debug_msg("Fingerprint_OS -- [%s]", IP);
-#endif
+   DEBUG_MSG("Fingerprint_OS -- [%s]", IP);
 
    if (!strcmp(IP, Inet_MyIPAddress()))
    {
@@ -442,9 +439,7 @@ char * Fingerprint_MAC(char *MAC)
    char line[1024];
    mac_database *mac_index;
 
-#ifdef DEBUG
-   Debug_msg("Fingerprint_MAC -- [%s]", MAC);
-#endif
+   DEBUG_MSG("Fingerprint_MAC -- [%s]", MAC);
 
    if (!strcmp(MAC, "")) return "unknown";
 
@@ -496,3 +491,6 @@ char * Fingerprint_MAC(char *MAC)
 
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
