@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_grell.c,v 1.10 2001/12/12 13:22:58 alor Exp $
+    $Id: ec_grell.c,v 1.13 2002/04/12 20:05:28 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -27,12 +27,12 @@
 #include <fcntl.h>
 
 #include <openssl/ssl.h>
+#include <sys/poll.h>
 
 #include "include/ec_inet_structures.h"
 #include "include/ec_inet_forge.h"
 #include "include/ec_dissector.h"
 #include "include/ec_buffer.h"
-#include "include/ec_error.h"
 #include "include/ec_decodedata.h"
 #include "include/ec_thread.h"
 
@@ -296,19 +296,25 @@ static int server_init(char *buf, size_t size, public_data *son_data)
 
    if (type_connect)
    {
-      fd_set fds;
+      //fd_set fds;
+      struct pollfd poll_fd[2];
 
       server_write(buf,offset, son_data);  // Skip readable messages
 
       loop
       {
-         FD_ZERO(&fds);
-         FD_SET(son_data->client_fd, &fds);
-         FD_SET(son_data->server_fd, &fds);
+         //FD_ZERO(&fds);
+         //FD_SET(son_data->client_fd, &fds);
+         //FD_SET(son_data->server_fd, &fds);
+         poll_fd[0].fd = son_data->client_fd;
+         poll_fd[1].fd = son_data->server_fd;
+         poll_fd[0].events = poll_fd[1].events = POLLIN;
 
-         select(FOPEN_MAX, &fds, 0, 0, 0);
+         //select(FOPEN_MAX, &fds, 0, 0, 0);
+         poll(poll_fd,2,-1);
 
-         if (FD_ISSET(son_data->client_fd, &fds))
+         //if (FD_ISSET(son_data->client_fd, &fds))
+         if (poll_fd[0].revents & POLLIN)
          {
             if ((j = client_read(buf, MAX_DATA, son_data)) <= 0)
             {
@@ -324,7 +330,8 @@ static int server_init(char *buf, size_t size, public_data *son_data)
                return -1;    // if it can't handle proxy auth...
             }
          }
-         else if (FD_ISSET(son_data->server_fd, &fds))
+         else //if (FD_ISSET(son_data->server_fd, &fds))
+         if (poll_fd[1].revents & POLLIN)
          {
             char *found;
             if ((j = server_read(buf, MAX_DATA, son_data)) <= 0)
@@ -396,9 +403,7 @@ void Grell_fini(void *dummy)
    close(proxy_fd);
    close(https_fd);
 
-#ifdef DEBUG
-   Debug_msg("Grell_fini -- grell closed gracefully...");
-#endif
+   DEBUG_MSG("Grell_fini -- grell closed gracefully...");
 }
 
 
@@ -410,6 +415,7 @@ void Grell_init(void)
    proxy_fd = socket(AF_INET, SOCK_STREAM, 0);
    https_fd = socket(AF_INET, SOCK_STREAM, 0);
 
+
    setsockopt(proxy_fd, SOL_SOCKET, SO_REUSEADDR, &i, sizeof(i));
    setsockopt(https_fd, SOL_SOCKET, SO_REUSEADDR, &i, sizeof(i));
 
@@ -425,12 +431,10 @@ void Grell_init(void)
    sa_in.sin_port = htons(HTTPS_Local_Port);
 
    if (bind(https_fd, (struct sockaddr *)&sa_in, sizeof(sa_in)) < 0)
-       Error_msg("Can't bind port %d (required for HTTPS dissection)\n", HTTPS_Local_Port);
+      Error_msg("Can't bind port %d (required for HTTPS dissection)\n", HTTPS_Local_Port);
 
-#ifdef DEBUG
-   Debug_msg("Grell_init -- Listening for Proxy redirect on port %d", Proxy_Local_Port);
-   Debug_msg("Grell_init -- Listening for HTTPS redirect on port %d", HTTPS_Local_Port);
-#endif
+   DEBUG_MSG("Grell_init -- Listening for Proxy redirect on port %d", Proxy_Local_Port);
+   DEBUG_MSG("Grell_init -- Listening for HTTPS redirect on port %d", HTTPS_Local_Port);
 
    listen(proxy_fd, 50);
    listen(https_fd, 50);
@@ -441,18 +445,16 @@ void Grell_init(void)
 
    if (SSL_CTX_use_certificate_file(father_data.ssl_ctx_client, CERT_FILE, SSL_FILETYPE_PEM) == 0)
    {
-      #ifdef DEBUG
-         Debug_msg("Grell_init -- SSL_CTX_use_certificate_file -- %s", DATA_PATH "/" CERT_FILE);
-      #endif
+      DEBUG_MSG("Grell_init -- SSL_CTX_use_certificate_file -- %s", DATA_PATH "/" CERT_FILE);
+
       if (SSL_CTX_use_certificate_file(father_data.ssl_ctx_client, DATA_PATH "/" CERT_FILE, SSL_FILETYPE_PEM) == 0)
          Error_msg("Can't open \"%s\" file !!", CERT_FILE);
    }
 
    if (SSL_CTX_use_PrivateKey_file(father_data.ssl_ctx_client, CERT_FILE, SSL_FILETYPE_PEM) == 0)
    {
-      #ifdef DEBUG
-         Debug_msg("Grell_init -- SSL_CTX_use_PrivateKey_file -- %s", DATA_PATH "/" CERT_FILE);
-      #endif
+      DEBUG_MSG("Grell_init -- SSL_CTX_use_PrivateKey_file -- %s", DATA_PATH "/" CERT_FILE);
+
       if (SSL_CTX_use_PrivateKey_file(father_data.ssl_ctx_client, DATA_PATH "/" CERT_FILE, SSL_FILETYPE_PEM) == 0)
          Error_msg("Can't open \"%s\" file !!", CERT_FILE);
    }
@@ -465,13 +467,13 @@ void Grell_init(void)
 void * Grell_spawn(void *local_father_data)
 {
    u_char buf[MAX_DATA*5];
-   fd_set fds;
+   //fd_set fds;
+   struct pollfd poll_fd[2];
+
    int i;
    public_data son_data;
 
-#ifdef DEBUG
-   Debug_msg("Grell_spawn -- new connection accepted");
-#endif
+   DEBUG_MSG("Grell_spawn -- new connection accepted");
 
    memcpy(&son_data, local_father_data, sizeof(public_data));
 
@@ -487,13 +489,20 @@ void * Grell_spawn(void *local_father_data)
 
    loop
    {
-      FD_ZERO(&fds);
-      FD_SET(son_data.client_fd, &fds);
-      FD_SET(son_data.server_fd, &fds);
+      //FD_ZERO(&fds);
+      //FD_SET(son_data.client_fd, &fds);
+      //FD_SET(son_data.server_fd, &fds);
 
-      select(FOPEN_MAX, &fds, 0, 0, 0);
 
-      if (FD_ISSET(son_data.client_fd, &fds))
+      poll_fd[0].fd = son_data.client_fd;
+      poll_fd[1].fd = son_data.server_fd;
+      poll_fd[0].events = poll_fd[1].events = POLLIN;
+
+      //select(FOPEN_MAX, &fds, 0, 0, 0);
+      poll(poll_fd,2,-1);
+
+      //if (FD_ISSET(son_data.client_fd, &fds))
+      if (poll_fd[0].revents & POLLIN)
       {
          i = sizeof(buf);
          if ((i = client_read(buf, i-2, &son_data)) <= 0) break;
@@ -501,7 +510,8 @@ void * Grell_spawn(void *local_father_data)
          if (server_write(buf, i, &son_data) != i)   break;
          client_parse(buf, i, &son_data);
       }
-      else if (FD_ISSET(son_data.server_fd, &fds))
+      else //if (FD_ISSET(son_data.server_fd, &fds))
+      if (poll_fd[1].revents & POLLIN)
       {
          i = sizeof(buf);
          if ((i = server_read(buf, i-2, &son_data)) <= 0) break;
@@ -521,7 +531,9 @@ void * Grell_spawn(void *local_father_data)
 
 void * Grell_start(void *none)
 {
-   fd_set fds;
+   //fd_set fds;
+   struct pollfd poll_fd[2];
+
    int dummy;
 
    Grell_init();
@@ -533,26 +545,30 @@ void * Grell_start(void *none)
 
    loop
    {
-      FD_ZERO(&fds);
+      //FD_ZERO(&fds);
+      //FD_SET(proxy_fd, &fds);
+      //FD_SET(https_fd, &fds);
+
+      poll_fd[0].fd = proxy_fd;
+      poll_fd[1].fd = https_fd;
+      poll_fd[0].events = poll_fd[1].events = POLLIN;
 
-      FD_SET(proxy_fd, &fds);
-      FD_SET(https_fd, &fds);
 
       pthread_testcancel();
 
-      select(FOPEN_MAX, &fds, 0, 0, (struct timeval *)0);
+      //select(FOPEN_MAX, &fds, 0, 0, (struct timeval *)0);
+      poll(poll_fd,2,-1);
 
       pthread_testcancel();
 
       dummy = sizeof(struct sockaddr);
 
-      if (FD_ISSET(proxy_fd, &fds))
+      //if (FD_ISSET(proxy_fd, &fds))
+      if (poll_fd[0].revents & POLLIN)
       {
          u_long peer;
 
-         #ifdef DEBUG
-            Debug_msg("Grell_start -- got a connection on proxy_fd");
-         #endif
+         DEBUG_MSG("Grell_start -- got a connection on proxy_fd");
 
          pthread_mutex_lock(&father_mutex);
 
@@ -564,13 +580,12 @@ void * Grell_start(void *none)
          peer |= inet_addr(Host_In_LAN[0].ip) & htonl(0xFF000000);
          memcpy(&father_data.client_sin.sin_addr, &peer, sizeof(u_long));
       }
-      else if (FD_ISSET(https_fd, &fds))
+      else //if (FD_ISSET(https_fd, &fds))
+      if (poll_fd[1].revents & POLLIN)
       {
          u_long peer;
 
-         #ifdef DEBUG
-            Debug_msg("Grell_start -- got a connection on https_fd");
-         #endif
+         DEBUG_MSG("Grell_start -- got a connection on https_fd");
 
          pthread_mutex_lock(&father_mutex);
 
@@ -601,17 +616,14 @@ pthread_t Grell_Run(void)
       {
          if (ds->active == 0)
          {
-            #ifdef DEBUG
-               Debug_msg("Grell was disabled by conf.file");
-            #endif
+            DEBUG_MSG("Grell was disabled by conf.file");
+
             return 0;
          }
       }
    }
 
-#ifdef DEBUG
-   Debug_msg("Grell Starts");
-#endif
+   DEBUG_MSG("Grell Starts");
 
    return ECThread_create("grell", &Grell_start, NULL);
 }
@@ -619,3 +631,6 @@ pthread_t Grell_Run(void)
 #endif //HAVE_OPENSSL
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
