@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_illithid.c,v 1.17 2002/02/11 00:58:17 alor Exp $
+    $Id: ec_illithid.c,v 1.26 2002/04/11 22:48:25 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -29,13 +29,13 @@
 #include "include/ec_inet_forge.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_buffer.h"
-#include "include/ec_error.h"
 #include "include/ec_dissector.h"
 #include "include/ec_filterdrop.h"
 #include "include/ec_parser.h"
 #include "include/ec_thread.h"
 #include "include/ec_decodedata.h"
 #include "include/ec_plugins.h"
+#include "include/ec_pcapfile.h"
 
 #define HASHES 256
 #define PCK_STOD 1
@@ -114,6 +114,9 @@ void * Illithid_Decoder(void *dummy)      // decoder thread
 {
    CONNECTION data_to_ettercap;
    Buffer_Flush(illithid_buffer);
+
+   DEBUG_MSG("Illithid_Decoder -- running");
+
    loop
    {
       pthread_testcancel();
@@ -122,7 +125,15 @@ void * Illithid_Decoder(void *dummy)      // decoder thread
          Decodedata_MakeConnectionList(&data_to_ettercap);
       else
       {
+#ifdef CYGWIN
+         /* the CYGWIN pthread_cond_wait / pthread_cond_signal
+          * seems to be broken... for now only a workaround.
+          * XXX - fix this ugly behaviour
+          */
+         usleep(1000);
+#else
          pthread_cond_wait(&decoder_cond, &decoder_mtx);
+#endif
       }
    }
 }
@@ -139,9 +150,7 @@ pthread_t Illithid_ARPBased_GetConnections(char *iface, char *IP1p, char *IP2p,
 {
    static illithid_param param;
 
-#ifdef DEBUG
-   Debug_msg("Illithid_ARPBased_GetConnections -- [%s] [%s] [%s] [%s]", IP1p, IP2p, MAC1p, MAC2p);
-#endif
+   DEBUG_MSG("Illithid_ARPBased_GetConnections -- [%s] [%s] [%s] [%s]", IP1p, IP2p, MAC1p, MAC2p);
 
    param.mode = ARPBASED;
    strlcpy(param.iface, iface, sizeof(param.iface));
@@ -157,9 +166,7 @@ pthread_t Illithid_PublicARP_GetConnections(char *iface, char *IP1p, char *IP2p,
 {
    static illithid_param param;
 
-#ifdef DEBUG
-   Debug_msg("Illithid_PublicARP_GetConnections -- [%s] [%s] [%s] [%s]", IP1p, IP2p, MAC1p, MAC2p);
-#endif
+   DEBUG_MSG("Illithid_PublicARP_GetConnections -- [%s] [%s] [%s] [%s]", IP1p, IP2p, MAC1p, MAC2p);
 
    param.mode = PUBLICARP;
    strlcpy(param.iface, iface, sizeof(param.iface));
@@ -177,9 +184,7 @@ pthread_t Illithid_IPBased_GetConnections(char *iface, char *IP1p, char *IP2p)
 {
    static illithid_param param;
 
-#ifdef DEBUG
-   Debug_msg("Illithid_IPBased_GetConnections -- [%s] [%s]", IP1p, IP2p);
-#endif
+   DEBUG_MSG("Illithid_IPBased_GetConnections -- [%s] [%s]", IP1p, IP2p);
 
    param.mode = IPBASED;
    strlcpy(param.iface, iface, sizeof(param.iface));
@@ -197,9 +202,7 @@ pthread_t Illithid_MACBased_GetConnections(char *iface, char *MAC1p, char *MAC2p
 {
    static illithid_param param;
 
-#ifdef DEBUG
-   Debug_msg("Illithid_MACBased_GetConnections -- [%s] [%s]", MAC1p, MAC2p);
-#endif
+   DEBUG_MSG("Illithid_MACBased_GetConnections -- [%s] [%s]", MAC1p, MAC2p);
 
    param.mode = MACBASED;
    strlcpy(param.iface, iface, sizeof(param.iface));
@@ -262,9 +265,10 @@ void * Illithid_GetConnections(void *param)
    if (((illithid_param *)param)->mode == ARPBASED && ( IP1 == 0 || IP2 == 0 ) )
        forward_mode = PUBLICARP;
 
-   if (((illithid_param *)param)->mode > PUBLICARP)
-      Inet_SetPromisc(((illithid_param *)param)->iface);
-   else
+   if (((illithid_param *)param)->mode > PUBLICARP) {
+      if (!Options.dumpfile || Options.writedump)
+      	Inet_SetPromisc(((illithid_param *)param)->iface);
+   } else
       IP_Test=MyIP&NetMask;
 
    buffer = Inet_Forge_packet(MTU*2);
@@ -276,7 +280,14 @@ void * Illithid_GetConnections(void *param)
       delta = 0;
       memset(buffer, 0, MTU);    // REQUIRED BY DISSECTORS !!!
 
-      len = Inet_GetRawPacket(sock, buffer, MTU, &pkttype);
+      if (!Options.writedump && Options.dumpfile) {
+         len = Pcapfile_Read(buffer, MTU);
+      } else {
+         len = Inet_GetRawPacket(sock, buffer, MTU, &pkttype);
+      }
+
+		if (Options.writedump && len > 0)
+			Pcapfile_Write(buffer, len);
 
 #ifdef PERMIT_PLUGINS
       if (len > 0) {
@@ -423,7 +434,7 @@ void * Illithid_GetConnections(void *param)
 
                   if (tcp_datalen < 0 || ntohs(ip->t_len) > len) goto send;
 
-						tcp_datalen = (tcp_datalen > MAX_DATA) ? MAX_DATA : tcp_datalen;  // don't accept bogus sized packets
+                  tcp_datalen = (tcp_datalen > MAX_DATA) ? MAX_DATA : tcp_datalen;  // don't accept bogus sized packets
 
                   data_to_ettercap.source_port = ntohs(tcp->source);
                   data_to_ettercap.dest_port = ntohs(tcp->dest);
@@ -484,7 +495,7 @@ void * Illithid_GetConnections(void *param)
 
                   if (udp_datalen < 0 || udp_datalen > len) goto send;
 
-						udp_datalen = (udp_datalen > MAX_DATA) ? MAX_DATA : udp_datalen;   // don't accept bogus sized packets
+                  udp_datalen = (udp_datalen > MAX_DATA) ? MAX_DATA : udp_datalen;   // don't accept bogus sized packets
 
                   data_to_ettercap.source_port = ntohs(udp->source);
                   data_to_ettercap.dest_port = ntohs(udp->dest);
@@ -666,9 +677,7 @@ nosend:     while(0);      // dirty trick to avoid warning....
             Ielem **saved_session;
             Ielem session;
 
-            #ifdef DEBUG
-               Debug_msg("Illithid_GetConnections -- KILL A CONNECTION");
-            #endif
+            DEBUG_MSG("Illithid_GetConnections -- KILL A CONNECTION");
 
             saved_session = Illithid_Find_Session(to_kill.source_ip, to_kill.dest_ip, to_kill.source_port, to_kill.dest_port, IPPROTO_TCP, &session);
 
@@ -722,9 +731,7 @@ nosend:     while(0);      // dirty trick to avoid warning....
             Ielem **saved_session = NULL;
             Ielem session;
 
-            #ifdef DEBUG
-               Debug_msg("Illithid_GetConnections -- INJECT");
-            #endif
+            DEBUG_MSG("Illithid_GetConnections -- INJECT");
 
             if (inj.proto == 'T')
             {
@@ -782,7 +789,8 @@ int Illithid_ToBeSniffed(SNIFFED_DATA *data)
 {
    char s=0, ps=0, d=0, pd=0;
 
-   if (current_illithid_data.proto != data->proto) return 0;
+   if (current_illithid_data.proto != 'A')
+      if (current_illithid_data.proto != data->proto) return 0;
 
    if (current_illithid_data.source_port == 0) ps = 1;
    if (current_illithid_data.dest_port == 0) pd = 1;
@@ -918,9 +926,7 @@ Ielem **Illithid_Find_Session(unsigned int IP1, unsigned int IP2, unsigned short
          hash_table[hash] = new_elem;
          to_find = &(hash_table[hash]);
 
-         #ifdef DEBUG
-            Debug_msg("Illithid_Find_Session -- CREATE NEW SESSION");
-         #endif
+         DEBUG_MSG("Illithid_Find_Session -- CREATE NEW SESSION");
       }
    }
    return (to_find);
@@ -939,9 +945,7 @@ void Illithid_Set_Session(Ielem **session, Ielem *outs, short mode)
       {
          Ielem *temp;
 
-         #ifdef DEBUG
-            Debug_msg("Illithid_Set_Session -- DELETE AN OLD SESSION");
-         #endif
+         DEBUG_MSG("Illithid_Set_Session -- DELETE AN OLD SESSION");
 
          temp = (Ielem *)((*session)->next);
          free(*session);
@@ -991,9 +995,7 @@ void Illithid_Reset_Conn(void *dummy)
    Ielem *session, *next;
    char *buf1, *buf2, *pck_to_send;
 
-#ifdef DEBUG
-   Debug_msg("Illithid_Reset_Conn");
-#endif
+   DEBUG_MSG("Illithid_Reset_Conn");
 
    for (j=0; j<HASHES; j++)
    {
@@ -1050,12 +1052,13 @@ void Illithid_Reset_Conn(void *dummy)
 
    Buffer_Flush(illithid_buffer);
 
-#ifdef DEBUG
-   Debug_msg("Illithid -- ShutDowned gracefully...");
-#endif
+   DEBUG_MSG("Illithid -- ShutDowned gracefully...");
 
 }
 
 
 /* EOF */
 
+
+// vim:ts=3:expandtab
+
