@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_inet.c,v 1.17 2002/02/10 10:07:49 alor Exp $
+    $Id: ec_inet.c,v 1.29 2002/04/11 20:16:36 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -28,39 +28,30 @@
 #include <sys/wait.h>
 #ifdef CYGWIN
    #undef _SYS_TIME_H_
+
+	#include <windowsx.h>
+	#include <ws2tcpip.h>
+	#include <Iphlpapi.h>
 #endif
 
-#include <sys/ioctl.h>
 #include <fcntl.h>
 #include <signal.h>
 
-
 #ifndef WAIT_ANY
    #define WAIT_ANY       (-1)    /* Any process.  */
 #endif
 
-#include "include/ec_error.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_inet_forge.h"
 #include "include/ec_buffer.h"
-#include "include/ec_thread.h"
 #include "include/ec_parser.h"
 
-static char ETH_BROADCAST[6] = {0xFF,0xFF,0xFF,0xFF,0xFF,0xFF};
-static char ARP_BROADCAST[6] = {0x0,0x0,0x0,0x0,0x0,0x0};
-
 typedef struct {
    u_long IP_Add;
    u_char MAC_Add[6];
    struct host_list *next;
 } host_list;
 
-#ifdef LINUX
-   struct ifreq old_ifr;      // old iface flags
-   char IpForward_status;     // old ipforward status
-#else
-   int IpForward_status;      // old ipforward status
-#endif
 
 #ifdef CYGWIN
 typedef struct sh {
@@ -71,6 +62,9 @@ typedef struct sh {
 typedef int socket_handle;
 #endif
 
+static char ETH_BROADCAST[6] = {0xFF,0xFF,0xFF,0xFF,0xFF,0xFF};
+static char ARP_BROADCAST[6] = {0x0,0x0,0x0,0x0,0x0,0x0};
+
 // protos...
 
 char * Inet_HostName(char *ip);
@@ -96,8 +90,9 @@ int Inet_CloseSocket(socket_handle sh);
 int Inet_Http_Send(socket_handle sh, char *payload);
 int Inet_Http_Receive(socket_handle sh, char *payload, size_t size);
 
+// the following are architecture dependent...
+// the are found in ./src/OS/'uname'/ec_inet_'uname'.c
 
-// Following are architecture dependent !! implementations are in ./src/`uname`/ec_inet_`uname`.c
 int Inet_FindIFace(char *iface);
 int Inet_CorrectIface(char *iface);
 int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, u_long *IP, u_long *NetMask);
@@ -116,47 +111,41 @@ char *Inet_MacFromIP(unsigned long ip);
    void Inet_UnsetRoute(void);
    void Inet_SetRoute(void);
 #endif
-// ----------------------------------------
-
-// Architecture dependent implemetation of Inet functions...
-
-#ifdef LINUX
-   #include "OS/linux/ec_inet_linux.c"
-#endif
-#if defined (FREEBSD) || defined (OPENBSD) || defined (NETBSD)
-   #include "OS/BSD/ec_inet_BSD.c"
-#endif
-#ifdef MACOSX
-   #include "OS/MacOsX/ec_inet_macosx.c"
-#endif
-#ifdef SOLARIS
-   #include "OS/solaris/ec_inet_solaris.c"
-#endif
-#ifdef CYGWIN
-   #include "OS/windows/ec_inet_cygwin.c"
-#endif
 
 // ----------------------------------------
 
-
 char * Inet_HostName(char *ip)   // returns hostname from ip
 {
    struct hostent *host;
    static struct in_addr addr;
+#ifdef CYGWIN
+   WSADATA wsdata;
+#endif
 
-   if (!Options.dontresolve)
-   {
+   if (!Options.dontresolve) {
+#ifdef CYGWIN
+   if ( WSAStartup(MAKEWORD(2, 2), &wsdata) != 0)
+      ERROR_MSG("Cannot inizialize winsock WSAStartup()");
+#endif
       addr.s_addr = inet_addr(ip);
       host = gethostbyaddr((char *)&addr, sizeof(struct in_addr), AF_INET);
       #ifdef DEBUG
-         if (host != NULL) Debug_msg("Inet_HostName -- [%s] [%s]", ip, (char *) host->h_name);
-         else Debug_msg("Inet_HostName -- [%s] [NOT resolved...]", ip);
+         if (host != NULL) DEBUG_MSG("Inet_HostName -- [%s] [%s]", ip, (char *) host->h_name);
+         else DEBUG_MSG("Inet_HostName -- [%s] [NOT resolved...]", ip);
       #endif
-      if (host != NULL) return (char *) host->h_name;
-   }
-   else
+      if (host != NULL) {
+#ifdef CYGWIN
+         WSACleanup();
+#endif
+          return (char *) host->h_name;
+      }
+   } else
       return "not resolved (-d option)";
 
+#ifdef CYGWIN
+   WSACleanup();
+#endif
+
    return "Unknown host";
 }
 
@@ -166,6 +155,12 @@ char * Inet_NameToIp(char *name) // returns ip from hostname
    struct hostent *host;
    struct in_addr addr;
    static char ip[16];
+#ifdef CYGWIN
+   WSADATA wsdata;
+
+   if ( WSAStartup(MAKEWORD(2, 2), &wsdata) != 0)
+      ERROR_MSG("Cannot inizialize winsock WSAStartup()");
+#endif
 
    memset(ip, 0, sizeof(ip));
 
@@ -174,6 +169,9 @@ char * Inet_NameToIp(char *name) // returns ip from hostname
 
       if (host != NULL) {
          strlcpy(ip, inet_ntoa( *(struct in_addr *) *host->h_addr_list), 16);
+#ifdef CYGWIN
+         WSACleanup();
+#endif
          return ip;
       }
       else
@@ -181,7 +179,9 @@ char * Inet_NameToIp(char *name) // returns ip from hostname
    }
 
    strlcpy(ip, inet_ntoa( addr ), 16);
-
+#ifdef CYGWIN
+   WSACleanup();
+#endif
    return ip;
 }
 
@@ -200,25 +200,19 @@ char * Inet_GetMyInfo(char tipo)
    {
          case 0:  // requesting IP
                   snprintf(IP, sizeof(IP), "%s", int_ntoa(IP_Add));
-                  #ifdef DEBUG
-                     Debug_msg("Inet_GetMyInfo IP -- [%s]", IP);
-                  #endif
+                  DEBUG_MSG("Inet_GetMyInfo IP -- [%s]", IP);
                   return IP;
                   break;
 
          case 1:  // requesting MAC
                   Inet_PutMACinString( MAC, MAC_Add );
-                  #ifdef DEBUG
-                     Debug_msg("Inet_GetMyInfo MAC -- [%s]", MAC);
-                  #endif
+                  DEBUG_MSG("Inet_GetMyInfo MAC -- [%s]", MAC);
                   return MAC;
                   break;
 
          case 2:  // requesting netmask
                   snprintf(MySubnet, sizeof(MySubnet), "%s", int_ntoa(NetMask));
-                  #ifdef DEBUG
-                     Debug_msg("Inet_GetMyInfo NetMask -- [%s]", MySubnet);
-                  #endif
+                  DEBUG_MSG("Inet_GetMyInfo NetMask -- [%s]", MySubnet);
                   return MySubnet;
                   break;
    }
@@ -258,9 +252,7 @@ int Inet_HostInLAN()
    if (Options.hostsfromfile)
        return Inet_Load_Host_List();
 
-#ifdef DEBUG
-   Debug_msg("Inet_HostInLAN\tIface: %s", Options.netiface);
-#endif
+   DEBUG_MSG("Inet_HostInLAN\tIface: %s", Options.netiface);
 
    list = Inet_Host_in_LAN_list(Options.netiface);
 
@@ -269,8 +261,8 @@ int Inet_HostInLAN()
    for( ; current; host_alive++)
       current = (host_list *)current->next;
 
-   if (!Options.dontresolve && !Host_In_LAN)
-      fprintf(stdout, "Resolving %d hostnames...\n", host_alive);
+   if (!Options.dontresolve && !Options.onscreen)
+      fprintf(stdout, "\nResolving %d hostnames...\n\n", host_alive);
 
    if (Host_In_LAN) free(Host_In_LAN);
    Host_In_LAN = (HOST *)calloc(host_alive,sizeof(HOST));
@@ -284,11 +276,16 @@ int Inet_HostInLAN()
       snprintf(Host_In_LAN[k].name, 128, "%s", Inet_HostName(Host_In_LAN[k].ip));
       Inet_PutMACinString(Host_In_LAN[k].mac, current->MAC_Add);
       k++;
+      if (!Options.dontresolve)
+      	Parser_StatusBar(number_of_hosts_in_lan);
    }
    Inet_Free_list(list);
-#ifdef DEBUG
-   Debug_msg("Inet_HostInLAN -- %d hosts in the lan", host_alive);
-#endif
+
+	if (!Options.dontresolve)
+		fprintf(stdout, "\n");
+
+   DEBUG_MSG("Inet_HostInLAN -- %d hosts in the lan", host_alive);
+
    return host_alive;
 }
 
@@ -310,9 +307,7 @@ char * Inet_Save_Host_List(void)
    snprintf(temp, 49, "%s", inet_ntoa(mask_addr));
    snprintf(hfile_name, 49, "%s_%s.ehl", inet_ntoa(ip_addr), temp);
 
-#ifdef DEBUG
-   Debug_msg("Inet_Save_Host_List saving file: %s", hfile_name);
-#endif
+   DEBUG_MSG("Inet_Save_Host_List saving file: %s", hfile_name);
 
    hfile = fopen(hfile_name, "w");
    if (hfile == NULL)
@@ -336,9 +331,7 @@ int Inet_Load_Host_List(void)
    u_long N_IP;
    int  host_alive,index;
 
-#ifdef DEBUG
-   Debug_msg("Inet_Load_Host_List from file: %s", Options.hostfile);
-#endif
+   DEBUG_MSG("Inet_Load_Host_List from file: %s", Options.hostfile);
 
    hfile = fopen(Options.hostfile,"r");
    if (hfile == NULL)
@@ -350,9 +343,7 @@ int Inet_Load_Host_List(void)
       fscanf(hfile,"%49s %49s %127s\n", C_IP, C_MAC, C_NAME);
    fseek(hfile, 0, SEEK_SET);
 
-#ifdef DEBUG
-   Debug_msg("Inet_Load_Host_List -- %d hosts in the lan", host_alive);
-#endif
+   DEBUG_MSG("Inet_Load_Host_List -- %d hosts in the lan", host_alive);
 
    if (Host_In_LAN) free(Host_In_LAN);
 
@@ -376,7 +367,7 @@ int Inet_Load_Host_List(void)
 
    fclose(hfile);
 
-   Options.hostsfromfile = 0;
+   //Options.hostsfromfile = 0;
 
    return host_alive;
 }
@@ -401,10 +392,9 @@ host_list *Inet_Host_in_LAN_list(char *iface)
    u_char *buf;
    TIME_DECLARE;
 
+   DEBUG_MSG("Inet_HostInLAN_list");
 
-#ifdef DEBUG
-   Debug_msg("Inet_HostInLAN_list");
-#endif
+	number_of_hosts_in_lan = 1; // at least there is our host ;)
 
    head = (host_list *)malloc(sizeof(host_list));
    if (head == NULL)
@@ -424,9 +414,7 @@ host_list *Inet_Host_in_LAN_list(char *iface)
 
    N_hosts = ntohl(~NetMask);
 
-#ifdef DEBUG
-   Debug_msg("Inet_HostInLAN_list -- netmask 0x%0x  hosts %d", htonl(NetMask), N_hosts);
-#endif
+   DEBUG_MSG("Inet_HostInLAN_list -- netmask 0x%0x  hosts %d", htonl(NetMask), N_hosts);
 
    if (Options.broadping)
    {
@@ -462,11 +450,119 @@ host_list *Inet_Host_in_LAN_list(char *iface)
       if (!Host_In_LAN && Options.storm_delay != DEFAULT_STORM_DELAY)
          fprintf(stdout, "Interval between arp request is %.5f sec...\n", Options.storm_delay/1.0e6);
 
-      if (!Host_In_LAN && host_to_be_scanned == 0)
-         fprintf(stdout, "Sending %d ARP request...\n", N_hosts);
+      if (!Host_In_LAN && host_to_be_scanned == 0) {
+         fprintf(stdout, "\nSending %d ARP request...\n\n", N_hosts);
+#ifdef CYGWIN
+         fprintf(stdout, "* This process is terribly SLOW under Windows...\n");
+         fprintf(stdout, "* It takes a second for each ARP request.\n*\n");
+         fprintf(stdout, "* You are encouraged to save the host list to a file with the -k option\n");
+         fprintf(stdout, "* and load it (with -j <filename>) in the future to skip this scan.\n\n\n");
+#endif
+      }
       else if (!Host_In_LAN && host_to_be_scanned > 0)
-         fprintf(stdout, "Sending %d ARP request...\n", host_to_be_scanned);
+         fprintf(stdout, "\nSending %d ARP request...\n\n", host_to_be_scanned);
 
+#ifdef CYGWIN
+      {
+         char mac[6];
+         ULONG   ulLen;
+         HRESULT hr;
+         IPAddr dest_ip;
+
+         if (Options.spoofIp)
+            IP_to_use = Options.spoofIp;
+         else
+            IP_to_use = head->IP_Add;
+
+         if (host_to_be_scanned > 0)   // only the hosts in the list
+         {
+            for (i=0; i<host_to_be_scanned; i++)
+            {
+               host_list **current;
+
+               dest_ip = inet_addr(Host_List[i]);
+
+               usleep(Options.storm_delay);
+
+               memset (mac, 0xff, sizeof(mac));
+               ulLen = 6;
+
+               hr = SendARP (dest_ip, IP_to_use, (ULONG *)mac, &ulLen);
+               Parser_StatusBar(host_to_be_scanned);
+
+               if (hr != 0) continue;
+
+					if (dest_ip == head->IP_Add) continue; // skip our host
+
+               if (memcmp(mac, ARP_BROADCAST, 6))
+               {
+                  current = &head;
+
+                  DEBUG_MSG("Inet_HostInLAN_list -- got a reply after %.5f seconds", TIME_ELAPSED );
+
+                  number_of_hosts_in_lan++;
+
+                  while(*current != NULL && memcmp(&((*current)->IP_Add), &dest_ip, 4))
+                     current = (host_list **)&((*current)->next);
+
+                  if (*current == NULL)
+                  {
+                     if ( (*current = (host_list *)malloc(sizeof(host_list))) == NULL)
+                        ERROR_MSG("malloc()");
+                     (*current)->next = NULL;
+                     memcpy((*current)->MAC_Add, mac, 6);
+                     memcpy((char *)&((*current)->IP_Add), &dest_ip, 4);
+                  }
+               }
+            }
+         }
+         else  // all host in the subnet
+         {
+            for (i=1; i<=N_hosts; i++)
+            {
+               int dest_ip;
+               host_list **current;
+               dest_ip = (head->IP_Add&NetMask)|htonl(i);
+
+               Parser_StatusBar(N_hosts);
+
+               // if dest is equal to me
+               if (dest_ip != head->IP_Add)
+               {
+                  usleep(Options.storm_delay);
+
+                  memset (mac, 0xff, sizeof(mac));
+                  ulLen = 6;
+
+                  hr = SendARP (dest_ip, IP_to_use, (ULONG *)mac, &ulLen);
+
+                  if (hr != 0) continue;
+
+                  if (memcmp(mac, ARP_BROADCAST, 6))
+                  {
+                     current = &head;
+
+                     DEBUG_MSG("Inet_HostInLAN_list -- got a reply after %.5f seconds", TIME_ELAPSED );
+
+                     number_of_hosts_in_lan++;
+
+                     while(*current != NULL && memcmp(&((*current)->IP_Add), &dest_ip, 4))
+                        current = (host_list **)&((*current)->next);
+
+                     if (*current == NULL)
+                     {
+                        if ( (*current = (host_list *)malloc(sizeof(host_list))) == NULL)
+                           ERROR_MSG("malloc()");
+                        (*current)->next = NULL;
+                        memcpy((*current)->MAC_Add, mac, 6);
+                        memcpy((char *)&((*current)->IP_Add), &dest_ip, 4);
+                     }
+                  }
+               }
+            }
+         }
+      }
+#else /* NOT CYGWIN */
 
       if (!fork())
       {
@@ -486,12 +582,16 @@ host_list *Inet_Host_in_LAN_list(char *iface)
             {
                int dest_ip;
                dest_ip = inet_addr(Host_List[i]);
+
+               if (dest_ip == head->IP_Add) continue; // skip our host
+
                Inet_Forge_arp( buf+ETH_HEADER, ARPOP_REQUEST,
                                   head->MAC_Add, IP_to_use,
                                   ARP_BROADCAST, dest_ip );
 
                usleep(Options.storm_delay);
                Inet_SendRawPacket(sock, buf, ETH_HEADER + ARP_HEADER);
+               Parser_StatusBar(host_to_be_scanned);
             }
          }
          else  // all host in the subnet
@@ -512,6 +612,8 @@ host_list *Inet_Host_in_LAN_list(char *iface)
                   usleep(Options.storm_delay);
                   Inet_SendRawPacket(sock, buf, ETH_HEADER + ARP_HEADER);
                }
+
+               Parser_StatusBar(N_hosts);
             }
          }
 
@@ -519,14 +621,16 @@ host_list *Inet_Host_in_LAN_list(char *iface)
          usleep(500000);   // 0.5 second to wait for slower replies (ettercap is syncronized on this process)
          exit(0);          // the forked process must exit after arp storm
       }
+
+#endif // ! CYGWIN
+
    }
 
-#ifdef DEBUG
-   Debug_msg("Inet_HostInLAN_list -- listening for replies...");
-#endif
+   DEBUG_MSG("Inet_HostInLAN_list -- listening for replies...");
+
+//   if (!Host_In_LAN)
+//      fprintf(stdout, "Listening for replies...\n");
 
-   if (!Host_In_LAN)
-      fprintf(stdout, "Listening for replies...\n");
 
    fcntl(sock, F_SETFL, O_NONBLOCK);
 
@@ -557,9 +661,9 @@ host_list *Inet_Host_in_LAN_list(char *iface)
                   if (HIP->proto != IPPROTO_ICMP) continue;
                   current = &head;
 
-                  #ifdef DEBUG
-                     Debug_msg("Inet_HostInLAN_list -- got a reply after %.5f seconds", TIME_ELAPSED );
-                  #endif
+                  DEBUG_MSG("Inet_HostInLAN_list -- got a reply after %.5f seconds", TIME_ELAPSED );
+
+                  number_of_hosts_in_lan++;
 
                   while(*current != NULL && memcmp(&((*current)->IP_Add),&HIP->source_ip,4))
                      current = (host_list **)&((*current)->next);
@@ -579,6 +683,7 @@ host_list *Inet_Host_in_LAN_list(char *iface)
    }
    else  // !broadping
    {
+#ifndef CYGWIN
 
          do
          {
@@ -599,9 +704,9 @@ host_list *Inet_Host_in_LAN_list(char *iface)
             {
                current = &head;
 
-               #ifdef DEBUG
-                  Debug_msg("Inet_HostInLAN_list -- got a reply after %.5f seconds", TIME_ELAPSED );
-               #endif
+               DEBUG_MSG("Inet_HostInLAN_list -- got a reply after %.5f seconds", TIME_ELAPSED );
+
+               number_of_hosts_in_lan++;
 
                while(*current != NULL && memcmp(&((*current)->IP_Add),arppkt->source_ip,4))
                   current = (host_list **)&((*current)->next);
@@ -617,11 +722,13 @@ host_list *Inet_Host_in_LAN_list(char *iface)
             }
          } while ( waitpid(WAIT_ANY, NULL, WNOHANG) == 0 );
 
+#endif
+
    }
 
-   #ifdef DEBUG
-      Debug_msg("Inet_HostInLAN_list -- waiting timed out after %.5f seconds", TIME_ELAPSED );
-   #endif
+#ifndef CYGWIN
+   DEBUG_MSG("Inet_HostInLAN_list -- waiting timed out after %.5f seconds", TIME_ELAPSED );
+#endif
 
    Inet_Forge_packet_destroy( buf );
    Inet_CloseRawSock(sock);
@@ -638,12 +745,12 @@ SniffingHost *Inet_NoSniff(void)
    u_char *buf;
    TIME_DECLARE;
 
-#ifdef DEBUG
-   Debug_msg("Inet_NoSniff");
-#endif
+   DEBUG_MSG("Inet_NoSniff");
+
+   //if (SniffTable) free(SniffTable);
 
    SniffTable = calloc(number_of_hosts_in_lan * 100, sizeof(SniffingHost));
-   memset(SniffTable, 0, sizeof(SniffingHost)*number_of_hosts_in_lan);
+   //memset(SniffTable, 0, sizeof(SniffingHost)*number_of_hosts_in_lan);
 
    sock = Inet_OpenRawSock(Options.netiface);
 
@@ -680,9 +787,7 @@ SniffingHost *Inet_NoSniff(void)
 
    Inet_Forge_packet_destroy( buf );
 
-#ifdef DEBUG
-   Debug_msg("Inet_NoSniff -- after ICMP storm");
-#endif
+   DEBUG_MSG("Inet_NoSniff -- after ICMP storm");
 
    buf = Inet_Forge_packet( MTU );
 
@@ -710,9 +815,7 @@ SniffingHost *Inet_NoSniff(void)
 
             if (HIP->proto != IPPROTO_ICMP) continue;
 
-#ifdef DEBUG
-   Debug_msg("Inet_NoSniff -- got a ICMP reply after %.5f seconds", TIME_ELAPSED );
-#endif
+            DEBUG_MSG("Inet_NoSniff -- got a ICMP reply after %.5f seconds", TIME_ELAPSED );
 
             for(i=0; i<number_of_hosts_in_lan; i++)
             {
@@ -723,25 +826,28 @@ SniffingHost *Inet_NoSniff(void)
                      for (j=0; j<number_of_hosts_in_lan; j++)
                         if (!memcmp(MACS, Host_In_LAN[j].mac, 17)) break;
 
-                     SniffTable[SniffTableIndex].Host_Index1=j;
-                     SniffTable[SniffTableIndex].Host_Index2=i;
-                     SniffTable[SniffTableIndex].mode=1;
-                     SniffTableIndex++;
-                     break;
+                        if (j<number_of_hosts_in_lan)
+                        {
+                         SniffTable[SniffTableIndex].Host_Index1=j;
+                         SniffTable[SniffTableIndex].Host_Index2=i;
+                         SniffTable[SniffTableIndex].mode=1;
+                         SniffTableIndex++;
+                     }
                   }
+                  break;
                }
             }
+
+            if ( SniffTableIndex >= number_of_hosts_in_lan*95) break;
          }
       }
    } while ( TIME_ELAPSED < 3 );
 
-#ifdef DEBUG
-   Debug_msg("Inet_NoSniff -- analyzing results" );
-#endif
+   DEBUG_MSG("Inet_NoSniff -- analyzing results" );
 
    // Search for strange ARP entries
-   for (i=0; i<number_of_hosts_in_lan-1; i++)
-      for(j=i+1; j<number_of_hosts_in_lan; j++)
+   for (i=0; i<number_of_hosts_in_lan-1 && SniffTableIndex < number_of_hosts_in_lan*95; i++)
+      for(j=i+1; j<number_of_hosts_in_lan && SniffTableIndex < number_of_hosts_in_lan*95; j++)
          if (!memcmp(Host_In_LAN[i].mac, Host_In_LAN[j].mac, 17))
          {
             SniffTable[SniffTableIndex].Host_Index1=i;
@@ -750,9 +856,7 @@ SniffingHost *Inet_NoSniff(void)
             SniffTableIndex++;
          }
 
-#ifdef DEBUG
-   Debug_msg("Inet_NoSniff -- freeing buffer" );
-#endif
+   DEBUG_MSG("Inet_NoSniff -- freeing buffer" );
 
    Inet_Forge_packet_destroy( buf );
 
@@ -795,10 +899,7 @@ int Inet_CheckSwitch()
 {
    int link_type=2;
 
-#ifdef DEBUG
-   Debug_msg("Inet_CheckSwitch" );
-#endif
-
+   DEBUG_MSG("Inet_CheckSwitch" );
 
    if (Options.link) return 0;
 
@@ -915,9 +1016,7 @@ int Inet_CheckSwitch()
    else return 0;
 
 
-#ifdef DEBUG
-   Debug_msg("Inet_CheckSwitch -- type %d", link_type );
-#endif
+   DEBUG_MSG("Inet_CheckSwitch -- type %d", link_type );
 
    return link_type;
 }
@@ -972,9 +1071,7 @@ socket_handle Inet_OpenSocket(char *host, short port)
    WSADATA wsdata;
 #endif
 
-#ifdef DEBUG
-   Debug_msg("Inet_OpenSocket -- host [%s] port [%d]", host, port);
-#endif
+   DEBUG_MSG("Inet_OpenSocket -- host [%s] port [%d]", host, port);
 
 #ifdef CYGWIN
    if ( WSAStartup(MAKEWORD(2, 2), &wsdata) != 0)
@@ -1019,9 +1116,7 @@ socket_handle Inet_OpenSocket(char *host, short port)
 
 int Inet_CloseSocket(socket_handle sh)
 {
-#ifdef DEBUG
-   Debug_msg("Inet_CloseSocket");
-#endif
+   DEBUG_MSG("Inet_CloseSocket");
 
 #ifdef CYGWIN
    WSACleanup();
@@ -1097,4 +1192,8 @@ int Inet_SendLargeTCPPacket(int sock, char *buffer, int len, int MTU)
    return(1);
 }
 
+
 /* EOF */
+
+// vim:ts=3:expandtab
+
