@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface.c,v 1.11 2002/02/10 10:07:49 alor Exp $
+    $Id: ec_interface.c,v 1.24 2002/04/19 13:04:02 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -43,7 +43,8 @@
 #include "include/ec_inet.h"
 #include "include/ec_buffer.h"
 #include "include/ec_fingerprint.h"
-#include "include/ec_error.h"
+#include "include/ec_doppleganger.h"
+#include "include/ec_thread.h"
 
 
 #ifdef PERMIT_PLUGINS
@@ -94,6 +95,8 @@ void Interface_OldStyleSniff(short mode);
 void Interface_CheckForPoisoner(void);
 void Interface_FingerPrint(void);
 void Interface_EntryRemoval(void);
+void Interface_OnlyPoison(void);
+
 
 // global variables for Interface...
 
@@ -117,8 +120,6 @@ char title_bottom_window[100];
 char title_main_window[100];
 char title_top_window[100];
 
-short ScreenMode;
-
 // -------------------------------------------
 
 void Interface_GetWindowSize(void)
@@ -141,28 +142,28 @@ void Interface_GetWindowSize(void)
    W_MAINY1 = W_TOPY2 + 1;
 
 
-   W_SELECTX = 25;
-   W_LIST_SOURCE = (W_MAINX2 - W_SELECTX * 2)/2 ;
-   W_LIST_DEST = W_LIST_SOURCE + W_SELECTX;
+   W_SELECTX = 20;
+   W_LIST_SOURCE = (W_MAINX2 - (W_SELECTX+5) * 2)/2 ;
+   W_LIST_DEST = W_LIST_SOURCE + W_SELECTX + 5;
 
    Sel_Number = W_MAINY2 - W_MAINY1 - 1;
 
-   W_SELECTCONN = W_MAINX2 - 1;
+	#ifdef HAVE_PDCURSES
+		W_SELECTCONN = 10;
+	#else
+   	W_SELECTCONN = W_MAINX2 - 1;
+	#endif
 
    W_SELECTPLUG = W_SELECTCONN - 5;
 
-#ifdef DEBUG
-   Debug_msg("Interface_GetWindowSize");
-#endif
+   DEBUG_MSG("Interface_GetWindowSize");
 }
 
 
 
 void Interface_Winch(void)       // TODO better handling...
 {
-#ifdef DEBUG
-   Debug_msg("Interface_Winch\tTODO");
-#endif
+   DEBUG_MSG("Interface_Winch\tTODO");
 /*
    clear();
 
@@ -194,9 +195,7 @@ void Interface_Winch(void)       // TODO better handling...
 
 void Interface_Redraw(void)
 {
-#ifdef DEBUG
-   Debug_msg("Interface_Redraw");
-#endif
+   DEBUG_MSG("Interface_Redraw");
 
    clear();
 
@@ -243,9 +242,7 @@ void Interface_Redraw(void)
 
 void Interface_InitTitle(char *ip, char *mac, char *subnet)
 {
-#ifdef DEBUG
-   Debug_msg("Interface_InitTitle [%s] [%s] [%s]", ip, mac, subnet);
-#endif
+   DEBUG_MSG("Interface_InitTitle [%s] [%s] [%s]", ip, mac, subnet);
 
    if (Options.silent)
    {
@@ -277,9 +274,7 @@ void Interface_InitTitle(char *ip, char *mac, char *subnet)
 
 void Interface_InitScreen(void)
 {
-#ifdef DEBUG
-   Debug_msg("Interface_InitScreen");
-#endif
+   DEBUG_MSG("Interface_InitScreen");
 
 #if defined (HAVE_TERMIOS_H) && !defined(CYGWIN)
    tcgetattr(0, &original_term_info);
@@ -289,16 +284,9 @@ void Interface_InitScreen(void)
    cbreak();
    noecho();
 
-#ifdef CYGWIN
-   LINES = 25;
-   COLS = 80;
-#endif
+   DEBUG_MSG("Interface_InitScreen -- screen size %dx%d -- color [%d]", LINES, COLS, has_colors());
 
-#ifdef DEBUG
-   Debug_msg("Interface_InitScreen -- screen size %dx%d", LINES, COLS);
-#endif
-
-   ScreenMode = 1;
+   Options.onscreen = 1;
 
    Interface_GetWindowSize();
 
@@ -344,9 +332,7 @@ void Interface_InitScreen(void)
 
    keypad(main_window,1);
 
-#ifdef DEBUG
-   Debug_msg("Interface_InitScreen -- INIZIALIZED");
-#endif
+   DEBUG_MSG("Interface_InitScreen -- INIZIALIZED");
 
    Interface_Redraw();     // touch the screen and call doupdate()
    Interface_InitList();
@@ -470,7 +456,8 @@ void Interface_PointItem(char direction, char hor_direction)
    if ( (Old_Pointer >= Base_Pointer) && (Old_Pointer <= Base_Pointer + Sel_Number -1))   // DON'T redraw previous selected item if it is out of view
    {
       wmove(main_window, Old_Pointer - Base_Pointer, W_LIST_SOURCE);
-      whline(main_window,' ',W_MAINX2 - 1);                          //deletes the previous position
+      //whline(main_window, ' ', W_MAINX2 - 1);                          //deletes the previous position
+      whline(main_window, ' ', W_SELECTX);                          //deletes the previous position
       wprintw(main_window, "%3d) %15s      %3d) %15s", Old_Pointer+1, Host_In_LAN[Old_Pointer].ip, Old_Pointer+1, Host_In_LAN[Old_Pointer].ip);
    }
 
@@ -538,9 +525,7 @@ void Interface_KeyTab(void)
 
 void Interface_SelectItem(void)        // TODO  implement color selection
 {
-#ifdef DEBUG
-   Debug_msg("Interface_SelectItem");
-#endif
+   DEBUG_MSG("Interface_SelectItem");
 
 
    if (Pointer == &Source_Pointer)
@@ -549,7 +534,7 @@ void Interface_SelectItem(void)        // TODO  implement color selection
       wbkgdset(top_window, COLOR_PAIR(HELP_COLOR));
       wprintw(top_window, "SOURCE: ");
       wbkgdset(top_window, COLOR_PAIR(BOTTOM_COLOR));
-      wprintw(top_window, "%15s", Host_In_LAN[Source_Pointer].ip);
+      wprintw(top_window, "%15s   %s", Host_In_LAN[Source_Pointer].ip, Host_In_LAN[Source_Pointer].mac);
       memcpy(&Host_Source, &Host_In_LAN[Source_Pointer], sizeof(HOST) );
       //sel_for_source = *Pointer;
    }
@@ -559,7 +544,7 @@ void Interface_SelectItem(void)        // TODO  implement color selection
       wbkgdset(top_window, COLOR_PAIR(HELP_COLOR));
       wprintw(top_window, "DEST  : ");
       wbkgdset(top_window, COLOR_PAIR(BOTTOM_COLOR));
-      wprintw(top_window, "%15s", Host_In_LAN[Dest_Pointer].ip);
+      wprintw(top_window, "%15s   %s", Host_In_LAN[Dest_Pointer].ip, Host_In_LAN[Dest_Pointer].mac);
       memcpy(&Host_Dest, &Host_In_LAN[Dest_Pointer], sizeof(HOST) );
       //sel_for_dest = *Pointer;
    }
@@ -583,8 +568,10 @@ char Interface_PopUp(char *question, ...)
    vsnprintf(message, 150, question, ap);
    va_end(ap);
 
+	message[W_MAINX2-5] = '\0';
+
    question_window = newwin(5, strlen(message) + 4,0,0);
-   mvwin(question_window, W_MAINY1+(W_MAINY2-W_MAINY1)/2-2, W_MAINX2/2 - (strlen(message)+4)/2 + 2 );
+   mvwin(question_window, W_MAINY1+(W_MAINY2-W_MAINY1)/2-2, W_MAINX2/2 - (strlen(message)+4)/2 + 1 );
    wbkgdset(question_window, COLOR_PAIR(TITLE_COLOR));
    wattron(question_window, A_BOLD);
    box(question_window,ACS_VLINE,ACS_HLINE);
@@ -598,9 +585,7 @@ char Interface_PopUp(char *question, ...)
 
    doupdate();
 
-#ifdef DEBUG
-   Debug_msg("Interface_PopUp returns -- %c", answer);
-#endif
+   DEBUG_MSG("Interface_PopUp returns -- %c", answer);
 
    return answer;
 }
@@ -612,9 +597,7 @@ void Interface_RefreshList(void)
    WINDOW *message_window;
    char mess[21] = "updating the list...";
 
-#ifdef DEBUG
-   Debug_msg("Interface_RefreshList");
-#endif
+   DEBUG_MSG("Interface_RefreshList");
 
    message_window = newwin(5, strlen(mess) + 4,0,0);
    mvwin(message_window, W_MAINY1+(W_MAINY2-W_MAINY1)/2-2, W_MAINX2/2 - (strlen(mess) + 4)/2 );
@@ -681,16 +664,16 @@ void Interface_HelpWindow(char *help[])
 void Interface_Connect(void)
 {
 
-#ifdef DEBUG
-   Debug_msg("Interface_Connect");
-#endif
+   DEBUG_MSG("Interface_Connect");
 
    if ( (!strcmp(Host_Source.ip, "")) && (!strcmp(Host_Dest.ip, "")) )
       Interface_PopUp("Before sniffing select AT LEAST source OR destination !!");
    else if ( (!strcmp(Host_Source.ip, Inet_MyIPAddress())) || (!strcmp(Host_Dest.ip, Inet_MyIPAddress())) )
       Interface_PopUp("You CAN'T arpsniff yourself !!");
    else if ( !strcmp(Host_Source.ip, Host_Dest.ip) )
-      Interface_PopUp("SOURCE and DEST must be different !!");
+      Interface_PopUp("SOURCE and DEST (ip) must be different !!");
+   else if (Options.dumpfile)
+      Interface_PopUp("You CAN'T arpsniff from a file !!");
    else
    {
       char answer;
@@ -760,14 +743,12 @@ void Interface_Connect(void)
 void Interface_OldStyleSniff(short mode)
 {
 
-#ifdef DEBUG
-   Debug_msg("Interface_OldStyleSniff -- mode = %d", mode);
-#endif
+   DEBUG_MSG("Interface_OldStyleSniff -- mode = %d -- [%s] [%s]", mode, Host_Source.ip, Host_Dest.ip);
 
    if ( !strcmp(Host_Source.ip, Host_Dest.ip) && strcmp(Host_Source.ip, "") )
-      Interface_PopUp("SOURCE and DEST must be different !!");
+      Interface_PopUp("SOURCE and DEST (ip) must be different !!");
    else if ( !strcmp(Host_Source.mac, Host_Dest.mac) && strcmp(Host_Source.mac, ""))
-      Interface_PopUp("SOURCE and DEST must be different !!");
+      Interface_PopUp("SOURCE and DEST (mac) must be different !!");
    else
    {
       wmove(top_window,0,0); whline(top_window, ' ', W_TOPX2);
@@ -812,14 +793,16 @@ void Interface_OldStyleSniff(short mode)
 
       wbkgdset(top_window, COLOR_PAIR(HELP_COLOR));
       mvwprintw(top_window,0,25, "<"); waddch(top_window, ACS_HLINE); waddch(top_window, ACS_HLINE); waddch(top_window, ACS_URCORNER);
-      if (mode)
-      {
+
+      if (!Options.writedump && Options.dumpfile) {
+         wmove(top_window, 1,28); waddch(top_window, ACS_LTEE); waddch(top_window, ACS_HLINE);
+         wbkgdset(top_window, COLOR_PAIR(BOTTOM_COLOR));
+         wprintw(top_window, " OffLine sniffing [%s]", Options.dumpfile);
+      } else if (mode) {
          wmove(top_window, 1,28); waddch(top_window, ACS_LTEE); waddch(top_window, ACS_HLINE);
          wbkgdset(top_window, COLOR_PAIR(BOTTOM_COLOR));
          wprintw(top_window, " illithid (MAC based) "); waddch(top_window, ACS_HLINE); wprintw(top_window, " %s", PROGRAM);
-      }
-      else
-      {
+      } else {
          wmove(top_window, 1,28); waddch(top_window, ACS_LTEE); waddch(top_window, ACS_HLINE);
          wbkgdset(top_window, COLOR_PAIR(BOTTOM_COLOR));
          wprintw(top_window, " illithid (IP based) "); waddch(top_window, ACS_HLINE); wprintw(top_window, " %s", PROGRAM);
@@ -847,6 +830,55 @@ void Interface_OldStyleSniff(short mode)
 }
 
 
+
+void Interface_OnlyPoison(void)
+{
+
+   DEBUG_MSG("Interface_OnlyPoison");
+
+   if ( (!strcmp(Host_Source.ip, "")) && (!strcmp(Host_Dest.ip, "")) )
+      Interface_PopUp("Before poison select AT LEAST source OR destination !!");
+   else if ( (!strcmp(Host_Source.ip, Inet_MyIPAddress())) || (!strcmp(Host_Dest.ip, Inet_MyIPAddress())) )
+      Interface_PopUp("You CAN'T poison yourself !!");
+   else if ( !strcmp(Host_Source.ip, Host_Dest.ip) )
+      Interface_PopUp("SOURCE and DEST (ip) must be different !!");
+   else
+   {
+      int i;
+      pthread_t Dopple_pid = 0;
+      
+      for(i=0; i<number_of_hosts_in_lan; i++)
+      {
+        if ( !strcmp(Host_Source.ip, Host_In_LAN[i].ip) )
+           strlcpy(Host_Source.mac, Host_In_LAN[i].mac, sizeof(Host_Source.mac));
+        if ( !strcmp(Host_Dest.ip, Host_In_LAN[i].ip) )
+           strlcpy(Host_Dest.mac, Host_In_LAN[i].mac, sizeof(Host_Dest.mac));
+      }
+
+      if ( !strcmp(Host_Source.mac, "") && !strcmp(Host_Dest.mac, "") )
+        Error_msg("Doppelganger needs at least one valid mac address !!\n\n(the ip was not found in the list)");
+
+      Dopple_pid = Doppleganger_Run(Options.netiface, Host_Source.ip, Host_Dest.ip, Host_Source.mac, Host_Dest.mac);
+   
+      Interface_CloseScreen();
+
+      fprintf(stdout, "\n\n Poisoning - %s [%s] -- %s [%s]\n\n", Host_Source.ip, Host_Source.mac, Host_Dest.ip, Host_Dest.mac);
+      fprintf(stdout, "\nPress any key to stop...\n");
+      fflush(stdout);
+      
+      getchar();
+      printf("\n\n\nShutting down all threads... ");
+      fflush(stdout);
+      ECThread_destroy(Dopple_pid);
+      printf("Done.\n\n");
+                                                                                                      
+      exit(0);
+   }
+   
+   DEBUG_MSG("Interface_OnlyPoison -- END");
+}
+
+   
 void Interface_CheckForPoisoner(void)
 {
    WINDOW *message_window;
@@ -855,9 +887,7 @@ void Interface_CheckForPoisoner(void)
    short found = 0;
    char mess[26] = "checking for poisoners...";
 
-#ifdef DEBUG
-   Debug_msg("Interface_CheckForPoisoner");
-#endif
+   DEBUG_MSG("Interface_CheckForPoisoner");
 
    if (number_of_hosts_in_lan == 1)
    {
@@ -876,7 +906,7 @@ void Interface_CheckForPoisoner(void)
 
    SniffList = Inet_NoSniff();
 
-   for (i=0; i<number_of_hosts_in_lan; i++)
+   for (i=0; ; i++)
    {
       if (SniffList[i].mode == 0) break;
       if (SniffList[i].mode == 1)
@@ -917,9 +947,7 @@ void Interface_FingerPrint(void)
    char *long_os_fingers;
    char temp[W_MAINX2];
 
-#ifdef DEBUG
-   Debug_msg("Interface_FingerPrint -- [%s] [%s]", Host_In_LAN[*Pointer].ip, Host_In_LAN[*Pointer].mac );
-#endif
+   DEBUG_MSG("Interface_FingerPrint -- [%s] [%s]", Host_In_LAN[*Pointer].ip, Host_In_LAN[*Pointer].mac );
 
    message_window = newwin(5, strlen(mess) + 4,0,0);
    mvwin(message_window, W_MAINY1+(W_MAINY2-W_MAINY1)/2-2, W_MAINX2/2 - (strlen(mess) + 4)/2 );
@@ -976,9 +1004,7 @@ void Interface_FingerPrint(void)
       memset(temp, 0, W_MAINX2);
       strlcpy(temp, strtok(NULL, "\n"), W_MAINX2-4-18);
       mvwprintw(finger_win, 3+i, 20, "%s", temp);
-      #ifdef DEBUG
-         Debug_msg("Interface_FingerPrint -- [%s]", temp );
-      #endif
+      DEBUG_MSG("Interface_FingerPrint -- [%s]", temp );
    }
    mvwprintw(finger_win, dimY-3, 20, "%s", mac_finger);
 
@@ -1001,9 +1027,7 @@ void Interface_FingerPrint(void)
 
 void Interface_EntryRemoval(void)
 {
-#ifdef DEBUG
-   Debug_msg("Interface_EntryRemoval -- %d", *Pointer);
-#endif
+   DEBUG_MSG("Interface_EntryRemoval -- %d", *Pointer);
 
    if (*Pointer == 0 || number_of_hosts_in_lan == 1)
    {
@@ -1030,9 +1054,7 @@ void Interface_Run(void)
 {
    int KeyPress;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Run");
-#endif
+   DEBUG_MSG("Interface_Run");
 
    if (Options.arpsniff)
       Interface_Connect();
@@ -1156,12 +1178,19 @@ void Interface_Run(void)
                   Interface_InitList();
                   break;
 
-#ifdef PERMIT_PLUGINS
+         case 'J':
+         case 'j':
+                  Interface_OnlyPoison(); /* never returns */
+                  break;
+                  
          case 'P':
          case 'p':
+#ifdef PERMIT_PLUGINS
                   Interface_Plugins_Run();
-                  break;
+#else
+                  Interface_PopUp("Plugins NOT supported under your system !!");
 #endif
+                  break;
 
 
          case KEY_F(1):
@@ -1177,11 +1206,10 @@ void Interface_Run(void)
                         "             . for man-in-the-middle technique",
                         "[sS]      - IP based sniffing",
                         "[mM]      - MAC based sniffing",
+                        "[jJ]      - Only poisoning - no sniffing",
                         "[dD]      - delete an entry from the list",
                         "[xX]      - Packet Forge",
-#ifdef PERMIT_PLUGINS
                         "[pP]      - run a plugin",
-#endif
                         "[fF]      - OS fingerprint",
                         "[oO]      - passive host identification",
                         "[cC]      - check for other poisoner...",
@@ -1212,29 +1240,23 @@ void Interface_Run(void)
 
          case 'q':
          case 'Q':
-                  #ifdef DEBUG
-                     Debug_msg("Interface_Run_END");
-                  #endif
+                  DEBUG_MSG("Interface_Run_END");
                   {
                      char answer;
-                     answer = Interface_PopUp("Do U really want to exit (y/n)?");
+                     answer = Interface_PopUp("Do you really want to exit (y/n)?");
                      if ((answer == 'y') || (answer == 'Y'))
                         Interface_WExit("They are safe!!  for now... ");
                   }
                   break;
 
          case KEY_F(10):
-                  #ifdef DEBUG
-                     Debug_msg("Interface_Run_END");
-                  #endif
+                  DEBUG_MSG("Interface_Run_END");
                   Interface_WExit("");
                   break;
 
          default:
                   //beep();
-                  #ifdef DEBUG
-                     Debug_msg("KeyPress in octal: %o  in decimal: %d", KeyPress, KeyPress);
-                  #endif
+                  DEBUG_MSG("KeyPress in octal: %o  in decimal: %d", KeyPress, KeyPress);
                   break;
       }
    }
@@ -1245,9 +1267,7 @@ void Interface_Run(void)
 
 void Interface_CloseScreen(void)
 {
-#ifdef DEBUG
-   Debug_msg("Interface_CloseScreen");
-#endif
+   DEBUG_MSG("Interface_CloseScreen");
 
    curs_set(1);
    clear();
@@ -1265,12 +1285,11 @@ void Interface_CloseScreen(void)
 void Interface_WExit(char *buffer)
 {
 
-#ifdef DEBUG
-   Debug_msg("Interface_WExit -- [%s]", buffer);
-#endif
+   DEBUG_MSG("Interface_WExit -- [%s]", buffer);
 
-   if (ScreenMode) Interface_CloseScreen();
+   if (Options.onscreen) Interface_CloseScreen();
 
+   fprintf(stdout, "\n\n");
    fprintf(stdout, "\033[01m\033[1m%s %s brought from the dark side of the net by ALoR and NaGA...\033[0m\n\n", PROGRAM, VERSION);
    fprintf(stdout, "\033[01m\033[1mmay the packets be with you...\033[0m\n\n");
    fprintf(stdout, "\n%s\n\n", buffer);
@@ -1282,3 +1301,6 @@ void Interface_WExit(char *buffer)
 #endif
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
