@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_factory.c,v 1.6 2001/12/09 20:24:51 alor Exp $
+    $Id: ec_interface_factory.c,v 1.8 2002/04/11 20:16:36 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -37,7 +37,6 @@
 #endif
 
 #include "include/ec_interface.h"
-#include "include/ec_error.h"
 #include "include/ec_inet_forge.h"
 #include "include/ec_inet.h"
 #include "include/ec_inet_structures.h"
@@ -88,9 +87,7 @@ int Interface_Factory_ETH(u_char *buf)
    unsigned n = 0;
    short len = -1;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Factory_ETH");
-#endif
+   DEBUG_MSG("Interface_Factory_ETH");
 
    refresh();
 
@@ -147,10 +144,8 @@ int Interface_Factory_ETH(u_char *buf)
          return -1;
       }
 
-      #ifdef DEBUG
-         Debug_msg("Interface_Factory_ETH -- [%s]",field_buffer(eth_form[3], 0));
-         Debug_msg("Interface_Factory_ETH -- [%s]",field_buffer(eth_form[5], 0));
-      #endif
+      DEBUG_MSG("Interface_Factory_ETH -- [%s]",field_buffer(eth_form[3], 0));
+      DEBUG_MSG("Interface_Factory_ETH -- [%s]",field_buffer(eth_form[5], 0));
 
       eth->type = htons(ETH_P_IP);
       len = ETH_HEADER;
@@ -174,9 +169,7 @@ int Interface_Factory_IP(u_char *buf, short *proto)
    unsigned n = 0;
    short len = -1;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Factory_IP");
-#endif
+   DEBUG_MSG("Interface_Factory_IP");
 
    refresh();
 
@@ -247,10 +240,8 @@ int Interface_Factory_IP(u_char *buf, short *proto)
       ip->source_ip      = inet_addr(field_buffer(ip_form[3], 0));
       ip->dest_ip        = inet_addr(field_buffer(ip_form[5], 0));
 
-      #ifdef DEBUG
-         Debug_msg("Interface_Factory_IP -- [%s]", int_ntoa(ip->source_ip));
-         Debug_msg("Interface_Factory_IP -- [%s]", int_ntoa(ip->dest_ip));
-      #endif
+      DEBUG_MSG("Interface_Factory_IP -- [%s]", int_ntoa(ip->source_ip));
+      DEBUG_MSG("Interface_Factory_IP -- [%s]", int_ntoa(ip->dest_ip));
 
       if (strtoul(field_buffer(ip_form[14], 0), NULL, 16))
          ip->checksum    = htons(strtoul(field_buffer(ip_form[14], 0), NULL, 16));
@@ -277,9 +268,7 @@ int Interface_Factory_TCP(u_char *buf)
    unsigned n = 0;
    short len = -1;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Factory_TCP");
-#endif
+   DEBUG_MSG("Interface_Factory_TCP");
 
    refresh();
 
@@ -366,9 +355,9 @@ int Interface_Factory_TCP(u_char *buf)
             return len;
          }
          fseek(fts, 0, SEEK_END);
-         #ifdef DEBUG
-            Debug_msg("Interface_Factory_TCP -- file opened [%s] size %d", tmp, ftell(fts));
-         #endif
+
+         DEBUG_MSG("Interface_Factory_TCP -- file opened [%s] size %d", tmp, ftell(fts));
+
          if (ftell(fts) + 40 > 1500)
          {
             Interface_PopUp("File too big (max 1460 bytes)");
@@ -425,10 +414,8 @@ int Interface_Factory_TCP(u_char *buf)
       tcp->checksum    = 0;
       tcp->urg_ptr     = 0;
 
-      #ifdef DEBUG
-         Debug_msg("Interface_Factory_TCP -- [%d]", ntohs(tcp->source));
-         Debug_msg("Interface_Factory_TCP -- [%d]", ntohs(tcp->dest));
-      #endif
+      DEBUG_MSG("Interface_Factory_TCP -- [%d]", ntohs(tcp->source));
+      DEBUG_MSG("Interface_Factory_TCP -- [%d]", ntohs(tcp->dest));
 
       ip->t_len        += htons(TCP_HEADER + datalen);
       if (!ip->checksum) ip->checksum = Inet_Forge_ChecksumIP( (u_short *)ip, sizeof(IP_header) );
@@ -462,9 +449,7 @@ int Interface_Factory_UDP(u_char *buf)
    unsigned n = 0;
    short len = -1;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Factory_UDP");
-#endif
+   DEBUG_MSG("Interface_Factory_UDP");
 
    refresh();
 
@@ -537,9 +522,9 @@ int Interface_Factory_UDP(u_char *buf)
             return len;
          }
          fseek(fts, 0, SEEK_END);
-         #ifdef DEBUG
-            Debug_msg("Interface_Factory_UDP -- file opened [%s] size %d", tmp, ftell(fts));
-         #endif
+
+         DEBUG_MSG("Interface_Factory_UDP -- file opened [%s] size %d", tmp, ftell(fts));
+
          if (ftell(fts) + 40 > 1500)
          {
             Interface_PopUp("File too big (max 1460 bytes)");
@@ -562,10 +547,8 @@ int Interface_Factory_UDP(u_char *buf)
       udp->checksum    = 0;
       udp->len         = htons(datalen + UDP_HEADER);
 
-      #ifdef DEBUG
-         Debug_msg("Interface_Factory_UDP -- [%d]", ntohs(udp->source));
-         Debug_msg("Interface_Factory_UDP -- [%d]", ntohs(udp->dest));
-      #endif
+      DEBUG_MSG("Interface_Factory_UDP -- [%d]", ntohs(udp->source));
+      DEBUG_MSG("Interface_Factory_UDP -- [%d]", ntohs(udp->dest));
 
       ip->t_len        += htons(UDP_HEADER + datalen);
       if (!ip->checksum) ip->checksum = Inet_Forge_ChecksumIP( (u_short *)ip, sizeof(IP_header) );
@@ -599,9 +582,7 @@ int Interface_Factory_RAW(u_char *buf)
    unsigned n = 0;
    short len = -1;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Factory_RAW");
-#endif
+   DEBUG_MSG("Interface_Factory_RAW");
 
    refresh();
 
@@ -648,9 +629,9 @@ int Interface_Factory_RAW(u_char *buf)
             return len;
          }
          fseek(fts, 0, SEEK_END);
-         #ifdef DEBUG
-            Debug_msg("Interface_Factory_RAW -- file opened [%s] size %d", tmp, ftell(fts));
-         #endif
+
+         DEBUG_MSG("Interface_Factory_RAW -- file opened [%s] size %d", tmp, ftell(fts));
+
          if (ftell(fts) + 40 > 1500)
          {
             Interface_PopUp("File too big (max 1460 bytes)");
@@ -699,9 +680,7 @@ int Interface_Factory_ETH(u_char *buf)
    int len = -1;
    ETH_header *eth;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Factory_ETH");
-#endif
+   DEBUG_MSG("Interface_Factory_ETH");
 
    f_win = newwin(dimY+2, dimX+2, W_BOTTOMY2/2 - dimY/2, W_MAINX2/2 - dimX/2);
    w_factory = newwin(dimY, dimX, W_BOTTOMY2/2 - dimY/2 +1, W_MAINX2/2 - dimX/2 +1);
@@ -724,14 +703,22 @@ int Interface_Factory_ETH(u_char *buf)
       doupdate();
    wgetnstr(w_factory, MACS, sizeof(MACS)-1);
 
+   if ( MACS[0] == 'q')
+   {
+      noecho();
+      curs_set(0);
+      return -1;
+   }
+
    wprintw(w_factory, "\nDest MAC   : ");
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
    wgetnstr(w_factory, MACD, sizeof(MACD)-1);
 
-   if ( MACS[0] == 'q' || MACD[0] == 'q')
+   if ( MACD[0] == 'q')
    {
+      noecho();
       curs_set(0);
       return -1;
    }
@@ -752,15 +739,12 @@ int Interface_Factory_ETH(u_char *buf)
          return -1;
       }
 
-      #ifdef DEBUG
-         Debug_msg("Interface_Factory_ETH -- [%s]", MACS);
-         Debug_msg("Interface_Factory_ETH -- [%s]", MACD);
-      #endif
+      DEBUG_MSG("Interface_Factory_ETH -- [%s]", MACS);
+      DEBUG_MSG("Interface_Factory_ETH -- [%s]", MACD);
 
       eth->type = htons(ETH_P_IP);
       len = ETH_HEADER;
 
-   noecho();
    curs_set(FALSE);
    delwin(f_win);
    delwin(w_factory);
@@ -784,9 +768,7 @@ int Interface_Factory_IP(u_char *buf, short *proto)
    int len = -1;
    IP_header *ip;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Factory_IP");
-#endif
+   DEBUG_MSG("Interface_Factory_IP");
 
    f_win = newwin(dimY+2, dimX+2, W_BOTTOMY2/2 - dimY/2, W_MAINX2/2 - dimX/2);
    w_factory = newwin(dimY, dimX, W_BOTTOMY2/2 - dimY/2 +1, W_MAINX2/2 - dimX/2 +1);
@@ -811,6 +793,7 @@ int Interface_Factory_IP(u_char *buf, short *proto)
 
    if ( IPS[0] == 'q' || IPS[0] == 'Q')
    {
+      noecho();
       curs_set(0);
       return -1;
    }
@@ -823,6 +806,7 @@ int Interface_Factory_IP(u_char *buf, short *proto)
 
    if ( IPD[0] == 'q' || IPD[0] == 'Q')
    {
+      noecho();
       curs_set(0);
       return -1;
    }
@@ -865,10 +849,8 @@ int Interface_Factory_IP(u_char *buf, short *proto)
       ip->source_ip      = inet_addr(IPS);
       ip->dest_ip        = inet_addr(IPD);
 
-      #ifdef DEBUG
-         Debug_msg("Interface_Factory_IP -- [%s]", int_ntoa(ip->source_ip));
-         Debug_msg("Interface_Factory_IP -- [%s]", int_ntoa(ip->dest_ip));
-      #endif
+      DEBUG_MSG("Interface_Factory_IP -- [%s]", int_ntoa(ip->source_ip));
+      DEBUG_MSG("Interface_Factory_IP -- [%s]", int_ntoa(ip->dest_ip));
 
       if (strtoul(checksum, NULL, 16))
          ip->checksum    = htons(strtoul(checksum, NULL, 16));
@@ -905,9 +887,7 @@ int Interface_Factory_TCP(u_char *buf)
    u_char payload[8*50];
    u_char file[50];
 
-#ifdef DEBUG
-   Debug_msg("Interface_Factory_TCP");
-#endif
+   DEBUG_MSG("Interface_Factory_TCP");
 
    f_win = newwin(dimY+2, dimX+2, W_BOTTOMY2/2 - dimY/2, W_MAINX2/2 - dimX/2);
    w_factory = newwin(dimY, dimX, W_BOTTOMY2/2 - dimY/2 +1, W_MAINX2/2 - dimX/2 +1);
@@ -932,6 +912,7 @@ int Interface_Factory_TCP(u_char *buf)
 
    if ( S[0] == 'q' || S[0] == 'Q')
    {
+      noecho();
       curs_set(0);
       return -1;
    }
@@ -944,6 +925,7 @@ int Interface_Factory_TCP(u_char *buf)
 
    if ( D[0] == 'q' || D[0] == 'Q')
    {
+      noecho();
       curs_set(0);
       return -1;
    }
@@ -999,9 +981,9 @@ int Interface_Factory_TCP(u_char *buf)
             return len;
          }
          fseek(fts, 0, SEEK_END);
-         #ifdef DEBUG
-            Debug_msg("Interface_Factory_TCP -- file opened [%s] size %d", tmp, ftell(fts));
-         #endif
+
+         DEBUG_MSG("Interface_Factory_TCP -- file opened [%s] size %d", tmp, ftell(fts));
+
          if (ftell(fts) + 40 > 1500)
          {
             Interface_PopUp("File too big (max 1460 bytes)");
@@ -1055,10 +1037,8 @@ int Interface_Factory_TCP(u_char *buf)
       tcp->checksum    = 0;
       tcp->urg_ptr     = 0;
 
-      #ifdef DEBUG
-         Debug_msg("Interface_Factory_TCP -- [%d]", ntohs(tcp->source));
-         Debug_msg("Interface_Factory_TCP -- [%d]", ntohs(tcp->dest));
-      #endif
+      DEBUG_MSG("Interface_Factory_TCP -- [%d]", ntohs(tcp->source));
+      DEBUG_MSG("Interface_Factory_TCP -- [%d]", ntohs(tcp->dest));
 
       ip->t_len        += htons(TCP_HEADER + datalen);
       if (!ip->checksum) ip->checksum = Inet_Forge_ChecksumIP( (u_short *)ip, sizeof(IP_header) );
@@ -1098,9 +1078,7 @@ int Interface_Factory_UDP(u_char *buf)
    u_char payload[8*50];
    u_char file[50];
 
-#ifdef DEBUG
-   Debug_msg("Interface_Factory_UDP");
-#endif
+   DEBUG_MSG("Interface_Factory_UDP");
 
    f_win = newwin(dimY+2, dimX+2, W_BOTTOMY2/2 - dimY/2, W_MAINX2/2 - dimX/2);
    w_factory = newwin(dimY, dimX, W_BOTTOMY2/2 - dimY/2 +1, W_MAINX2/2 - dimX/2 +1);
@@ -1125,6 +1103,7 @@ int Interface_Factory_UDP(u_char *buf)
 
    if ( S[0] == 'q' || S[0] == 'Q')
    {
+      noecho();
       curs_set(0);
       return -1;
    }
@@ -1137,6 +1116,7 @@ int Interface_Factory_UDP(u_char *buf)
 
    if ( D[0] == 'q' || D[0] == 'Q')
    {
+      noecho();
       curs_set(0);
       return -1;
    }
@@ -1175,9 +1155,9 @@ int Interface_Factory_UDP(u_char *buf)
             return len;
          }
          fseek(fts, 0, SEEK_END);
-         #ifdef DEBUG
-            Debug_msg("Interface_Factory_TCP -- file opened [%s] size %d", tmp, ftell(fts));
-         #endif
+
+         DEBUG_MSG("Interface_Factory_TCP -- file opened [%s] size %d", tmp, ftell(fts));
+
          if (ftell(fts) + 40 > 1500)
          {
             Interface_PopUp("File too big (max 1460 bytes)");
@@ -1199,10 +1179,8 @@ int Interface_Factory_UDP(u_char *buf)
       udp->checksum    = 0;
       udp->len         = htons(datalen + UDP_HEADER);
 
-      #ifdef DEBUG
-         Debug_msg("Interface_Factory_UDP -- [%d]", ntohs(udp->source));
-         Debug_msg("Interface_Factory_UDP -- [%d]", ntohs(udp->dest));
-      #endif
+      DEBUG_MSG("Interface_Factory_UDP -- [%d]", ntohs(udp->source));
+      DEBUG_MSG("Interface_Factory_UDP -- [%d]", ntohs(udp->dest));
 
       ip->t_len        += htons(UDP_HEADER + datalen);
       if (!ip->checksum) ip->checksum = Inet_Forge_ChecksumIP( (u_short *)ip, sizeof(IP_header) );
@@ -1239,9 +1217,7 @@ int Interface_Factory_RAW(u_char *buf)
    u_char payload[14*50];
    u_char file[50];
 
-#ifdef DEBUG
-   Debug_msg("Interface_Factory_RAW");
-#endif
+   DEBUG_MSG("Interface_Factory_RAW");
 
    f_win = newwin(dimY+2, dimX+2, W_BOTTOMY2/2 - dimY/2, W_MAINX2/2 - dimX/2);
    w_factory = newwin(dimY, dimX, W_BOTTOMY2/2 - dimY/2 +1, W_MAINX2/2 - dimX/2 +1);
@@ -1282,9 +1258,9 @@ int Interface_Factory_RAW(u_char *buf)
             return len;
          }
          fseek(fts, 0, SEEK_END);
-         #ifdef DEBUG
-            Debug_msg("Interface_Factory_TCP -- file opened [%s] size %d", tmp, ftell(fts));
-         #endif
+
+         DEBUG_MSG("Interface_Factory_TCP -- file opened [%s] size %d", tmp, ftell(fts));
+
          if (ftell(fts) + 40 > 1500)
          {
             Interface_PopUp("File too big (max 1460 bytes)");
@@ -1332,9 +1308,9 @@ int Interface_Factory_Run(void)
 
 #ifdef DEBUG
    #ifdef HAVE_FORM
-      Debug_msg("Interface_Factory_Run");
+      DEBUG_MSG("Interface_Factory_Run");
    #else
-      Debug_msg("Interface_Factory_Run -- NO FORM");
+      DEBUG_MSG("Interface_Factory_Run -- NO FORM");
    #endif
 #endif
 
@@ -1368,17 +1344,14 @@ int Interface_Factory_Run(void)
 
    Inet_SendRawPacket(sock, buf, forged_pck-buf);
 
-#ifdef DEBUG
-   Debug_msg("Interface_Factory_Run -- %d byte(s) sent", forged_pck-buf);
-#endif
+   DEBUG_MSG("Interface_Factory_Run -- %d byte(s) sent", forged_pck-buf);
 
    Interface_Redraw();
    Interface_PopUp("%d byte(s) forged and sent on the wire", forged_pck-buf);
 
 cancelled:
-#ifdef DEBUG
-   Debug_msg("Interface_Factory_Run -- freeing buffer");
-#endif
+   DEBUG_MSG("Interface_Factory_Run -- freeing buffer");
+
    Inet_Forge_packet_destroy( buf );
    Inet_CloseRawSock(sock);
 
@@ -1390,3 +1363,6 @@ cancelled:
 
 /* EOF */
 
+
+// vim:ts=3:expandtab
+
