@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_inject.c,v 1.7 2001/12/09 20:24:51 alor Exp $
+    $Id: ec_interface_inject.c,v 1.8 2002/03/08 08:49:55 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -40,7 +40,6 @@
 #include "include/ec_interface.h"
 #include "include/ec_interface_sniff_data.h"
 #include "include/ec_decodedata.h"
-#include "include/ec_error.h"
 #include "include/ec_filterdrop.h"
 #include "include/ec_parser.h"
 #ifdef HAVE_FORM
@@ -93,9 +92,7 @@ int Fil_Pointer = 0;
 void Interface_Inject_Redraw(void)
 {
 
-#ifdef DEBUG
-   Debug_msg("Interface_Inject_Redraw");
-#endif
+   DEBUG_MSG("Interface_Inject_Redraw");
 
    Interface_Sniff_Data_Redraw();
    doupdate();
@@ -105,9 +102,7 @@ void Interface_Inject_Redraw(void)
 void Interface_Inject_SetFilter_Redraw(void)
 {
 
-#ifdef DEBUG
-   Debug_msg("Interface_Inject_SetFilter_Redraw");
-#endif
+   DEBUG_MSG("Interface_Inject_SetFilter_Redraw");
 
    Interface_Redraw();
 
@@ -128,9 +123,7 @@ int Interface_Inject_Run(u_char *inject_data, char proto, char *app)
    char inject_sequence[MAX_INJECT];
    int len;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Inject_Run -- %c %s", proto, app);
-#endif
+   DEBUG_MSG("Interface_Inject_Run -- %c %s", proto, app);
 
    i_win = newwin(dimY+2, dimX+2, W_BOTTOMY2/2 - dimY/2, W_MAINX2/2 - dimX/2);
    inject_window = newwin(dimY, dimX, W_BOTTOMY2/2 - dimY/2 +1, W_MAINX2/2 - dimX/2 +1);
@@ -151,9 +144,7 @@ int Interface_Inject_Run(u_char *inject_data, char proto, char *app)
    wmove(inject_window, 1, 0);
    wgetnstr(inject_window, inject_sequence, MAX_INJECT-1);
 
-#ifdef DEBUG
-   Debug_msg("Interface_Inject_Run -- inject_sequence len -- [%d]", strlen(inject_sequence));
-#endif
+   DEBUG_MSG("Interface_Inject_Run -- inject_sequence len -- [%d]", strlen(inject_sequence));
 
    noecho();
    curs_set(FALSE);
@@ -163,9 +154,7 @@ int Interface_Inject_Run(u_char *inject_data, char proto, char *app)
 
    len = FilterDrop_strescape(inject_data, inject_sequence);
 
-#ifdef DEBUG
-   Debug_msg("Interface_Inject_Run -- inject_data len -- [%d]", len);
-#endif
+   DEBUG_MSG("Interface_Inject_Run -- inject_data len -- [%d]", len);
 
    return len;
 
@@ -197,9 +186,7 @@ void Interface_Inject_FilterTopStatus(void)
 void Interface_Inject_FilterStatus(void)
 {
 
-#ifdef DEBUG
-   Debug_msg("Interface_Inject_FilterStatus -- source %d : dest %d", filter_on_source, filter_on_dest);
-#endif
+   DEBUG_MSG("Interface_Inject_FilterStatus -- source %d : dest %d", filter_on_source, filter_on_dest);
 
    wbkgdset(filter_window, COLOR_PAIR(HELP_COLOR));
    mvwprintw(filter_window,  4, 6, "S] Filters on Source : ");
@@ -239,9 +226,7 @@ void Interface_Inject_SetFilter(short mode)
    int dimX = 62;
    int KeyPress;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Inject_SetFilter");
-#endif
+   DEBUG_MSG("Interface_Inject_SetFilter");
 
    Fil_Number = dimY;
 
@@ -441,9 +426,7 @@ int Interface_Inject_Filter(DROP_FILTER *filters)
    int status = 0;
    char tmp[10];
 
-#ifdef DEBUG
-   Debug_msg("Interface_Inject_Filter");
-#endif
+   DEBUG_MSG("Interface_Inject_Filter");
 
    refresh();
 
@@ -562,9 +545,7 @@ int Interface_Inject_Filter(DROP_FILTER *filters)
    char tmp[10];
    char tmp_search[MAX_FILTER+1];
 
-#ifdef DEBUG
-   Debug_msg("Interface_Inject_Filter -- NO FORM");
-#endif
+   DEBUG_MSG("Interface_Inject_Filter -- NO FORM");
 
    e_win = newwin(dimY+2, dimX+2, W_BOTTOMY2/2 - dimY/2, W_MAINX2/2 - dimX/2);
    edit_window = newwin(dimY, dimX, W_BOTTOMY2/2 - dimY/2 +1, W_MAINX2/2 - dimX/2 +1);
@@ -786,9 +767,7 @@ void Interface_Inject_EditFilters(DROP_FILTER *FA_ptr)
 {
    int KeyPress;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Inject_EditFilters");
-#endif
+   DEBUG_MSG("Interface_Inject_EditFilters");
 
    werase(filter_window);
    wmove(filter_window, 0, 0);
@@ -906,3 +885,6 @@ void Interface_Inject_EditFilters(DROP_FILTER *FA_ptr)
 #endif
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
