@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_passive.c,v 1.14 2002/02/10 10:07:49 alor Exp $
+    $Id: ec_interface_passive.c,v 1.24 2002/04/18 17:03:17 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -32,6 +32,11 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
+#if defined(HAVE_SYS_POLL_H)
+   #include <sys/poll.h>
+#elif defined (HAVE_POLL_H)
+   #include <poll.h>
+#endif
 
 #include "include/ec_interface.h"
 #include "include/ec_decodedata.h"
@@ -40,7 +45,6 @@
 #include "include/ec_inet_forge.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_buffer.h"
-#include "include/ec_error.h"
 #include "include/ec_logtofile.h"
 #include "include/ec_fingerprint.h"
 #include "include/ec_thread.h"
@@ -94,6 +98,16 @@ int Host_Pointer = 0;
 extern int Sel_Number;
 char showname = 0;
 
+extern char read_from_dump_flag;  // from inet
+
+#ifdef CYGWIN
+   /*
+    * it seems that if we call douptade too frequently the windows terminal freeze up
+    * so we introduce a minimum delay between doupdate() calls.
+    */
+   int last_do_update;
+#endif
+
 //---------------------------
 
 
@@ -102,7 +116,6 @@ void Interface_Passive_InitList(void)
    int j;
    int Host_Top_Pointer;
 
-
    if (has_colors())
       wbkgdset(main_window, COLOR_PAIR(MAIN_COLOR));
    else
@@ -132,13 +145,13 @@ void Interface_Passive_InitList(void)
          wbkgdset(main_window, COLOR_PAIR(MAIN_COLOR));
 
       wmove(main_window, j-Host_Base_Pointer, LeftMargin );
-      wprintw(main_window, "%3d) %-15s  ", j+1, (showname && strcmp(Passive_Host[j].name, "")) ? Passive_Host[j].name : Passive_Host[j].ip);
+      wprintw(main_window, "%3d) %-15s   ", j+1, (showname && strcmp(Passive_Host[j].name, "")) ? Passive_Host[j].name : Passive_Host[j].ip);
       wbkgdset(main_window, COLOR_PAIR(MAIN_COLOR));
       wattroff(main_window, A_BOLD);
       wmove(main_window, j-Host_Base_Pointer, LeftMargin + 23);  waddch(main_window, ACS_VLINE);
       wprintw(main_window, " %2s ", Passive_Host[j].type);
       wmove(main_window, j-Host_Base_Pointer, LeftMargin + 28);  waddch(main_window, ACS_VLINE);
-      wprintw(main_window, " %s", Passive_Host[j].os);
+      wprintw(main_window, " %-45s", Passive_Host[j].os);
    }
 
    if (has_colors())
@@ -156,12 +169,12 @@ void Interface_Passive_InitList(void)
 
    wmove(main_window, Host_Pointer - Host_Base_Pointer, LeftMargin );
    whline(main_window, ' ', W_SELECTCONN);
-   wprintw(main_window, "%3d) %-15s  ", Host_Pointer+1, (showname && strcmp(Passive_Host[Host_Pointer].name, "")) ? Passive_Host[Host_Pointer].name : Passive_Host[Host_Pointer].ip);
+   wprintw(main_window, "%3d) %-15s   ", Host_Pointer+1, (showname && strcmp(Passive_Host[Host_Pointer].name, "")) ? Passive_Host[Host_Pointer].name : Passive_Host[Host_Pointer].ip);
    wbkgdset(main_window, COLOR_PAIR(POINT_COLOR));
    wmove(main_window, Host_Pointer-Host_Base_Pointer, LeftMargin + 23);  waddch(main_window, ACS_VLINE);
    wprintw(main_window, " %2s ",Passive_Host[Host_Pointer].type);
    wmove(main_window, Host_Pointer-Host_Base_Pointer, LeftMargin + 28);  waddch(main_window, ACS_VLINE);
-   wprintw(main_window, " %s", Passive_Host[Host_Pointer].os);
+   wprintw(main_window, " %-45s", Passive_Host[Host_Pointer].os);
 
    werase(bottom_window);
    if (Passive_Host[Host_Pointer].os[0] == 0 && Passive_Host[Host_Pointer].os[1] != 0)
@@ -174,7 +187,16 @@ void Interface_Passive_InitList(void)
 
    wnoutrefresh(bottom_window);
    wnoutrefresh(main_window);
+
+#ifdef CYGWIN
+   if (GetTickCount() - last_do_update <= MIN_DO_UPDATE_DELAY)
+      return;  // do not call doupdate() at fast time inteval
+
+   last_do_update = GetTickCount();
+#endif
+
    doupdate();
+
 }
 
 
@@ -186,6 +208,14 @@ void Interface_Passive_PointItem(char direction)
 
    if (number_of_passive_hosts == 0) return;   // no connection... no action... ;)
 
+#ifdef CYGWIN
+   if (GetTickCount() - last_do_update <= MIN_DO_UPDATE_DELAY)
+      // do not call doupdate() at fast time inteval
+		return;
+
+   last_do_update = GetTickCount();
+#endif
+
    Old_Host_Pointer = Host_Pointer;
 
    Host_Pointer += direction;
@@ -230,13 +260,13 @@ void Interface_Passive_PointItem(char direction)
 
       wmove(main_window, Old_Host_Pointer - Host_Base_Pointer, LeftMargin);
       whline(main_window,' ', W_SELECTCONN);                         //deletes the previous position
-      wprintw(main_window, "%3d) %-15s  ", Old_Host_Pointer+1, (showname && strcmp(Passive_Host[Old_Host_Pointer].name, "")) ? Passive_Host[Old_Host_Pointer].name : Passive_Host[Old_Host_Pointer].ip);
+      wprintw(main_window, "%3d) %-15s   ", Old_Host_Pointer+1, (showname && strcmp(Passive_Host[Old_Host_Pointer].name, "")) ? Passive_Host[Old_Host_Pointer].name : Passive_Host[Old_Host_Pointer].ip);
       wbkgdset(main_window, COLOR_PAIR(MAIN_COLOR));
       wattroff(main_window, A_BOLD);
       wmove(main_window, Old_Host_Pointer-Host_Base_Pointer, LeftMargin + 23);  waddch(main_window, ACS_VLINE);
       wprintw(main_window, " %2s ",Passive_Host[Old_Host_Pointer].type);
       wmove(main_window, Old_Host_Pointer-Host_Base_Pointer, LeftMargin + 28);  waddch(main_window, ACS_VLINE);
-      wprintw(main_window, " %s", Passive_Host[Old_Host_Pointer].os);
+      wprintw(main_window, " %-45s", Passive_Host[Old_Host_Pointer].os);
    }
 
    if (has_colors())
@@ -253,12 +283,12 @@ void Interface_Passive_PointItem(char direction)
 
    wmove(main_window, Host_Pointer - Host_Base_Pointer, LeftMargin);
    whline(main_window, ' ', W_SELECTCONN);                           //select new position
-   wprintw(main_window, "%3d) %-15s  ", Host_Pointer+1, (showname && strcmp(Passive_Host[Host_Pointer].name, "")) ? Passive_Host[Host_Pointer].name : Passive_Host[Host_Pointer].ip);
+   wprintw(main_window, "%3d) %-15s   ", Host_Pointer+1, (showname && strcmp(Passive_Host[Host_Pointer].name, "")) ? Passive_Host[Host_Pointer].name : Passive_Host[Host_Pointer].ip);
    wbkgdset(main_window, COLOR_PAIR(POINT_COLOR));
    wmove(main_window, Host_Pointer-Host_Base_Pointer, LeftMargin + 23);  waddch(main_window, ACS_VLINE);
    wprintw(main_window, " %2s ",Passive_Host[Host_Pointer].type);
    wmove(main_window, Host_Pointer-Host_Base_Pointer, LeftMargin + 28);  waddch(main_window, ACS_VLINE);
-   wprintw(main_window, " %s", Passive_Host[Host_Pointer].os);
+   wprintw(main_window, " %-45s", Passive_Host[Host_Pointer].os);
 
    werase(bottom_window);
    if (Passive_Host[Host_Pointer].os[0] == 0 && Passive_Host[Host_Pointer].os[1] != 0)
@@ -280,9 +310,7 @@ void Interface_Passive_MakeReport(char mode)
    WINDOW *message_window;
    char mess[17] = "making report...";
 
-#ifdef DEBUG
-   Debug_msg("Interface_Passive_MakeReport");
-#endif
+   DEBUG_MSG("Interface_Passive_MakeReport");
 
    message_window = newwin(5, strlen(mess) + 4,0,0);
    mvwin(message_window, W_MAINY1+(W_MAINY2-W_MAINY1)/2-2, W_MAINX2/2 - (strlen(mess) + 4)/2 );
@@ -316,9 +344,7 @@ void Interface_Passive_ShowDetails(int i)
    char found = 0;
    struct open_ports *current;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Passive_ShowDetails");
-#endif
+   DEBUG_MSG("Interface_Passive_ShowDetails");
 
    LIST_FOREACH(current, &Passive_Host[i].tcp_ports, next)    // enlarge the window to contain the open ports...
       if (current != LIST_FIRST(&Passive_Host[i].tcp_ports))
@@ -351,7 +377,7 @@ void Interface_Passive_ShowDetails(int i)
          wprintw(detail_window, " **** THIS HOST IS A GATEWAY FOR IPs LIKE %s ****\n\n", Passive_Host[i].gwforthis);
 
       if (!strcmp(Passive_Host[i].type, "RT"))
-         wprintw(detail_window, " **** THIS HOST ATCS AS A ROUTER FOR THE LAN ****\n\n");
+         wprintw(detail_window, " **** THIS HOST ACTS AS A ROUTER FOR THE LAN ****\n\n");
 
       if (!strcmp(Passive_Host[i].type, "NL"))
          wprintw(detail_window, " **** THIS HOST DOESN'T BELONG TO THE NETMASK ****\n\n");
@@ -489,9 +515,7 @@ void Interface_Passive_Submit(int j)
    char host[] = "ettercap.sourceforge.net";
    char page[] = "/index.php?s=stuff&p=fingerprint";
 
-#ifdef DEBUG
-   Debug_msg("Interface_Passive_Submit -- [%s]", Passive_Host[j].fingerprint);
-#endif
+   DEBUG_MSG("Interface_Passive_Submit -- [%s]", Passive_Host[j].fingerprint);
 
    fingerprint = strdup(Passive_Host[j].fingerprint);
    ip = strdup(Passive_Host[j].ip);
@@ -527,7 +551,12 @@ void Interface_Passive_Submit(int j)
          int x=0,y=0;
          getyx(w_submit, y, x);
          wmove(w_submit, y, --x);
-         pechochar(w_submit, ' ');
+         #ifdef HAVE_PDCURSES
+            waddch(w_submit, ' ');
+            wrefresh(w_submit);
+         #else
+            pechochar(w_submit, ' ');
+         #endif
          wmove(w_submit, y, x);
          OS[p_text] = 0;
          if ( p_text > 0 ) p_text--;
@@ -542,7 +571,12 @@ void Interface_Passive_Submit(int j)
       }
       else
       {
-         pechochar(w_submit, c);
+         #ifdef HAVE_PDCURSES
+            waddch(w_submit, c);
+            wrefresh(w_submit);
+         #else
+            pechochar(w_submit, c);
+         #endif
          if (p_text < 60) OS[p_text++] = c;
       }
 
@@ -559,9 +593,7 @@ void Interface_Passive_Submit(int j)
    if ( !strcmp(OS, "") || !strcmp(fingerprint, "") )
       return;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Passive_Submit - remote - %s %s", fingerprint, OS);
-#endif
+   DEBUG_MSG("Interface_Passive_Submit - remote - %s %s", fingerprint, OS);
 
    for (i=0; i<60; i++)
       if (OS[i] == ' ') OS[i] = '+';
@@ -586,9 +618,7 @@ void Interface_Passive_Submit(int j)
                                     "User-Agent: %s (%s).\r\n"
                                     "\r\n", page, data, host, PROGRAM, VERSION );
 
-#ifdef DEBUG
-   Debug_msg("Interface_Passive_Submit -- %s", getmsg);
-#endif
+   DEBUG_MSG("Interface_Passive_Submit -- %s", getmsg);
 
 
    Inet_Http_Send(sock, getmsg);
@@ -604,9 +634,7 @@ void Interface_Passive_Submit(int j)
 
    strlcpy(Passive_Host[j].os, OS, 60);
 
-#ifdef DEBUG
-   Debug_msg("Interface_Passive_Submit - local - [%s] [%s] [%s]", fingerprint, OS, Passive_Host[j].os);
-#endif
+   DEBUG_MSG("Interface_Passive_Submit - local - [%s] [%s] [%s]", fingerprint, OS, Passive_Host[j].os);
 
    f_os = fopen( "./" OS_FILE, "r");
    if (f_os == NULL)
@@ -675,13 +703,17 @@ void Interface_Passive_Run(void)
 {
    int KeyPress;
    pthread_t Dryad_pid;
+   u_short passlist_csum = 0;
+   u_short hash = 0;
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+   struct pollfd poll_fd;
+#else
    fd_set msk_fd;
    struct timeval TimeOut;
-
-#ifdef DEBUG
-   Debug_msg("Interface_Passive_Run");
 #endif
 
+   DEBUG_MSG("Interface_Passive_Run");
+
    init_pair(W_MAIN_COLOR, COLOR_WHITE, COLOR_BLUE);
    init_pair(W_POINT_COLOR, COLOR_WHITE, COLOR_CYAN);
    init_pair(N_MAIN_COLOR, COLOR_BLACK, COLOR_BLUE);
@@ -706,7 +738,11 @@ void Interface_Passive_Run(void)
    mvwprintw(top_window,0,25, "<"); waddch(top_window, ACS_HLINE); waddch(top_window, ACS_HLINE); waddch(top_window, ACS_URCORNER);
    wmove(top_window, 1,28); waddch(top_window, ACS_LTEE); waddch(top_window, ACS_HLINE);
    wbkgdset(top_window, COLOR_PAIR(BOTTOM_COLOR));
-   wprintw(top_window, " dryad (passive scanning) "); waddch(top_window, ACS_HLINE); wprintw(top_window, " %s", PROGRAM);
+   if (!Options.writedump && Options.dumpfile) {
+      wprintw(top_window, " dryad (OffLine from [%s]) ", Options.dumpfile);
+   } else {
+      wprintw(top_window, " dryad (passive scanning) "); waddch(top_window, ACS_HLINE); wprintw(top_window, " %s", PROGRAM);
+   }
    wbkgdset(top_window, COLOR_PAIR(HELP_COLOR));
    mvwprintw(top_window,2,25, "<"); waddch(top_window, ACS_HLINE); waddch(top_window, ACS_HLINE); waddch(top_window, ACS_LRCORNER);
    wbkgdset(top_window, COLOR_PAIR(BOTTOM_COLOR));
@@ -722,18 +758,32 @@ void Interface_Passive_Run(void)
 
    Dryad_pid = Dryad_Run();
 
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+   poll_fd.fd = 0;
+   poll_fd.events = POLLIN;
+#else
    memset(&TimeOut, 0, sizeof(TimeOut));  //  timeout = 0
    FD_ZERO(&msk_fd);
+#endif
 
    loop
    {
+
+      hash = Inet_Forge_Checksum((u_short *)Passive_Host, 0xe77e, sizeof(PASSIVE_DATA)*number_of_passive_hosts, 0, 0);
+
+      if (passlist_csum != hash && number_of_passive_hosts > 0) {    // check if the list has changed by calculating its checksum
+         Interface_Passive_InitList();
+         passlist_csum = hash;
+      }
+
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+      poll(&poll_fd, 1, 1);
+      if (poll_fd.revents & POLLIN)
+#else
       FD_SET(0, &msk_fd);
-
       select(FOPEN_MAX, &msk_fd, (fd_set *) 0, (fd_set *) 0, &TimeOut);
-
-      Interface_Passive_InitList();
-
       if (FD_ISSET(0, &msk_fd))
+#endif
       {
 
          KeyPress = wgetch(main_window);
@@ -776,6 +826,7 @@ void Interface_Passive_Run(void)
             case 'D':
             case 'd':
                      Interface_Passive_Showname();
+                     Interface_Passive_InitList();
                      break;
 
 
@@ -788,7 +839,7 @@ void Interface_Passive_Run(void)
             case 'h':{
                         static char *help[] = {
                            "[qQ][F10] - quit",
-                           "[return]  - show detail for the selected host",
+                           "[return]  - show details for the selected host",
                            "[dD]      - toggle show name or IP",
                            "[l ]      - log collected info to a file (only local IP)",
                            "[L ]      - log all collected info to a file",
@@ -825,9 +876,8 @@ void Interface_Passive_Run(void)
                      Host_Pointer = 0;
                      showname = 0;
                      Options.passive = 0;
-                     #ifdef DEBUG
-                        Debug_msg("Interface_Passive_END");
-                     #endif
+                     read_from_dump_flag = 0;  // permit a new scan of the offline file
+                     DEBUG_MSG("Interface_Passive_END");
                      return;
                      break;
          }
@@ -843,3 +893,6 @@ void Interface_Passive_Run(void)
 #endif
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
