@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_plugins.c,v 1.7 2002/02/10 10:07:49 alor Exp $
+    $Id: ec_interface_plugins.c,v 1.11 2002/04/06 08:55:58 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -33,6 +33,11 @@
 
 
 #include <ctype.h>
+#if defined(HAVE_SYS_POLL_H)
+	#include <sys/poll.h>
+#elif defined (HAVE_POLL_H)
+	#include <poll.h>
+#endif
 
 #include "include/ec_interface.h"
 #include "include/ec_plugins.h"
@@ -53,6 +58,7 @@
 
 void Interface_Plugins_Run(void);
 void Interface_Plugins_Redraw(void);
+void Interface_Plugins_PluginOutput_Redraw(void);
 void Interface_Plugins_Winch(void);
 char Interface_Plugins_PopUp(char *question);
 void Interface_Plugins_PointItem(char direction);
@@ -93,9 +99,7 @@ short scroll_yp, scroll_out_yp;
 
 void Interface_Plugins_Winch(void)  // TODO better handling...
 {
-#ifdef DEBUG
-   Debug_msg("Interface_Plugin_Winch\tTODO");
-#endif
+   DEBUG_MSG("Interface_Plugin_Winch\tTODO");
 
    Interface_Plugins_Redraw();
 }
@@ -106,9 +110,7 @@ void Interface_Plugins_Redraw(void)
 
    Interface_Redraw();
 
-#ifdef DEBUG
-   Debug_msg("Interface_Plugins_Redraw");
-#endif
+   DEBUG_MSG("Interface_Plugins_Redraw");
 
    redrawwin(b_plugin_window);
 
@@ -120,6 +122,24 @@ void Interface_Plugins_Redraw(void)
 }
 
 
+void Interface_Plugins_PluginOutput_Redraw(void)
+{
+
+   Interface_Redraw();
+
+   DEBUG_MSG("Interface_Plugins_PluginOutput_Redraw");
+
+   redrawwin(o_win);
+
+   wnoutrefresh(o_win);
+   pnoutrefresh(output_window, scroll_out_yp, 0, 1, 2, W_MAINY2-1 , W_MAINX2 - 2);
+
+   doupdate();
+
+}
+
+
+
 char Interface_Plugins_PopUp(char *question)
 {
    WINDOW *question_window;
@@ -140,9 +160,7 @@ char Interface_Plugins_PopUp(char *question)
 
    doupdate();
 
-#ifdef DEBUG
-   Debug_msg("Interface_PLugins_PopUp returns -- %c", answer);
-#endif
+   DEBUG_MSG("Interface_PLugins_PopUp returns -- %c", answer);
 
    return answer;
 }
@@ -322,9 +340,7 @@ void Interface_Plugins_SelectItem(void)
 {
    int KeyPress;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Plugins_SelectItem");
-#endif
+   DEBUG_MSG("Interface_Plugins_SelectItem");
 
    if (number_of_plugins == 0) return; // no plugin... no action... ;)
 
@@ -419,13 +435,22 @@ void Interface_Plugins_Output_Scroll(short direction)
 
 void Interface_Plugins_Output(void)
 {
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+	struct pollfd poll_fd;
+#else
    fd_set msk_fd;
    struct timeval TimeOut;
+#endif
    short saved_yp = scroll_out_yp;
    int KeyPress;
 
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+   poll_fd.fd = 0;
+   poll_fd.events = POLLIN;
+#else
    memset(&TimeOut, 0, sizeof(TimeOut));  //  timeout = 0
    FD_ZERO(&msk_fd);
+#endif
 
    if (o_win != NULL)
    {
@@ -453,11 +478,14 @@ void Interface_Plugins_Output(void)
 
    loop
    {
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+      poll(&poll_fd, 1, 1);
+      if (poll_fd.revents & POLLIN)
+#else
       FD_SET(0, &msk_fd);
-
       select(FOPEN_MAX, &msk_fd, (fd_set *) 0, (fd_set *) 0, &TimeOut);
-
       if (FD_ISSET(0, &msk_fd))
+#endif
       {
          KeyPress = wgetch(o_win);
 
@@ -515,17 +543,18 @@ void Interface_Plugins_Output(void)
 
                case KEY_F(1):
                case 'H':
-               case 'h':{
-                           static char *help[] = {
-                              "[qQ][F10] - quit",
-                              "[arrows]  - scroll the output",
-                              "[dD]      - dump plugins output to a file",
-                              "[hH]      - this help screen",
-                              NULL};
-                           Interface_HelpWindow(help);
-                        }
-                  Interface_Plugins_Redraw();
-                  break;
+               case 'h':
+                     {
+                        static char *help[] = {
+                           "[qQ][F10] - quit",
+                           "[arrows]  - scroll the output",
+                           "[dD]      - dump plugins output to a file",
+                           "[hH]      - this help screen",
+                           NULL};
+                        Interface_HelpWindow(help);
+                     }
+                     Interface_Plugins_PluginOutput_Redraw();
+                     break;
 
                case KEY_F(10):
                case 'Q':
@@ -607,9 +636,7 @@ void Interface_Plugins_Run(void)
 {
    int KeyPress, i;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Plugins_Run");
-#endif
+   DEBUG_MSG("Interface_Plugins_Run");
 
    P_Sel_Number = Sel_Number - 4;
 
@@ -692,9 +719,7 @@ void Interface_Plugins_Run(void)
          case 'q':
          case 'Q':
          case KEY_F(10):
-                  #ifdef DEBUG
-                     Debug_msg("Interface_Plugin_Run_END");
-                  #endif
+                  DEBUG_MSG("Interface_Plugin_Run_END");
 
                   for(i=0; i< number_of_plugins; i++)    // activate the plugins
                      if (Plugins_Array[i].status == 'A')
@@ -720,3 +745,6 @@ void Interface_Plugins_Run(void)
 
 /* EOF */
 
+
+// vim:ts=3:expandtab
+
