@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_sniff.c,v 1.13 2002/02/11 20:31:56 alor Exp $
+    $Id: ec_interface_sniff.c,v 1.25 2002/04/18 17:39:10 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -30,6 +30,12 @@
    #include <curses.h>
 #endif
 
+#if defined(HAVE_SYS_POLL_H)
+   #include <sys/poll.h>
+#elif defined (HAVE_POLL_H)
+   #include <poll.h>
+#endif
+
 #include "include/ec_interface.h"
 #include "include/ec_interface_sniff_data.h"
 #include "include/ec_interface_factory.h"
@@ -44,7 +50,6 @@
 #include "include/ec_inet_forge.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_buffer.h"
-#include "include/ec_error.h"
 #include "include/ec_logtofile.h"
 #include "include/ec_thread.h"
 
@@ -72,7 +77,6 @@ void Interface_Sniff_InitList(void);
 void Interface_Sniff_RefreshList(void);
 void Interface_Sniff_KillConn(void);
 void Interface_Sniff_ActiveDissecor(short mode);
-void * Interface_Sniff_Timeouter(void *dummy);
 
 // global variables
 
@@ -90,6 +94,17 @@ extern int Sel_Number;
 
 extern short inject;
 
+extern char read_from_dump_flag; // from inet
+
+
+#ifdef CYGWIN
+   /*
+    * it seems that if we call douptade too frequently the windows terminal freeze up
+    * so we introduce a minimum delay between doupdate() calls.
+    */
+   int last_do_update;
+#endif
+
 //---------------------------
 
 
@@ -98,6 +113,7 @@ void Interface_Sniff_InitList(void)
    int j;
    int Conn_Top_Pointer;
    char info[250];
+   short info_len, info_pos;
 
    if (has_colors())
       wbkgdset(main_window, COLOR_PAIR(MAIN_COLOR));
@@ -109,6 +125,12 @@ void Interface_Sniff_InitList(void)
    if (number_of_connections == 0)     // no connection... no action... ;)
    {
       wnoutrefresh(main_window);
+		#ifdef CYGWIN
+   	if (GetTickCount() - last_do_update <= MIN_DO_UPDATE_DELAY)
+      	return;  // do not call doupdate() at fast time inteval
+
+   	last_do_update = GetTickCount();
+		#endif
       doupdate();
       return;
    }
@@ -118,12 +140,15 @@ void Interface_Sniff_InitList(void)
    for(j=Conn_Base_Pointer; j<Conn_Top_Pointer; j++)     // prints connections within the main_window height
    {
       wmove(main_window, j-Conn_Base_Pointer, LeftMargin );
-      wprintw(main_window, "%3d) %15s:%d", j+1, Conn_Between_Hosts[j].source_ip, Conn_Between_Hosts[j].source_port);
-      mvwprintw(main_window, j-Conn_Base_Pointer, 28," <--> %15s:%d", Conn_Between_Hosts[j].dest_ip , Conn_Between_Hosts[j].dest_port);
+      wprintw(main_window, "%3d) %15s:%-5d  ", j+1, Conn_Between_Hosts[j].source_ip, Conn_Between_Hosts[j].source_port);
+      mvwprintw(main_window, j-Conn_Base_Pointer, 28," <--> %15s:%-5d  ", Conn_Between_Hosts[j].dest_ip , Conn_Between_Hosts[j].dest_port);
       wmove(main_window, j-Conn_Base_Pointer, LeftMargin + 56);  waddch(main_window, ACS_VLINE);
-      wprintw(main_window, " %s", Conn_Between_Hosts[j].status);
+      wprintw(main_window, " %6s ", Conn_Between_Hosts[j].status);
       wmove(main_window, j-Conn_Base_Pointer, LeftMargin + 65);  waddch(main_window, ACS_VLINE);
-      wprintw(main_window, " %s", Conn_Between_Hosts[j].type);
+
+   	snprintf(info, W_MAINX2 - 68, "%s", Conn_Between_Hosts[j].type);
+
+      wprintw(main_window, " %-10s ", info);
    }
 
    if (has_colors())
@@ -131,27 +156,39 @@ void Interface_Sniff_InitList(void)
    else
       wattron(main_window,A_REVERSE);
 
-
    wmove(main_window, Conn_Pointer - Conn_Base_Pointer, LeftMargin );
    whline(main_window, ' ', W_SELECTCONN);
-   wprintw(main_window, "%3d) %15s:%d", Conn_Pointer+1, Conn_Between_Hosts[Conn_Pointer].source_ip, Conn_Between_Hosts[Conn_Pointer].source_port);
-   mvwprintw(main_window, Conn_Pointer-Conn_Base_Pointer, 28," <--> %15s:%d", Conn_Between_Hosts[Conn_Pointer].dest_ip , Conn_Between_Hosts[Conn_Pointer].dest_port);
+   wprintw(main_window, "%3d) %15s:%-5d  ", Conn_Pointer+1, Conn_Between_Hosts[Conn_Pointer].source_ip, Conn_Between_Hosts[Conn_Pointer].source_port);
+   mvwprintw(main_window, Conn_Pointer-Conn_Base_Pointer, 28," <--> %15s:%-5d  ", Conn_Between_Hosts[Conn_Pointer].dest_ip , Conn_Between_Hosts[Conn_Pointer].dest_port);
    wmove(main_window, Conn_Pointer-Conn_Base_Pointer, LeftMargin + 56);  waddch(main_window, ACS_VLINE);
-   wprintw(main_window, " %s", Conn_Between_Hosts[Conn_Pointer].status);
+   wprintw(main_window, " %6s ", Conn_Between_Hosts[Conn_Pointer].status);
    wmove(main_window, Conn_Pointer - Conn_Base_Pointer, LeftMargin + 65); waddch(main_window, ACS_VLINE);
-   wprintw(main_window, " %s", Conn_Between_Hosts[Conn_Pointer].type);
+   snprintf(info, W_MAINX2 - 68, "%s", Conn_Between_Hosts[Conn_Pointer].type);
+   wprintw(main_window, " %-10s ", info);
 
    werase(bottom_window);
    mvwprintw(bottom_window, 0, 1, " %s", Conn_Between_Hosts[Conn_Pointer].user);
    mvwprintw(bottom_window, 1, 1, " %s", Conn_Between_Hosts[Conn_Pointer].pass);
-   snprintf(info, W_MAINX2 - 28, "%s", Conn_Between_Hosts[Conn_Pointer].info);
-   if (strlen(info)+1 == W_MAINX2 - 28)
-      mvwprintw(bottom_window, 1, 20, " %s->", info);
-   else
-      mvwprintw(bottom_window, 1, 20, " %s", info);
 
+   
+   info_pos = (strlen(Conn_Between_Hosts[Conn_Pointer].pass)+1 > 20) ? strlen(Conn_Between_Hosts[Conn_Pointer].pass)+4 : 20;
+   info_len = W_MAINX2 - info_pos - 5;
+   
+   snprintf(info, info_len, "%s", Conn_Between_Hosts[Conn_Pointer].info);
+   if (strlen(info)+1 == info_len)
+      mvwprintw(bottom_window, 1, info_pos, " %s->", info);
+   else if (strlen(info))
+      mvwprintw(bottom_window, 1, info_pos, " %s", info);
+   
    wnoutrefresh(bottom_window);
    wnoutrefresh(main_window);
+
+#ifdef CYGWIN
+   if (GetTickCount() - last_do_update <= MIN_DO_UPDATE_DELAY)
+      return;  // do not call doupdate() at fast time inteval
+
+   last_do_update = GetTickCount();
+#endif
    doupdate();
 
 }
@@ -163,9 +200,19 @@ void Interface_Sniff_PointItem(char direction)
 
    int Old_Conn_Pointer;
    char info[250];
+   short info_len, info_pos;
 
    if (number_of_connections == 0) return;   // no connection... no action... ;)
 
+#ifdef CYGWIN
+   if (GetTickCount() - last_do_update <= MIN_DO_UPDATE_DELAY)
+      // do not call doupdate() at fast time inteval
+		return;
+
+   last_do_update = GetTickCount();
+#endif
+
+
    Old_Conn_Pointer = Conn_Pointer;
 
    Conn_Pointer += direction;
@@ -201,12 +248,14 @@ void Interface_Sniff_PointItem(char direction)
       wmove(main_window, Old_Conn_Pointer - Conn_Base_Pointer, LeftMargin);
       whline(main_window,' ', W_SELECTCONN);                         //deletes the previous position
 
-      wprintw(main_window, "%3d) %15s:%d", Old_Conn_Pointer+1, Conn_Between_Hosts[Old_Conn_Pointer].source_ip, Conn_Between_Hosts[Old_Conn_Pointer].source_port);
-      mvwprintw(main_window, Old_Conn_Pointer-Conn_Base_Pointer, 28," <--> %15s:%d", Conn_Between_Hosts[Old_Conn_Pointer].dest_ip , Conn_Between_Hosts[Old_Conn_Pointer].dest_port);
+      wprintw(main_window, "%3d) %15s:%-5d  ", Old_Conn_Pointer+1, Conn_Between_Hosts[Old_Conn_Pointer].source_ip, Conn_Between_Hosts[Old_Conn_Pointer].source_port);
+      mvwprintw(main_window, Old_Conn_Pointer-Conn_Base_Pointer, 28," <--> %15s:%-5d  ", Conn_Between_Hosts[Old_Conn_Pointer].dest_ip , Conn_Between_Hosts[Old_Conn_Pointer].dest_port);
       wmove(main_window, Old_Conn_Pointer - Conn_Base_Pointer, LeftMargin + 56);  waddch(main_window, ACS_VLINE);
-      wprintw(main_window, " %s", Conn_Between_Hosts[Old_Conn_Pointer].status);
+      wprintw(main_window, " %6s ", Conn_Between_Hosts[Old_Conn_Pointer].status);
       wmove(main_window, Old_Conn_Pointer - Conn_Base_Pointer, LeftMargin + 65);  waddch(main_window, ACS_VLINE);
-      wprintw(main_window, " %s", Conn_Between_Hosts[Old_Conn_Pointer].type);
+
+      snprintf(info, W_MAINX2 - 68, "%s", Conn_Between_Hosts[Old_Conn_Pointer].type);
+   	wprintw(main_window, " %-10s ", info);
    }
 
    if (has_colors())
@@ -217,24 +266,31 @@ void Interface_Sniff_PointItem(char direction)
    wmove(main_window, Conn_Pointer - Conn_Base_Pointer, LeftMargin);
    whline(main_window, ' ', W_SELECTCONN);                           //select new position
 
-   wprintw(main_window, "%3d) %15s:%d", Conn_Pointer+1, Conn_Between_Hosts[Conn_Pointer].source_ip, Conn_Between_Hosts[Conn_Pointer].source_port);
-   mvwprintw(main_window, Conn_Pointer-Conn_Base_Pointer, 28," <--> %15s:%d", Conn_Between_Hosts[Conn_Pointer].dest_ip , Conn_Between_Hosts[Conn_Pointer].dest_port);
+   wprintw(main_window, "%3d) %15s:%-5d  ", Conn_Pointer+1, Conn_Between_Hosts[Conn_Pointer].source_ip, Conn_Between_Hosts[Conn_Pointer].source_port);
+   mvwprintw(main_window, Conn_Pointer-Conn_Base_Pointer, 28," <--> %15s:%-5d  ", Conn_Between_Hosts[Conn_Pointer].dest_ip , Conn_Between_Hosts[Conn_Pointer].dest_port);
    wmove(main_window, Conn_Pointer - Conn_Base_Pointer, LeftMargin + 56);  waddch(main_window, ACS_VLINE);
-   wprintw(main_window, " %s", Conn_Between_Hosts[Conn_Pointer].status);
+   wprintw(main_window, " %6s ", Conn_Between_Hosts[Conn_Pointer].status);
    wmove(main_window, Conn_Pointer - Conn_Base_Pointer, LeftMargin + 65);  waddch(main_window, ACS_VLINE);
-   wprintw(main_window, " %s", Conn_Between_Hosts[Conn_Pointer].type);
+
+   snprintf(info, W_MAINX2 - 68, "%s", Conn_Between_Hosts[Conn_Pointer].type);
+   wprintw(main_window, " %-10s ", info);
 
    werase(bottom_window);
    mvwprintw(bottom_window, 0, 1, " %s", Conn_Between_Hosts[Conn_Pointer].user);
    mvwprintw(bottom_window, 1, 1, " %s", Conn_Between_Hosts[Conn_Pointer].pass);
-   snprintf(info, W_MAINX2 - 28, "%s", Conn_Between_Hosts[Conn_Pointer].info);
-   if (strlen(info)+1 == W_MAINX2 - 28)
-      mvwprintw(bottom_window, 1, 20, " %s->", info);
-   else
-      mvwprintw(bottom_window, 1, 20, " %s", info);
+
+   info_pos = (strlen(Conn_Between_Hosts[Conn_Pointer].pass)+1 > 20) ? strlen(Conn_Between_Hosts[Conn_Pointer].pass)+4 : 20;
+   info_len = W_MAINX2 - info_pos - 5;
+   
+   snprintf(info, info_len, "%s", Conn_Between_Hosts[Conn_Pointer].info);
+   if (strlen(info)+1 == info_len)
+      mvwprintw(bottom_window, 1, info_pos, " %s->", info);
+   else if (strlen(info))
+      mvwprintw(bottom_window, 1, info_pos, " %s", info);
 
    wnoutrefresh(bottom_window);
    wnoutrefresh(main_window);
+
    doupdate();
 }
 
@@ -244,9 +300,7 @@ void Interface_Sniff_RefreshList(void)
 {
    WINDOW *message_window;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Sniff_RefreshList");
-#endif
+   DEBUG_MSG("Interface_Sniff_RefreshList");
 
    message_window = newwin(5, strlen("updating list...") + 4,0,0);
    mvwin(message_window, W_MAINY1+(W_MAINY2-W_MAINY1)/2-2, W_MAINX2/2 - (strlen("updating list...") + 4)/2 );
@@ -268,9 +322,7 @@ void Interface_Sniff_RefreshList(void)
 
    doupdate();
 
-#ifdef DEBUG
-   Debug_msg("Interface_Sniff_RefreshList -- end");
-#endif
+   DEBUG_MSG("Interface_Sniff_RefreshList -- end");
 }
 
 
@@ -280,16 +332,14 @@ void Interface_Sniff_KillConn(void)
 
    if (Conn_Between_Hosts[Conn_Pointer].proto == 'U')
    {
-      Interface_PopUp("Trying to kill an UDP connection ?!? Ehi Kiddie, go home !!");
+      Interface_PopUp("Trying to kill an UDP connection ?!? Hey Kiddie, go home !!");
       return;
    }
 
-#ifdef DEBUG
-   Debug_msg("Interface_Sniff_KillConn -- %s:%d -> %s:%d ", Conn_Between_Hosts[Conn_Pointer].source_ip,
+   DEBUG_MSG("Interface_Sniff_KillConn -- %s:%d -> %s:%d ", Conn_Between_Hosts[Conn_Pointer].source_ip,
                                                             Conn_Between_Hosts[Conn_Pointer].source_port,
                                                             Conn_Between_Hosts[Conn_Pointer].dest_ip,
                                                             Conn_Between_Hosts[Conn_Pointer].dest_port );
-#endif
 
    kill_data.source_ip = inet_addr(Conn_Between_Hosts[Conn_Pointer].source_ip);
    kill_data.dest_ip = inet_addr(Conn_Between_Hosts[Conn_Pointer].dest_ip);
@@ -305,9 +355,7 @@ void Interface_Sniff_KillConn(void)
 void Interface_Sniff_ActiveDissecor(short mode)
 {
 
-#ifdef DEBUG
-   Debug_msg("Interface_Sniff_ActiveDissecor %d", active_dissector);
-#endif
+   DEBUG_MSG("Interface_Sniff_ActiveDissecor %d", active_dissector);
 
    wbkgdset(top_window, COLOR_PAIR(HELP_COLOR));
    mvwprintw(top_window, 2, 31, "Active Dissector: ");
@@ -331,46 +379,6 @@ void Interface_Sniff_ActiveDissecor(short mode)
 }
 
 
-void * Interface_Sniff_Timeouter(void *dummy)      // Timeouter thread
-{
-   int i;
-   time_t now;
-   extern pthread_mutex_t connection_mutex;
-
-   loop
-   {
-      pthread_testcancel();
-
-      if (number_of_connections <= 0)
-      {
-         usleep(5000);
-         continue;
-      }
-
-      now = time(NULL);
-
-      pthread_mutex_lock(&connection_mutex);
-
-      for (i = 0; i < number_of_connections; i++)
-      {
-         if (Conn_Between_Hosts[i].proto == 'T')
-         {
-            if (!strcmp(Conn_Between_Hosts[i].status, "ACTIVE") && Conn_Between_Hosts[i].timestamp <= now - CONN_TIME_SILENT)
-               strcpy(Conn_Between_Hosts[i].status, "silent");
-
-            if (strcmp(Conn_Between_Hosts[i].status, "KILLED") &&
-                strcmp(Conn_Between_Hosts[i].status, "CLOSED") && Conn_Between_Hosts[i].timestamp <= now - CONN_TIME_TIMEOUT) // 10 min of timeout
-               strcpy(Conn_Between_Hosts[i].status, "timeout");
-         }
-      }
-
-      pthread_mutex_unlock(&connection_mutex);
-
-      sleep(2);
-   }
-}
-
-
 
 void Interface_Sniff_Run(short mode)
 {
@@ -379,13 +387,17 @@ void Interface_Sniff_Run(short mode)
    #if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
       pthread_t Grell_pid = 0;
    #endif
+   u_short connlist_csum = 0;
+   u_short hash = 0;
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+   struct pollfd poll_fd;
+#else
    fd_set msk_fd;
    struct timeval TimeOut;
-
-#ifdef DEBUG
-   Debug_msg("Interface_Sniff_Run -- mode %d", mode);
 #endif
 
+   DEBUG_MSG("Interface_Sniff_Run -- mode %d", mode);
+
    if (pipe_with_illithid_data == -1) pipe_with_illithid_data = Buffer_Create(1.0e6);
    if (pipe_with_plugins == -1) pipe_with_plugins = Buffer_Create(1.5e5);  // 150 Kbyte
 
@@ -447,24 +459,37 @@ void Interface_Sniff_Run(short mode)
 
    if (Options.passive) Interface_Passive_Run();
 
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+   poll_fd.fd = 0;
+   poll_fd.events = POLLIN;
+#else
    memset(&TimeOut, 0, sizeof(TimeOut));  //  timeout = 0
    FD_ZERO(&msk_fd);
+#endif
 
-   time_pid = ECThread_create("timeouter", &Interface_Sniff_Timeouter, NULL);
+   time_pid = ECThread_create("timeouter", &DecodeData_Connection_Timeouter, NULL);
 
    loop
    {
-      FD_SET(0, &msk_fd);
+      hash = Inet_Forge_Checksum((u_short *)Conn_Between_Hosts, 0xe77e, sizeof(CONNECTION)*number_of_connections, 0, 0);
 
-      select(FOPEN_MAX, &msk_fd, (fd_set *) 0, (fd_set *) 0, &TimeOut);
-
-      Interface_Sniff_InitList();
+      if (connlist_csum != hash && number_of_connections > 0) {   // check if the list has changed by calculating its checksum
+         Interface_Sniff_InitList();
+         connlist_csum = hash;
+      }
 
 #ifdef PERMIT_PLUGINS
       Interface_Plugins_PluginOutput();
 #endif
 
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+      poll(&poll_fd, 1, 1);
+      if (poll_fd.revents & POLLIN)
+#else
+      FD_SET(0, &msk_fd);
+      select(FOPEN_MAX, &msk_fd, (fd_set *) 0, (fd_set *) 0, &TimeOut);
       if (FD_ISSET(0, &msk_fd))
+#endif
       {
 
 #ifdef PERMIT_PLUGINS
@@ -565,13 +590,17 @@ void Interface_Sniff_Run(short mode)
                      Interface_PopUp("Passwords dumped to %s", LogToFile_DumpPass());
                      break;
 
-#ifdef PERMIT_PLUGINS
             case 'P':
             case 'p':
+#ifdef PERMIT_PLUGINS
                      Interface_Plugins_Run();
                      Buffer_Flush(pipe_with_plugins);
+#else
+                     Interface_PopUp("Plugins NOT supported under your system !!");
+#endif
                      break;
-
+                     
+#ifdef PERMIT_PLUGINS
             case 'I':
             case 'i':
                      Interface_Plugins_Output();
@@ -584,9 +613,7 @@ void Interface_Sniff_Run(short mode)
                      if (mode <= PUBLICARP)
                      {
                         active_dissector = (active_dissector) ? 0 : 1;     // activate/deactivate active dissector (arp based)
-                        #ifdef DEBUG
-                           Debug_msg("\tactive_dissector %d", active_dissector);
-                        #endif
+                        DEBUG_MSG("\tactive_dissector %d", active_dissector);
                         Interface_Sniff_ActiveDissecor(mode);
                      }
                      else
@@ -622,8 +649,8 @@ void Interface_Sniff_Run(short mode)
                            "[fF]      - set/edit filters chains",
                            "[lL]      - log all collected passwords to a file",
                            "[kK]      - kill the connection (be careful !)",
-#ifdef PERMIT_PLUGINS
                            "[pP]      - plugin management",
+#ifdef PERMIT_PLUGINS
                            "[iI]      - plugin output window",
 #endif
                            "[oO]      - passive scanning of the LAN",
@@ -640,7 +667,7 @@ void Interface_Sniff_Run(short mode)
                      if (inject == 1)
                      {
                         char answer;
-                        answer = Interface_PopUp("If U exit now some connections may be ReSeTted!! continue (y/n)?");
+                        answer = Interface_PopUp("If you exit now some connections may be ReSeT!! continue (y/n)?");
                         Interface_Redraw();
                         if ((answer != 'y') && (answer != 'Y'))
                            break;
@@ -669,23 +696,20 @@ void Interface_Sniff_Run(short mode)
                         wnoutrefresh(main_window);
                         inject = 0;
                      }
-                     #ifdef DEBUG
-                        Debug_msg("Interface_Sniff_END");
-                     #endif
+                     DEBUG_MSG("Interface_Sniff_END");
                      if (Options.silent) Interface_WExit("They are safe!!  for now... ");
                      werase(bottom_window);
                      wnoutrefresh(bottom_window);
                      doupdate();
                      Decodedata_RefreshConnectionList();
                      number_of_connections = -1;
+                     read_from_dump_flag = 0;  // permit a new rescan of the offline file
                      return;
                      break;
 
             case KEY_F(10):
-                     #ifdef DEBUG
-                        Debug_msg("Interface_Sniff_END");
-                        Debug_msg("Interface_Run_END");
-                     #endif
+                     DEBUG_MSG("Interface_Sniff_END");
+                     DEBUG_MSG("Interface_Run_END");
                      {
                         WINDOW *message_window;
                         char mess[29] = "shutting down all threads...";
@@ -712,9 +736,8 @@ void Interface_Sniff_Run(short mode)
                      Interface_WExit("They are safe!!  for now... ");
                      break;
          }
-      }
-      else  // workaround for the 100% CPU usage...
-         usleep(1);
+      } else
+         usleep(1000);  // workaround for the 100% CPU usage...
 
    }
 
@@ -725,3 +748,6 @@ void Interface_Sniff_Run(short mode)
 #endif
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
