@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_sniff_data.c,v 1.10 2002/02/10 10:07:49 alor Exp $
+    $Id: ec_interface_sniff_data.c,v 1.16 2002/04/18 17:03:17 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -31,6 +31,11 @@
 #endif
 
 #include <sys/types.h>
+#if defined(HAVE_SYS_POLL_H)
+	#include <sys/poll.h>
+#elif defined (HAVE_POLL_H)
+	#include <poll.h>
+#endif
 
 #include "include/ec_interface.h"
 #include "include/ec_interface_inject.h"
@@ -39,7 +44,6 @@
 #include "include/ec_dissector.h"
 #include "include/ec_illithid.h"
 #include "include/ec_buffer.h"
-#include "include/ec_error.h"
 #include "include/ec_inet_structures.h"
 
 #define PAD_BUFFER 1000        // buffered lines for sniffing
@@ -111,9 +115,7 @@ u_short portdest;
 
 void Interface_Sniff_Data_Winch(void)  // TODO better handling...
 {
-#ifdef DEBUG
-   Debug_msg("Interface_Sniff_Data_Winch\tTODO");
-#endif
+   DEBUG_MSG("Interface_Sniff_Data_Winch\tTODO");
 
    Interface_Sniff_Data_Redraw();
 }
@@ -124,9 +126,7 @@ void Interface_Sniff_Data_Redraw(void)
 
    Interface_Redraw();
 
-#ifdef DEBUG
-   Debug_msg("Interface_Sniff_Data_Redraw");
-#endif
+   DEBUG_MSG("Interface_Sniff_Data_Redraw");
 
    if (joined)
    {
@@ -221,9 +221,7 @@ void Interface_Sniff_Data_LogToFile(char proto)
    struct tm *dd;
    char date[8];
 
-#ifdef DEBUG
-   Debug_msg("Interface_Sniff_Data_LogToFile");
-#endif
+   DEBUG_MSG("Interface_Sniff_Data_LogToFile");
 
    tt = time(NULL);
    dd = localtime(&tt);
@@ -232,19 +230,19 @@ void Interface_Sniff_Data_LogToFile(char proto)
 
    if (joined)
    {
-      strcpy(question, "Do U want to log the trafic to this file ? (y/n)");
+      strcpy(question, "Do you want to log the trafic to this file ? (y/n)");
       snprintf(filename, sizeof(filename), "%s-%c-%s:%d-%s:%d-FULL.log", date, proto, ipsource, portsource, ipdest, portdest);
    }
    else
    {
       if (win_pointer == data_source_win)
       {
-         strcpy(question, "Do U want to log SOURCE-to-DEST to this file ? (y/n)");
+         strcpy(question, "Do you want to log SOURCE-to-DEST to this file ? (y/n)");
          snprintf(filename, sizeof(filename), "%s-%c-%s:%d-%s:%d.log", date, proto, ipsource, portsource, ipdest, portdest);
       }
       else
       {
-         strcpy(question, "Do U want to log DEST-to-SOURCE to this file ? (y/n)");
+         strcpy(question, "Do you want to log DEST-to-SOURCE to this file ? (y/n)");
          snprintf(filename, sizeof(filename), "%s-%c-%s:%d-%s:%d.log", date, proto, ipdest, portdest, ipsource, portsource);
       }
    }
@@ -324,8 +322,8 @@ void Interface_Sniff_Data_LogToFile(char proto)
 
 
 #ifdef DEBUG
-   Debug_msg("Interface_Sniff_Data_LogToFile returns -- %c", answer);
-   if ( (answer == 'y') || (answer == 'Y') ) Debug_msg("\t %s", filename);
+   DEBUG_MSG("Interface_Sniff_Data_LogToFile returns -- %c", answer);
+   if ( (answer == 'y') || (answer == 'Y') ) DEBUG_MSG("\t %s", filename);
 #endif
 
    Interface_Sniff_Data_Redraw();
@@ -335,9 +333,7 @@ void Interface_Sniff_Data_LogToFile(char proto)
 
 void Interface_Sniff_Data_StopCont(void)
 {
-#ifdef DEBUG
-   Debug_msg("Interface_Sniff_Data_StopCont");
-#endif
+   DEBUG_MSG("Interface_Sniff_Data_StopCont");
 
 
    if (stop == 0)
@@ -396,9 +392,7 @@ void Interface_Sniff_Data_StopCont(void)
 
 void Interface_Sniff_Data_View(short mode)
 {
-#ifdef DEBUG
-   Debug_msg("Interface_Sniff_Data_View -- %d", mode);
-#endif
+   DEBUG_MSG("Interface_Sniff_Data_View -- %d", mode);
 
 
    switch(mode)
@@ -484,6 +478,8 @@ void Interface_Sniff_Data_View(short mode)
                            scrollok(data_joined_win, TRUE);
                            wmove(data_joined, scroll_yj, 0);
 
+                           scrollok(data_joined, TRUE);
+
                            wnoutrefresh(data_joined_win);
                            pnoutrefresh(data_joined, scroll_yj, 0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 - 4);
                            doupdate();
@@ -559,14 +555,14 @@ void Interface_Sniff_Data_SniffData(void)
                            break;
 
             case HEX_VIEW:
-                           if (data_from_illithid.proto == 'T')
+                           if (data_from_illithid.proto == 'T') {
                               wprintw(data_joined, "\n> S %lx A %lx (%s) <\n%s",
                                                 data_from_illithid.seq,
                                                 data_from_illithid.ack_seq,
                                                 Decodedata_TCPFlags(data_from_illithid.flags),
-                                                Decodedata_GetHexData(data_from_illithid.data, data_from_illithid.datasize, W_MAINX2/2 - 4));
-                           else
-                              wprintw(data_joined, "%s", Decodedata_GetHexData(data_from_illithid.data, data_from_illithid.datasize, W_MAINX2/2 - 4));
+                                                Decodedata_GetHexData(data_from_illithid.data, data_from_illithid.datasize, (joined) ? W_MAINX2 : W_MAINX2/2 - 4));
+                           } else
+                              wprintw(data_joined, "%s", Decodedata_GetHexData(data_from_illithid.data, data_from_illithid.datasize, (joined) ? W_MAINX2 : W_MAINX2/2 - 4));
 
                            pnoutrefresh(data_joined, scroll_yj,0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 - 4);
                            break;
@@ -660,23 +656,29 @@ void Interface_Sniff_Data_DrawScroller(void)
 
    if (joined)
    {
-      mvwvline(data_joined_win, 1, W_MAINX2 - 5, ACS_VLINE, W_MAINY2-10);
+   	wmove(data_joined_win, 1, W_MAINX2 - 5);
+      wvline(data_joined_win, ACS_VLINE, W_MAINY2-10);
       wattron(data_joined_win, A_REVERSE);
-      mvwvline(data_joined_win, jvpos, W_MAINX2 - 5, ' ', sheight);
+      wmove(data_joined_win, jvpos, W_MAINX2 - 5);
+      wvline(data_joined_win, ' ', sheight);
       wnoutrefresh(data_joined_win);
       wattroff(data_joined_win, A_REVERSE);
    }
    else
    {
-      mvwvline(data_source_win, 1, W_MAINX2 / 2 - 3, ACS_VLINE, W_MAINY2-10);
+   	wmove(data_source_win, 1, W_MAINX2 / 2 - 3);
+      wvline(data_source_win, ACS_VLINE, W_MAINY2-10);
       wattron(data_source_win, A_REVERSE);
-      mvwvline(data_source_win, svpos, W_MAINX2 / 2 - 3, ' ', sheight);
+      wmove(data_source_win, svpos, W_MAINX2 / 2 - 3);
+      wvline(data_source_win, ' ', sheight);
       wnoutrefresh(data_source_win);
       wattroff(data_source_win, A_REVERSE);
 
-      mvwvline(data_dest_win, 1, W_MAINX2 / 2 - 3, ACS_VLINE, W_MAINY2-10);
+		wmove(data_dest_win, 1, W_MAINX2 / 2 - 3);
+      wvline(data_dest_win, ACS_VLINE, W_MAINY2-10);
       wattron(data_dest_win, A_REVERSE);
-      mvwvline(data_dest_win, dvpos, W_MAINX2 / 2 - 3, ' ', sheight);
+      wmove(data_dest_win, dvpos, W_MAINX2 / 2 - 3);
+      wvline(data_dest_win, ' ', sheight);
       wnoutrefresh(data_dest_win);
       wattroff(data_dest_win, A_REVERSE);
    }
@@ -727,13 +729,11 @@ void Interface_Sniff_Data_Inject(char proto, char *app)
    INJECTED_DATA inject_data;
    int data_len;
 
-#ifdef DEBUG
-   Debug_msg("Interface_Sniff_Data_Inject");
-#endif
+   DEBUG_MSG("Interface_Sniff_Data_Inject");
 
    if (joined)
    {
-      Interface_PopUp("Injection not possible while in JOINED view");
+      Interface_PopUp("Injection is not possible while in JOINED view");
       Interface_Sniff_Data_Redraw();
       return;
    }
@@ -752,9 +752,7 @@ void Interface_Sniff_Data_Inject(char proto, char *app)
 
       if (win_pointer == data_dest_win)
       {
-         #ifdef DEBUG
-            Debug_msg("Interface_Sniff_Data_Inject -- INJECT -- %s", ipdest);
-         #endif
+         DEBUG_MSG("Interface_Sniff_Data_Inject -- INJECT -- %s", ipdest);
          inject_data.source_ip = inet_addr(ipsource);
          inject_data.dest_ip = inet_addr(ipdest);
          inject_data.source_port = htons(portsource);
@@ -768,9 +766,7 @@ void Interface_Sniff_Data_Inject(char proto, char *app)
       }
       else
       {
-         #ifdef DEBUG
-            Debug_msg("Interface_Sniff_Data_Inject -- INJECT -- %s", ipsource);
-         #endif
+         DEBUG_MSG("Interface_Sniff_Data_Inject -- INJECT -- %s", ipsource);
          inject_data.source_ip = inet_addr(ipdest);
          inject_data.dest_ip = inet_addr(ipsource);
          inject_data.source_port = htons(portdest);
@@ -799,13 +795,11 @@ void Interface_Sniff_Data_Kill(char proto)
 
    if (proto == 'U')
    {
-      Interface_PopUp("Trying to kill an UDP connection ?!? Ehi Kiddie, go home !!");
+      Interface_PopUp("Trying to kill an UDP connection ?!? Hey Kiddie, go home !!");
       return;
    }
 
-#ifdef DEBUG
-   Debug_msg("Interface_Sniff_Data_Kill -- %s:%d -> %s:%d ", ipsource, portsource, ipdest, portdest);
-#endif
+   DEBUG_MSG("Interface_Sniff_Data_Kill -- %s:%d -> %s:%d ", ipsource, portsource, ipdest, portdest);
 
    kill_data.source_ip = inet_addr(ipsource);
    kill_data.dest_ip = inet_addr(ipdest);
@@ -827,8 +821,12 @@ void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char
    int KeyPress;
    int dimY = W_MAINY2 - W_MAINY1 - 3;
    int dimX = W_MAINX2 / 2 - 2;
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+	struct pollfd poll_fd;
+#else
    fd_set msk_fd;
    struct timeval TimeOut;
+#endif
    struct in_addr addr;
    char macsource[20];
    char macdest[20];
@@ -843,9 +841,7 @@ void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char
    strlcpy(macdest, macd, sizeof(macdest));
    strlcpy(app, type, sizeof(app));
 
-#ifdef DEBUG
-   Debug_msg("Interface_Sniff_Data_Run -- %d -- %c [%s:%d] [%s:%d] [%s] [%s]", mode, proto, ipsource, portsource, ipdest, portdest, macsource, macdest );
-#endif
+   DEBUG_MSG("Interface_Sniff_Data_Run -- %d -- %c [%s:%d] [%s:%d] [%s] [%s]", mode, proto, ipsource, portsource, ipdest, portdest, macsource, macdest );
 
    data_source_win = newwin(dimY, dimX, W_MAINY1 + 2, 2);
    data_dest_win = newwin(dimY, dimX, W_MAINY1 + 2, W_MAINX2 / 2 + 1);
@@ -912,9 +908,13 @@ void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char
 
    Interface_Sniff_Data_View(view);    // default view
 
-
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+   poll_fd.fd = 0;
+   poll_fd.events = POLLIN;
+#else
    memset(&TimeOut, 0, sizeof(TimeOut));  //  timeout = 0
    FD_ZERO(&msk_fd);
+#endif
 
    current_illithid_data.proto = proto;
    current_illithid_data.source_port = portsource;
@@ -930,17 +930,20 @@ void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char
    loop
    {
 
-      FD_SET(0, &msk_fd);
-
-      select(FOPEN_MAX, &msk_fd, (fd_set *) 0, (fd_set *) 0, &TimeOut);
-
       Interface_Sniff_Data_SniffData();
 
 #ifdef PERMIT_PLUGINS
       Interface_Plugins_PluginOutput();
 #endif
 
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+      poll(&poll_fd, 1, 1);
+      if (poll_fd.revents & POLLIN)
+#else
+      FD_SET(0, &msk_fd);
+      select(FOPEN_MAX, &msk_fd, (fd_set *) 0, (fd_set *) 0, &TimeOut);
       if (FD_ISSET(0, &msk_fd))
+#endif
       {
 
 #ifdef PERMIT_PLUGINS
@@ -1049,7 +1052,7 @@ void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char
             case 'h':{
                         static char *help[] = {
                         "[qQ][F10] - quit (and stop sniffing)",
-                        "[tab]     - switch between window",
+                        "[tab]     - switch between windows",
                         "[pgUp]    - scroll back (as well as UpArrow)",
                         "[pgDw]    - scroll forward (as well as DownArrow)",
                         "[iI]      - inject characters in the connection",
@@ -1082,7 +1085,8 @@ void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char
                      delwin(data_source_win);
                      data_source_win = NULL;    // for winching (see ec_signal.c)
                      wbkgdset(bottom_window, COLOR_PAIR(BOTTOM_COLOR));
-                     mvwhline(top_window, 2, 55, ' ', 20);
+                     wmove(top_window, 2, 55);
+                     whline(top_window, ' ', 20);
                      if (joined)
                      {
                         delwin(data_joined_win);
@@ -1097,9 +1101,7 @@ void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char
                      wnoutrefresh(bottom_window);
                      wnoutrefresh(main_window);
                      doupdate();
-                     #ifdef DEBUG
-                        Debug_msg("Interface_Sniff_Data_End");
-                     #endif
+                     DEBUG_MSG("Interface_Sniff_Data_End");
                      return;
                   break;
          }
@@ -1114,3 +1116,6 @@ void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char
 #endif
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
