@@ -17,12 +17,13 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_main.c,v 1.17 2002/02/10 10:07:49 alor Exp $
+    $Id: ec_main.c,v 1.30 2002/04/18 17:03:17 alor Exp $
 */
 
 #include "include/ec_main.h"
 
 #include <sys/ioctl.h>
+#include <ctype.h>
 #if defined (HAVE_TERMIOS_H) && !defined (CYGWIN)
    #include <termios.h>
 #endif
@@ -33,7 +34,6 @@
 #endif
 
 
-#include "include/ec_error.h"
 #include "include/ec_inet.h"
 #include "include/ec_simple.h"
 #include "include/ec_signal.h"
@@ -78,7 +78,6 @@ char active_dissector = 1;    // ec_main.h
 char filter_on_source = 0;
 char filter_on_dest = 0;
 
-
 // protos...
 
 void Main_Usage(void);
@@ -96,10 +95,8 @@ void Main_Devel_Release(void);
 int main(int argc, char *argv[])
 {
 
-#ifdef DEBUG
-   Debug_Init();
-   Debug_msg("Main");
-#endif
+   DEBUG_INIT();
+   DEBUG_MSG("Main -- here we go !!");
 
    ECThread_register(pthread_self(), "ettercap");
 
@@ -115,13 +112,14 @@ int main(int argc, char *argv[])
 {
    int i;
    for(i=0; i<argc; i++)
-      Debug_msg("Main_ParameterList - [%d] %s", i, argv[i]);
+      DEBUG_MSG("Main_ParameterList - [%d] %s", i, argv[i]);
 }
 #endif
 
    Options.delay = DEFAULT_DELAY;               // the default delay between arp replies (ec_doppleganger)
    Options.storm_delay = DEFAULT_STORM_DELAY;   // the default delay between arp request on start up (ec_inet)
 
+   fprintf (stdout, "\n\033[01m\033[1m%s %s (c) 2001 %s\033[0m\n\n", PROGRAM, VERSION, AUTHORS);
 
    if (Parser_ParseOptions(argc, argv) == 1)    // config file
       Parser_ParseConfFile(optarg);
@@ -138,7 +136,7 @@ int main(int argc, char *argv[])
 #ifdef LINUX
       Error_msg("%s (%s)", strerror(errno), Options.netiface);
 #else
-      Error_msg("Network Interface %s is NOT valid !!", Options.netiface);
+      Error_msg("%s is NOT a valid network interface for ettercap !!", Options.netiface);
 #endif
 
    if (Options.filter) Main_CheckForFilters();
@@ -146,6 +144,8 @@ int main(int argc, char *argv[])
    pipe(pipe_inject);      // create the pipes with illithid
    pipe(pipe_kill);
 
+   fprintf (stdout, "Your IP: %s with MAC: %s on Iface: %s\n", Inet_MyIPAddress(), Inet_MyMACAddress(), Options.netiface);
+
    if (Options.normal)
       Main_Normal();
    else
@@ -160,20 +160,17 @@ return 0;
 void Main_Usage(void)
 {
 
-#ifdef DEBUG
-   Debug_msg("Main_Usage");
-#endif
+   DEBUG_MSG("Main_Usage");
 
-   fprintf (stdout, "\n\033[01m\033[1m%s %s (c) 2001 %s\033[0m\n\n", PROGRAM, VERSION, AUTHORS);
    fprintf (stdout, "\nUsage: %s [OPTION] [HOST:PORT] [HOST:PORT] [MAC] [MAC]\n\n", PROGRAM);
 
    fprintf (stdout, "Sniffing method:\n");
-   fprintf (stdout, "  -a, --arpsniff               ARPBASED sniffing (specifying two host)\n");
+   fprintf (stdout, "  -a, --arpsniff               ARPBASED sniffing (specifying two hosts)\n");
    fprintf (stdout, "                               SMARTARP (specifying one host but with the list)\n");
    fprintf (stdout, "                               PUBLICARP (specifying only one host silently)\n");
    fprintf (stdout, "                               in silent mode : must specify both IP and MAC\n");
    fprintf (stdout, "                                 i.e.: ettercap -Nza IP IP MAC MAC    (ARPBASED)\n");
-   fprintf (stdout, "                                       ettercap -Na IP MAC           (SMARTCARP)\n");
+   fprintf (stdout, "                                       ettercap -Na IP MAC           (SMARTARP)\n");
    fprintf (stdout, "                                       ettercap -Nza IP MAC          (PUBLICARP)\n");
    fprintf (stdout, "  -s, --sniff                  IPBASED sniffing\n");
    fprintf (stdout, "                               you can specify the ANY ip that means ALL hosts\n");
@@ -182,27 +179,35 @@ void Main_Usage(void)
    fprintf (stdout, "                                 e.g.: ettercap -zm MAC1 MAC2\n");
    fprintf (stdout, "                                       ettercap -Nm MAC\n");
 
+   fprintf (stdout, "\nOff Line Sniffing:\n");
+   fprintf (stdout, "  -T, --readpcapfile           OFFLINE sniffing (read packets from a file)\n");
+   fprintf (stdout, "                                 e.g.: ettercap -T file_dumped_from_tcpdump\n");
+   fprintf (stdout, "  -Y, --writepcapfile          DUMP packets to a pcap compatible file format\n");
+   fprintf (stdout, "                                 e.g.: ettercap -NzsY file_to_be_dumped\n");
+
    fprintf (stdout, "\nGeneral options:\n");
-   fprintf (stdout, "  -N, --simple                 NON interactive mode (without ncurses)\n");
+   fprintf (stdout, "  -N, --simple                 NON-interactive mode (without ncurses)\n");
    fprintf (stdout, "  -z, --silent                 silent mode (no arp storm on start up)\n");
    fprintf (stdout, "  -O, --passive                passive scanning of the LAN\n");
    fprintf (stdout, "  -b, --broadping              broadcast ping instead of arp storm on start up\n");
-   fprintf (stdout, "  -D, --delay <n sec>          the dalay between arp replies (default is 30 sec)\n");
-   fprintf (stdout, "  -Z, --stormdelay <n usec>    the dalay between arp request (def is 1500 usec)\n");
-   fprintf (stdout, "  -S, --spoof <IP>             on start up send request with this IP\n");
+   fprintf (stdout, "  -D, --delay <n sec>          the delay between arp replies when poisoning (default is 30 sec)\n");
+   fprintf (stdout, "  -Z, --stormdelay <n usec>    the delay between arp requests on startup (def is 1500 usec)\n");
+   fprintf (stdout, "  -S, --spoof <IP>             on start up send requests with this IP\n");
    fprintf (stdout, "  -H, --hosts <IP1[,IP2][,..]> on start up scan only these hosts\n");
    fprintf (stdout, "  -d, --dontresolve            don't resolve the IPs (speed up the startup)\n");
    fprintf (stdout, "  -i, --iface <iface>          network interface to be used\n");
    fprintf (stdout, "  -n, --netmask <netmask>      the netmask used to scan the lan\n");
    fprintf (stdout, "  -e, --etterconf <filename>   load options from a config file\n");
-   fprintf (stdout, "  -j, --loadhosts <filename>   load hosts list from a file\n");
-   fprintf (stdout, "  -k, --savehosts              save hosts list to a file\n");
+   fprintf (stdout, "  -j, --loadhosts <filename>   load host/mac list from a file\n");
+   fprintf (stdout, "  -k, --savehosts              save host/mac list to a file\n");
    fprintf (stdout, "  -v, --version                check for the latest ettercap version\n");
    fprintf (stdout, "  -y, --yes                    in combination with -v auto answer yes\n");
    fprintf (stdout, "  -h, --help                   this help screen\n");
 
    fprintf (stdout, "\nSilent mode options (combined with -N):\n");
-   fprintf (stdout, "  -u, --udp                    sniff only udp connection (default is tcp)\n");
+   fprintf (stdout, "  -t, --proto <proto>          sniff only <proto> connection (def. is tcp+udp)\n");
+   fprintf (stdout, "                               proto can be: tcp, udp or all\n");
+   fprintf (stdout, "  -J, --onlypoison             don't sniff, only do arp poisoning\n");
    fprintf (stdout, "  -R, --reverse                sniff all the connection but the selected one\n");
 #ifdef PERMIT_PLUGINS
    fprintf (stdout, "  -p, --plugin <name>          run the \"name\" plugin (\"list\" for available ones)\n");
@@ -211,14 +216,15 @@ void Main_Usage(void)
    fprintf (stdout, "  -C, --collect                collect users and passwords only\n");
    fprintf (stdout, "                               this options must be used with a sniffing method\n");
    fprintf (stdout, "                                    Eg: ettercap -NCzs\n");
-   fprintf (stdout, "  -f, --fingerprint <host>     do OS fingerprinting on HOST\n");
+   fprintf (stdout, "  -f, --fingerprint <host>     do active OS fingerprinting on HOST\n");
    fprintf (stdout, "  -x, --hexview                display data in hex mode\n");
    fprintf (stdout, "  -L, --logtofile              logs all data to specific file(s)\n");
+   fprintf (stdout, "                               (for pcap use -Y)\n");
    fprintf (stdout, "  -q, --quiet                  \"demonize\" ettercap (useful with -L)\n");
    fprintf (stdout, "  -w, --newcert                create a new SSL cert file for HTTPS dissector\n");
    fprintf (stdout, "  -F, --filter <filename>      load  \"filename\" as the filter chain file\n");
-   fprintf (stdout, "  -c, --check                  check for other poisoners in the LAN\n");
-   fprintf (stdout, "  -t, --linktype               tries to indentify the LAN type (switch or hub)\n");
+   fprintf (stdout, "  -c, --check                  check for other poisoners on the LAN\n");
+   fprintf (stdout, "  -g, --linktype               tries to indentify the LAN type (switch or hub)\n");
    fprintf (stdout, "\n");
 
    exit (0);
@@ -233,9 +239,7 @@ void Main_Interactive(void)
 #ifndef CYGWIN
    struct winsize  ws = {0, 0, 0, 0};
 
-   #ifdef DEBUG
-      Debug_msg("Main_Interactive");
-   #endif
+   DEBUG_MSG("Main_Interactive");
 
 #endif
 
@@ -249,18 +253,14 @@ void Main_Interactive(void)
       short cols = ws.ws_col;
       short rows = ws.ws_row;
 
-      #ifdef DEBUG
-         Debug_msg("Main_Interactive -- screen wide %dx%d (TIOCGWINSZ)", ws.ws_row, ws.ws_col);
-      #endif
+      DEBUG_MSG("Main_Interactive -- screen wide %dx%d (TIOCGWINSZ)", ws.ws_row, ws.ws_col);
 
       if ((p = getenv("LINES")))
          rows = atoi(p);
       if ((p = getenv("COLUMNS")))
          cols = atoi(p);
 
-      #ifdef DEBUG
-         Debug_msg("Main_Interactive -- screen wide %sx%s (getenv)", getenv("LINES"), getenv("COLUMNS"));
-      #endif
+      DEBUG_MSG("Main_Interactive -- screen wide %sx%s (getenv)", getenv("LINES"), getenv("COLUMNS"));
 
       if (rows < 25 || cols < 80)
          Error_msg("Screen must be at least 25x80 !!");
@@ -268,6 +268,7 @@ void Main_Interactive(void)
    }
 #endif
 
+
 #ifdef PERMIT_PLUGINS
    Plugin_LoadAll();
 #endif
@@ -279,16 +280,12 @@ void Main_Interactive(void)
    Interface_InitScreen();
    Interface_Run();
 #else
-   #ifdef DEBUG
-      Debug_msg("Ncurses not supported -- turning to non interactive mode...");
-   #endif
+   DEBUG_MSG("Ncurses not supported -- turning to non interactive mode...");
    fprintf(stdout, "\nNcurses not supported -- turning to non interactive mode...\n\n");
    Main_Normal();
 #endif
 
-#ifdef DEBUG
-   Debug_msg("Main_Interactive_END");
-#endif
+   DEBUG_MSG("Main_Interactive_END");
 }
 
 
@@ -297,12 +294,8 @@ void Main_Interactive(void)
 void Main_Normal(void)
 {
 
-#ifdef DEBUG
-   Debug_msg("Main_Normal");
-#endif
+   DEBUG_MSG("Main_Normal");
 
-   printf ("\n\033[01m\033[1m%s %s (c) 2001 %s\033[0m\n\n", PROGRAM, VERSION, AUTHORS);
-   printf ("Your IP: %s with MAC: %s on Iface: %s\n", Inet_MyIPAddress(), Inet_MyMACAddress(), Options.netiface);
 
 #ifdef PERMIT_PLUGINS
    if (Options.plugin || Options.arpsniff || Options.sniff  || Options.macsniff)
@@ -311,7 +304,7 @@ void Main_Normal(void)
 
    if (Options.list || Options.check || Options.arpsniff ||
        Options.sniff  || Options.macsniff || Options.link ||
-       Options.passive || Options.hoststofile)
+       Options.passive || Options.hoststofile || Options.onlypoison)
    {
       if (!Options.silent) printf("Building host list for netmask %s, please wait...\n", Inet_MySubnet());
       number_of_hosts_in_lan = Inet_HostInLAN();
@@ -319,7 +312,7 @@ void Main_Normal(void)
 
    if (Options.hoststofile)
    {
-      fprintf(stdout, "\nHost list dumped into file: %s\n\n", Inet_Save_Host_List());
+      fprintf(stdout, "\nHost/MAC list dumped into file: %s\n\n", Inet_Save_Host_List());
       exit(0);
    }
 
@@ -340,16 +333,15 @@ void Main_Normal(void)
       Simple_Plugin();
 #endif
 
-   if (Options.arpsniff || Options.sniff  || Options.macsniff)
+   if (Options.arpsniff || Options.sniff  || Options.macsniff || Options.onlypoison)
       Simple_Run();
 
    if (Options.passive)
       Simple_PassiveScan();
 
    printf("\n");
-#ifdef DEBUG
-   Debug_msg("Main_Normal_END");
-#endif
+
+   DEBUG_MSG("Main_Normal_END");
 
 exit(0);
 }
@@ -358,19 +350,37 @@ exit(0);
 
 void Main_CheckForRun(char *program_argv0)
 {
-
-#ifdef DEBUG
-   Debug_msg("Main_CheckForRun");
+#ifdef CYGWIN
+   #include <sys/utsname.h>
+   struct utsname buf;
 #endif
 
-   if (getuid() != 0)
-   {
-      Options.normal = 1;
-      Error_msg("Sorry UID %d, must be root to run %s !!", getuid(), PROGRAM);
-   }
+   int i;
 
-   if (!strstr(program_argv0, PROGRAM))      // just for script-kiddies ;)
-      Error_msg("ehi guy ! my name is \"%s\" ! I really don't like \"%s\"...", PROGRAM, program_argv0);
+DEBUG_MSG("Main_CheckForRun -- [%s]", program_argv0);
+
+#ifdef CYGWIN
+
+   uname(&buf);
+
+   if (strncmp(strstr(buf.sysname, "_") + 1, "NT", 2))
+      Error_msg("Ettercap only runs on Windows NT / 2000 / XP");
+
+#else
+   if (getuid() != 0)
+      Error_msg("Sorry UID %d, you must be root to run %s !!", getuid(), PROGRAM);
+#endif
+
+   if (strchr(program_argv0, '/'))
+      program_argv0 = strrchr(program_argv0, '/') + 1;
+
+   for (i=0; i<strlen(program_argv0); i++)
+      program_argv0[i] = tolower(program_argv0[i]);
+
+DEBUG_MSG("Main_CheckForRun -- [%s]", program_argv0);
+
+   if (!strstr(program_argv0, PROGRAM))     // just for script-kiddies ;)
+      Error_msg("Hey guy ! My name is \"%s\" ! I REALLY don't like \"%s\"...", PROGRAM, program_argv0);
 
 }
 
@@ -379,9 +389,7 @@ void Main_CheckForRun(char *program_argv0)
 void Main_CheckForFilters(void)
 {
 
-#ifdef DEBUG
-   Debug_msg("Main_CheckForFilters");
-#endif
+   DEBUG_MSG("Main_CheckForFilters");
 
    switch(FilterDrop_Validation(Filter_Array_Dest))
    {
@@ -420,7 +428,7 @@ void Main_Devel_Release(void)
    fprintf (stdout, "==============================================================================\n");
    fprintf (stdout, "  %s %s IS STILL IN DEVELOPMENT STATE. ABSOLUTELY NO WARRANTY !\n\n", PROGRAM, VERSION);
    fprintf (stdout, "  if you are a betatester please report bugs to :\n");
-   fprintf (stdout, "      http://ettercap.sourceforge.net/forum/viewforum.php?forum=7\n\n");
+   fprintf (stdout, "      http://ettercap.sourceforge.net/forum/viewforum.php?f=7\n\n");
    fprintf (stdout, "  or send an email to:\n");
    fprintf (stdout, "      alor@users.sourceforge.net\n");
    fprintf (stdout, "      crwm@freemail.it\n\n");
@@ -428,11 +436,7 @@ void Main_Devel_Release(void)
 //   fprintf (stdout, "  but this is NOT for you, so don't blame us for any bugs or problems !\n");
    fprintf (stdout, "==============================================================================\n");
    fprintf (stdout, "\n\n");
-// if (!Options.normal)
-// {
-//    fprintf(stdout, "Press return to continue...");
-//    getchar();
-// }
+
 }
 #endif
 
@@ -450,9 +454,7 @@ void Main_Check_NewRelease(void)
 //   char host[] = "zefiro.alor.org";
 //   char page[] = "/ettercap/latest.php";
 
-#ifdef DEBUG
-   Debug_msg("Main_Check_NewRelease -- now is %s", VERSION);
-#endif
+   DEBUG_MSG("Main_Check_NewRelease -- now is %s", VERSION);
 
    memset(buffer, 0, sizeof(buffer));
 
@@ -482,22 +484,18 @@ void Main_Check_NewRelease(void)
                                        "\r\n", page, host, PROGRAM, VERSION );
       Inet_Http_Send(sock, getmsg);
 
-#ifdef DEBUG
-   Debug_msg("Main_Check_NewRelease - SEND -----------------------\n\n%s\n\n", getmsg);
-   Debug_msg("Main_Check_NewRelease - ENDSEND --------------------");
-#endif
+      DEBUG_MSG("Main_Check_NewRelease - SEND -----------------------\n\n%s\n\n", getmsg);
+      DEBUG_MSG("Main_Check_NewRelease - ENDSEND --------------------");
 
       Inet_Http_Receive(sock, buffer, sizeof(buffer));
 
-#ifdef DEBUG
-   Debug_msg("Main_Check_NewRelease - RECEIVE --------------------\n\n%s\n\n", buffer);
-   Debug_msg("Main_Check_NewRelease - ENDRECEIVE -----------------");
-#endif
+      DEBUG_MSG("Main_Check_NewRelease - RECEIVE --------------------\n\n%s\n\n", buffer);
+      DEBUG_MSG("Main_Check_NewRelease - ENDRECEIVE -----------------");
 
       Inet_CloseSocket(sock);
 
       if (!strlen(buffer))
-         Error_msg("The server didn't replied");
+         Error_msg("The server didn't respond");
 
       ptr = strstr(buffer, "\r\n\r\n") + 4;  // skip the headers.
       if (strncmp(ptr, "LATEST: ", 8))
@@ -509,9 +507,7 @@ void Main_Check_NewRelease(void)
          Error_msg("You already have the latest ettercap release (\033[01m\033[1m%s\033[0m)\n\n", latest);
       else if (strncmp(latest, VERSION, 5) < 0)
       {
-         #ifdef DEBUG
-            Debug_msg("You have a newer release than the official one (%s)", latest);
-         #endif
+         DEBUG_MSG("You have a newer release than the official one (%s)", latest);
          fprintf(stdout, "You have a newer release (\033[01m\033[1m%s\033[0m) than the official one (\033[01m\033[1m%s\033[0m)\n\n", VERSION, latest);
          fprintf(stdout, "\033[01m\033[1m%s\033[0m is currently under development... use at you own risk... ;)\n\n", VERSION);
          exit(0);
@@ -549,3 +545,6 @@ void Main_Check_NewRelease(void)
 /* EOF */
 
 
+
+// vim:ts=3:expandtab
+
