@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_parser.c,v 1.16 2001/12/20 20:09:45 alor Exp $
+    $Id: ec_parser.c,v 1.27 2002/04/16 13:13:18 alor Exp $
 */
 
 
@@ -30,7 +30,6 @@
    #include "missing/getopt.h"
 #endif
 
-#include "include/ec_error.h"
 #include "include/ec_inet.h"
 #include "include/ec_simple.h"
 #include "include/ec_dissector.h"
@@ -59,6 +58,7 @@ void Parser_Expand(char *to_parse);
 int match_pattern(const char *s, const char *pattern);
 void Parser_Filters(char *line, DROP_FILTER *filter);
 char *Parser_StrSpacetoUnder(char *h_name);
+void Parser_StatusBar(int max);
 
 //-----------------------------------
 
@@ -81,9 +81,8 @@ int Parser_ParseOptions(int counter, char **values)
       { "plugin", required_argument, NULL, 'p' },
       { "hexview", no_argument, NULL, 'x' },
       { "silent", no_argument, NULL, 'z' },
-      { "udp", no_argument, NULL, 'u' },
       { "fingerprint", no_argument, NULL, 'f' },
-      { "linktype", no_argument, NULL, 't' },
+      { "linktype", no_argument, NULL, 'g' },
       { "collect", no_argument, NULL, 'C' },
       { "broadping", no_argument, NULL, 'b' },
       { "logtofile", no_argument, NULL, 'L' },
@@ -101,20 +100,18 @@ int Parser_ParseOptions(int counter, char **values)
       { "passive", no_argument, NULL, 'O' },
       { "loadhosts", required_argument, NULL, 'j' },
       { "savehosts", no_argument, NULL, 'k' },
+      { "proto", required_argument, NULL, 't' },
+      { "readpcapfile", required_argument, NULL, 'T' },
+      { "writepcapfile", required_argument, NULL, 'Y' },
+      { "onlypoison", no_argument, NULL, 'J' },
       { 0 , 0 , 0 , 0}
    };
 
-#ifdef DEBUG
-   Debug_msg("Parser_ParseOptions -- [%d] [%s]", counter, *values);
-#endif
+   DEBUG_MSG("Parser_ParseOptions -- [%d] [%s]", counter, *values);
 
    optind = 0;
 
-#ifdef PERMIT_PLUGINS
-   while ((c = getopt_long (counter, values, "hvyNlasmci:p:xzuftCbn:Lqe:dwF:H:D:RS:Z:Oj:k",long_options, (int *)0)) != EOF) {
-#else
-   while ((c = getopt_long (counter, values, "hvyNlasmci:xzuftCbn:Lqe:dwF:H:D:RS:Z:Oj:k",long_options, (int *)0)) != EOF) {    // no plugin
-#endif
+   while ((c = getopt_long (counter, values, "hvyNlasmci:p:xzfgCbn:Lqe:dwF:H:D:RS:Z:Oj:kt:T:Y:J",long_options, (int *)0)) != EOF) {
 
       switch (c) {
 
@@ -122,8 +119,7 @@ int Parser_ParseOptions(int counter, char **values)
             Main_Usage();
          break;
 
-         case 'v':   Options.version = 1;
-                     Options.normal = 1;        break;
+         case 'v':   Options.version = 1;       break;
 
          case 'y':   Options.yes = 1;           break;
 
@@ -147,7 +143,7 @@ int Parser_ParseOptions(int counter, char **values)
 
          case 'f':   Options.finger = 1;        break;
 
-         case 't':   Options.link = 1;          break;
+         case 'g':   Options.link = 1;          break;
 
          case 'C':   Options.collect = 1;       break;
 
@@ -164,12 +160,15 @@ int Parser_ParseOptions(int counter, char **values)
          case 'O':   Options.passive = 1;
                      Options.silent = 1;        break;
 
-#ifdef PERMIT_PLUGINS
          case 'p':
-            Options.plugin = 1;
-            Execute_Plugin = strdup(optarg);
+            #ifdef PERMIT_PLUGINS
+                     Options.plugin = 1;
+                     Execute_Plugin = strdup(optarg);
+
+            #else
+                     Error_msg("PLUGIN SUPPORT not supported on this OS.");
+            #endif
          break;
-#endif
 
          case 'i':
             strlcpy(Options.netiface, optarg, sizeof(Options.netiface));
@@ -184,6 +183,32 @@ int Parser_ParseOptions(int counter, char **values)
             Options.hoststofile = 1;
          break;
 
+         case 'T':
+            Options.silent = 1;
+            Options.dumpfile = strdup(optarg);
+         break;
+
+         case 'Y':
+            Options.writedump = 1;
+            Options.dumpfile = strdup(optarg);
+         break;
+
+         case 't':
+            if (!strncasecmp(optarg, "tcp", 3)) Options.tcp = 1;
+            else if (!strncasecmp(optarg, "udp", 3)) Options.udp = 1;
+            else if (!strncasecmp(optarg, "all", 3)) {
+               Options.tcp = 1;
+               Options.udp = 1;
+            } else
+               Error_msg("[%s]: protocol unrecognized", optarg);
+
+         break;
+
+         case 'J':
+            Options.normal = 1;
+            Options.onlypoison = 1;
+         break;
+         
          case 'n':
             strlcpy(Options.netmask, optarg, sizeof(Options.netmask));
          break;
@@ -210,7 +235,6 @@ int Parser_ParseOptions(int counter, char **values)
          break;
 
          case 'w':
-            Options.normal = 1;
             Simple_CreateCertFile();
          break;
 
@@ -247,20 +271,26 @@ void Parser_ParseParameters(char *first, char *second, char *third, char *fourth
 {
 
 #ifdef DEBUG
-   if (first)  Debug_msg("Parser_ParseParameters -- 1 [%s]", first); else goto exit_debug;
-   if (second) Debug_msg("Parser_ParseParameters -- 2 [%s]", second); else goto exit_debug;
-   if (third)  Debug_msg("Parser_ParseParameters -- 3 [%s]", third); else goto exit_debug;
-   if (fourth) Debug_msg("Parser_ParseParameters -- 4 [%s]", fourth); else goto exit_debug;
+   if (first)  DEBUG_MSG("Parser_ParseParameters -- 1 [%s]", first); else goto exit_debug;
+   if (second) DEBUG_MSG("Parser_ParseParameters -- 2 [%s]", second); else goto exit_debug;
+   if (third)  DEBUG_MSG("Parser_ParseParameters -- 3 [%s]", third); else goto exit_debug;
+   if (fourth) DEBUG_MSG("Parser_ParseParameters -- 4 [%s]", fourth); else goto exit_debug;
 exit_debug:
 #endif
 
 #define R(a,b,c) (a & b) | ((a ^ b) & c)     // returns true if more than one was selected
 
+   if (!Options.normal &&
+                   (Options.reverse || Options.collect || Options.list ||
+                    Options.finger || Options.logtofile || Options.quiet ||
+                    Options.check))
+      Error_msg("Perhaps you have forgotten the -N option...\n");
+
    if (!Options.normal) Options.reverse = 0;
 
-   if (Options.quiet && !Options.normal && !Options.logtofile )
-      Error_msg("Demonization is only useful with -NL or -NLC !!\n\n");
-
+   if (Options.quiet && !Options.normal ) 
+      Error_msg("Demonization is only useful with -N *cannot daemonize the interface* !!\n\n");
+   
    if ( R(Options.arpsniff, Options.sniff, Options.macsniff) )
       Error_msg("Please select only one sniffing method !!\n\n");
 
@@ -273,6 +303,14 @@ exit_debug:
    if (Options.normal && Options.passive && (Options.sniff || Options.arpsniff || Options.macsniff))
       Error_msg("Passive scanning can't be combined with a sniffing method !!\n\n");
 
+   if (Options.dumpfile && Options.arpsniff)
+      Error_msg("You can't ARP sniff from a file !!\n\n");
+
+   if (Options.onlypoison && (Options.passive || Options.filter || 
+                              Options.sniff || Options.arpsniff || Options.macsniff ||
+                              Options.logtofile))
+      Error_msg("This options can't be used in conjunction with -J !!\n\n");
+   
    if (Options.sniff || Options.macsniff)
       Options.silent = 1;
 
@@ -297,7 +335,7 @@ exit_debug:
             Error_msg("SOURCE and DEST MAC address must be different !!");
       }
 
-      if (Options.arpsniff)
+      if (Options.arpsniff || Options.onlypoison)
       {
          int i=0;
          char check[6];
@@ -375,7 +413,7 @@ exit_debug:
    }
    else // !silent
    {
-      if (Options.arpsniff && !first)
+      if ((Options.arpsniff || Options.onlypoison) && !first)
          Error_msg("Please specify  source and destination IP for ARP Based (full-duplex)\n"
                    "or only one IP for PUBLIC ARP (half-duplex)");
 
@@ -401,12 +439,10 @@ exit_debug:
 
 
 
-#ifdef DEBUG
-   Debug_msg("Parser_ParseParameters - name - [%s][%s]", Host_Dest.name, Host_Source.name);
-   Debug_msg("Parser_ParseParameters -  IP  - [%s][%s]", Host_Dest.ip, Host_Source.ip);
-   Debug_msg("Parser_ParseParameters - port - [%d][%d]", Host_Dest.port, Host_Source.port);
-   Debug_msg("Parser_ParseParameters -  MAC - [%s][%s]", Host_Dest.mac, Host_Source.mac);
-#endif
+   DEBUG_MSG("Parser_ParseParameters - name - [%s][%s]", Host_Dest.name, Host_Source.name);
+   DEBUG_MSG("Parser_ParseParameters -  IP  - [%s][%s]", Host_Dest.ip, Host_Source.ip);
+   DEBUG_MSG("Parser_ParseParameters - port - [%d][%d]", Host_Dest.port, Host_Source.port);
+   DEBUG_MSG("Parser_ParseParameters -  MAC - [%s][%s]", Host_Dest.mac, Host_Source.mac);
 
 }
 
@@ -414,7 +450,7 @@ exit_debug:
 
 char * Parser_AddStr(char *list, char *string)
 {
-	int len = strlen(list)+strlen(string)+1;
+   int len = strlen(list)+strlen(string)+1;
 
    list = realloc(list, len);
    if (list == NULL)
@@ -441,9 +477,7 @@ void Parser_ParseConfFile(char *filename)
    char plugins = 0;
 #endif
 
-#ifdef DEBUG
-   Debug_msg("Parser_ParseConfFile - %s", filename);
-#endif
+   DEBUG_MSG("Parser_ParseConfFile - %s", filename);
 
    memset(&pargv, 0, 256*sizeof(int));
 
@@ -468,9 +502,7 @@ void Parser_ParseConfFile(char *filename)
       if (!strlen(line))   // skip 0 length line
          continue;
 
-      #ifdef DEBUG
-         Debug_msg("Parser_ParseConfFile - [%s]", line);
-      #endif
+      DEBUG_MSG("Parser_ParseConfFile - [%s]", line);
 
       if (!strncasecmp(line, "OPTIONS: ", 9))
       {
@@ -567,10 +599,7 @@ void Parser_ParseConfFile(char *filename)
 
          option = strdup(line+6);
          if ( inet_aton(option, (struct in_addr *)&illithid_gwip) == 0)
-         {
-            Options.normal = 1;  // prevent Error_msg to close the screen
             Error_msg("Incorrect GWIP (%s) in the conf file !!", option);
-         }
          free(option);
       }
 
@@ -605,9 +634,7 @@ void Parser_ParseConfFile(char *filename)
    if (!strcmp(to_be_parsed, "etter.conf ")) // no options in the file....
       return;
 
-#ifdef DEBUG
-      Debug_msg("Parser_ParseConfFile - [%s]", to_be_parsed);
-#endif
+   DEBUG_MSG("Parser_ParseConfFile - [%s]", to_be_parsed);
 
    ptr = strtok(to_be_parsed, " ");
    pargv[pargc++] = strdup(ptr);
@@ -619,9 +646,9 @@ void Parser_ParseConfFile(char *filename)
 {
    int i;
    for(i=0; i<pargc; i++)
-      Debug_msg("Parser_ParseConfFile - [%d] %s", i, pargv[i]);
+      DEBUG_MSG("Parser_ParseConfFile - [%d] %s", i, pargv[i]);
 
-   Debug_msg("Parser_ParseConfFile - pargc [%d]", pargc);
+   DEBUG_MSG("Parser_ParseConfFile - pargc [%d]", pargc);
 }
 #endif
 
@@ -817,9 +844,7 @@ void Parser_LoadFilters(char *filename)
    if (Filter_File)
    {
       etterfilter = fopen(Filter_File, "r");
-      #ifdef DEBUG
-         Debug_msg("Parser_LoadFilters - [%s]", Filter_File);
-      #endif
+      DEBUG_MSG("Parser_LoadFilters - [%s]", Filter_File);
    }
    else if (!strcmp(filename, ""))
    {
@@ -832,17 +857,13 @@ void Parser_LoadFilters(char *filename)
          etterfilter = fopen(line, "r");
       }
       Filter_File = strdup(line);
-      #ifdef DEBUG
-         Debug_msg("Parser_LoadFilters - [%s]", line);
-      #endif
+      DEBUG_MSG("Parser_LoadFilters - [%s]", line);
    }
    else
    {
       etterfilter = fopen(filename, "r");
       Filter_File = strdup(filename);
-      #ifdef DEBUG
-         Debug_msg("Parser_LoadFilters - [%s]", filename);
-      #endif
+      DEBUG_MSG("Parser_LoadFilters - [%s]", filename);
    }
 
    if (etterfilter == NULL)
@@ -910,10 +931,10 @@ void Parser_LoadFilters(char *filename)
 {
    short i;
    for (i=0; i<Filter_Source; i++)
-      Debug_msg("\tSOURCE: %s", Parser_PrintFilter(Filter_Array_Source, i));
+      DEBUG_MSG("\tSOURCE: %s", Parser_PrintFilter(Filter_Array_Source, i));
 
    for (i=0; i<Filter_Dest; i++)
-      Debug_msg("\tDEST  : %s", Parser_PrintFilter(Filter_Array_Dest, i));
+      DEBUG_MSG("\tDEST  : %s", Parser_PrintFilter(Filter_Array_Dest, i));
 }
 #endif
 
@@ -1014,27 +1035,19 @@ int Parser_HostList(char *to_parse)
    u_long dummy;
    int i=0;
 
-#ifdef DEBUG
-   Debug_msg("Parser_HostList - [%s]", to_parse);
-#endif
+   DEBUG_MSG("Parser_HostList - [%s]", to_parse);
 
    fprintf(stdout, "Expanding wildcarded hosts...");
 
-   if (strstr(to_parse, " "))
-   {
-      fprintf(stdout, "\n");
-      Options.normal = 1;
-      Error_msg("The host list can't contain blank spaces...");
-   }
+   if (strstr(to_parse, " ") || strstr(to_parse, "%") )
+      Error_msg("\nThe host list has an invalid format...");
 
    list_to_parse = calloc(1,1);
 
    for(ip=strsep(&to_parse, ","); ip != NULL; ip=strsep(&to_parse, ","))
       Parser_Expand(ip);
 
-#ifdef DEBUG
-   Debug_msg("Parser_HostList - [%s]", list_to_parse);
-#endif
+   DEBUG_MSG("Parser_HostList - [%s]", list_to_parse);
 
    fprintf(stdout, "\nLoading IP addresses from list...\n");
 
@@ -1119,5 +1132,58 @@ char *Parser_StrSpacetoUnder(char *h_name)
 }
 
 
+
+void Parser_StatusBar(int max)
+{
+   if (!Options.onscreen) {
+      static int progress = 1;
+      float percent;
+      int i;
+
+      percent = (float)(progress)*100/(max);
+
+   /* we use stderr to avoid scrambling of logfile generated by: ettercap -Nl > logfile */
+
+      switch(progress % 4) {
+         case 0:
+               fprintf(stderr, "\r| |");
+               break;
+         case 1:
+               fprintf(stderr, "\r/ |");
+               break;
+         case 2:
+               fprintf(stderr, "\r- |");
+               break;
+         case 3:
+               fprintf(stderr, "\r\\ |");
+               break;
+      }
+
+      for (i=0; i < percent/2; i++)
+         fprintf(stderr, "=");
+
+      fprintf(stderr, ">");
+
+      for(; i < 50; i++)
+         fprintf(stderr, " ");
+
+      fprintf(stderr, "| %6.2f %%", percent );
+
+      fflush(stderr);
+
+      if (progress == max) {
+         progress = 1;
+         fprintf(stderr, "\r* |==================================================>| 100.00 %%\n");
+         return;
+      }
+
+      progress++;
+
+   }
+}
+
 /* EOF */
 
+
+// vim:ts=3:expandtab
+
