@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_plugins.c,v 1.12 2002/02/10 10:07:49 alor Exp $
+    $Id: ec_plugins.c,v 1.15 2002/03/08 08:49:56 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -46,7 +46,6 @@
 #include <dirent.h>
 
 #include "include/ec_plugins.h"
-#include "include/ec_error.h"
 #include "include/ec_parser.h"
 #include "include/ec_queue.h"
 #include "include/ec_buffer.h"
@@ -58,6 +57,12 @@
    #define RTLD_NOW DL_LAZY
 #endif
 
+#if defined(OPENBSD) || defined(MACOSX)
+   #define SYM_PREFIX "_"     // for the symbols loaded with dlsym
+#else
+   #define SYM_PREFIX ""
+#endif
+
 struct plug_list
 {
    struct plugin_attr plugin;
@@ -118,9 +123,7 @@ void Plugin_LoadAll(void)
    struct dirent **namelist;
    int n, i;
 
-#ifdef DEBUG
-   Debug_msg("Plugin_LoadAll -- %s", PLUGIN_PATH);
-#endif
+   DEBUG_MSG("Plugin_LoadAll -- %s", PLUGIN_PATH);
 
    fprintf (stdout, "\nLoading plugins... ");
    fflush (stdout);
@@ -128,8 +131,7 @@ void Plugin_LoadAll(void)
    n = scandir(".", &namelist, 0, alphasort);
 
    for(i=n-1; i>=0; i--)
-     if ( match_pattern(namelist[i]->d_name, "ec_*.so") )
-     {
+     if ( match_pattern(namelist[i]->d_name, "ec_*.so") ) {
          if ( Plugin_Load(Plugin_Getname(namelist[i]->d_name), ".") == 0)
             fprintf (stdout, "\n./%s contains errors !",namelist[i]->d_name);
          fflush (stdout);
@@ -138,10 +140,8 @@ void Plugin_LoadAll(void)
    n = scandir(PLUGIN_PATH, &namelist, 0, alphasort);
 
    for(i=n-1; i>=0; i--)
-     if ( match_pattern(namelist[i]->d_name, "ec_*.so") )
-     {
-         switch( Plugin_Load(Plugin_Getname(namelist[i]->d_name), PLUGIN_PATH) )
-         {
+     if ( match_pattern(namelist[i]->d_name, "ec_*.so") ) {
+         switch( Plugin_Load(Plugin_Getname(namelist[i]->d_name), PLUGIN_PATH) ) {
             case 0:
                      fprintf (stdout, "\n%s/%s contains errors !", PLUGIN_PATH, namelist[i]->d_name);
                      break;
@@ -154,13 +154,11 @@ void Plugin_LoadAll(void)
 
    fprintf (stdout, "Done.\n");
 
-   LIST_FOREACH(current, &loaded_plug_list, next)        // unload external plugins....
-   {
-      if (current->plugin.ops.plug_type == PT_EXT)
-      {
-         #ifdef DEBUG
-            Debug_msg("Plugin_LoadAll - Unloading external - %s", current->plugin.name);
-         #endif
+   LIST_FOREACH(current, &loaded_plug_list, next) {       // unload external plugins....
+      if (current->plugin.ops.plug_type == PT_EXT) {
+
+         DEBUG_MSG("Plugin_LoadAll - Unloading external - %s", current->plugin.name);
+
          (current->plugin.fini_function)(NULL);
          dlclose(current->plugin.handle);
          current->plugin.handle = NULL;
@@ -175,12 +173,9 @@ int Plugin_Load(char *name, char *path)
 {
    struct plug_list *current;
 
-#ifdef DEBUG
-      Debug_msg("Plugin_Load -- %s%s", path, name);
-#endif
+   DEBUG_MSG("Plugin_Load -- %s/%s", path, name);
 
-   LIST_FOREACH(current, &loaded_plug_list, next)
-   {
+   LIST_FOREACH(current, &loaded_plug_list, next) {
       if (!strcmp(current->plugin.name, name) && current->plugin.handle != NULL)
          return -1; // already loaded
    }
@@ -195,53 +190,34 @@ int Plugin_Load(char *name, char *path)
    current->plugin.enabled = Parser_Activated_Plugin(name);
 
    current->plugin.handle = dlopen(Plugin_Getfile(name, path), RTLD_NOW);
-   if (!current->plugin.handle)
-   {
-      #ifdef DEBUG
-         Debug_msg("Plugin_Load - %s - dlopen() | %s", Plugin_Getfile(name, path), dlerror());
-      #endif
+   if (!current->plugin.handle) {
+      DEBUG_MSG("Plugin_Load - %s - dlopen() | %s", Plugin_Getfile(name, path), dlerror());
       return 0;
    }
 
+   current->plugin.fini_function = dlsym(current->plugin.handle, SYM_PREFIX "Plugin_Fini");
 
-#if defined(OPENBSD) || defined(MACOSX)
-   current->plugin.fini_function = dlsym(current->plugin.handle, "_Plugin_Fini");
-#else
-   current->plugin.fini_function = dlsym(current->plugin.handle, "Plugin_Fini");
-#endif
-   if (current->plugin.fini_function == NULL)
-   {
-      #ifdef DEBUG
-         Debug_msg("Plugin_Load - %s - dlsym() | %s", Plugin_Getfile(name, path), dlerror());
-      #endif
+   if (current->plugin.fini_function == NULL) {
+      DEBUG_MSG("Plugin_Load - %s - dlsym() | %s", Plugin_Getfile(name, path), dlerror());
       dlclose(current->plugin.handle);
       current->plugin.handle = NULL;
       return 0;
    }
 
-#if defined(OPENBSD) || defined(MACOSX)
-   current->plugin.init_function = dlsym(current->plugin.handle, "_Plugin_Init");
-#else
-   current->plugin.init_function = dlsym(current->plugin.handle, "Plugin_Init");
-#endif
-   if (current->plugin.init_function == NULL)
-   {
-      #ifdef DEBUG
-         Debug_msg("Plugin_Load - %s - dlsym() | %s", Plugin_Getfile(name, path), dlerror());
-      #endif
+   current->plugin.init_function = dlsym(current->plugin.handle, SYM_PREFIX "Plugin_Init");
+
+   if (current->plugin.init_function == NULL) {
+      DEBUG_MSG("Plugin_Load - %s - dlsym() | %s", Plugin_Getfile(name, path), dlerror());
       dlclose(current->plugin.handle);
       current->plugin.handle = NULL;
       return 0;
    }
 
 
-   if ((current->plugin.init_function)(current) == 1)   // inizialize the plugin
-   {
+   if ((current->plugin.init_function)(current) == 1) {  // inizialize the plugin
       LIST_INSERT_HEAD(&loaded_plug_list, current, next);
       return 1;
-   }
-   else
-   {
+   } else {
       dlclose(current->plugin.handle);
       current->plugin.handle = NULL;
       return 0;
@@ -254,14 +230,10 @@ int Plugin_UnLoad(char *name)
 {
    struct plug_list *current;
 
-#ifdef DEBUG
-   Debug_msg("Plugin_UnLoad -- unloading %s plugin", name);
-#endif
+   DEBUG_MSG("Plugin_UnLoad -- unloading %s plugin", name);
 
-   LIST_FOREACH(current, &loaded_plug_list, next)
-   {
-      if (!strcmp(current->plugin.name, name))
-      {
+   LIST_FOREACH(current, &loaded_plug_list, next) {
+      if (!strcmp(current->plugin.name, name)) {
          (current->plugin.fini_function)(NULL);
          dlclose(current->plugin.handle);
          current->plugin.handle = NULL;
@@ -277,14 +249,10 @@ void Plugin_SetActivation(char *name, char status)
 {
    struct plug_list *current;
 
-#ifdef DEBUG
-   Debug_msg("Plugin_SetActivation -- %s\t %d", name, status);
-#endif
+   DEBUG_MSG("Plugin_SetActivation -- %s\t %d", name, status);
 
-   LIST_FOREACH(current, &loaded_plug_list, next)
-   {
-      if (!strcmp(current->plugin.name, name))
-      {
+   LIST_FOREACH(current, &loaded_plug_list, next) {
+      if (!strcmp(current->plugin.name, name)) {
          current->plugin.enabled = status;
          return;
       }
@@ -296,8 +264,7 @@ void Plugin_HookPoint(char hook_point, void *args)
 {
    struct plug_list *current;
 
-   LIST_FOREACH(current, &loaded_plug_list, next)
-   {
+   LIST_FOREACH(current, &loaded_plug_list, next) {
       if (current->plugin.enabled == 1 &&
           current->plugin.ops.hook_point == hook_point)
       {
@@ -313,25 +280,16 @@ int Plugin_RunExt(char *name)
    struct plug_list *current;
    int (*Plug_init)(void *);
 
-#ifdef DEBUG
-   Debug_msg("Plugin_RunExt -- executing external plugin %s", name);
-#endif
+   DEBUG_MSG("Plugin_RunExt -- executing external plugin %s", name);
 
-   LIST_FOREACH(current, &loaded_plug_list, next)
-   {
-      if (current->plugin.ops.plug_type == PT_EXT && !strcmp(current->plugin.name, name))
-      {
+   LIST_FOREACH(current, &loaded_plug_list, next) {
+      if (current->plugin.ops.plug_type == PT_EXT && !strcmp(current->plugin.name, name)) {
          Plugin_SYS_Output("Starting %s plugin...", name);
 
          current->plugin.handle = dlopen(Plugin_Getfile(current->plugin.name, current->plugin.path), RTLD_NOW);
 
-         #if defined(OPENBSD) || defined(MACOSX)
-            current->plugin.fini_function = dlsym(current->plugin.handle, "_Plugin_Fini");
-            Plug_init = dlsym(current->plugin.handle, "_Plugin_Init");
-         #else
-            current->plugin.fini_function = dlsym(current->plugin.handle, "Plugin_Fini");
-            Plug_init = dlsym(current->plugin.handle, "Plugin_Init");
-         #endif
+         current->plugin.fini_function = dlsym(current->plugin.handle, SYM_PREFIX "Plugin_Fini");
+         Plug_init = dlsym(current->plugin.handle, SYM_PREFIX "Plugin_Init");
 
          /* error checking was made at Plugin_Load(...) */
 
@@ -343,14 +301,12 @@ int Plugin_RunExt(char *name)
 
          dlclose(current->plugin.handle);             // unload
 
-         if (!Options.normal)
+         if (Options.onscreen)
             Plugin_SYS_Output("%s plugin ended.  (press 'q' to quit...)", name);
          else
             Plugin_SYS_Output("%s plugin ended.", name);
 
-         #ifdef DEBUG
-            Debug_msg("Plugin_RunExt -- shutting down external plugin %s", name);
-         #endif
+         DEBUG_MSG("Plugin_RunExt -- shutting down external plugin %s", name);
 
          return 1;
       }
@@ -397,10 +353,8 @@ char ** Plugin_ExtList(void)
 
    list = (char **)calloc(1, sizeof(char *));
 
-   LIST_FOREACH(current, &loaded_plug_list, next)
-   {
-      if (current->plugin.ops.plug_type == PT_EXT)
-      {
+   LIST_FOREACH(current, &loaded_plug_list, next) {
+      if (current->plugin.ops.plug_type == PT_EXT) {
          ++i;
          list = (char **)realloc(list, (i+1)*sizeof(char *));
          snprintf(line, sizeof(line), "%2d) %8s     v %.1f -- %s\n", i, current->plugin.name, (float)(current->plugin.ops.plug_version)/10, current->plugin.ops.plug_info);
@@ -420,8 +374,7 @@ int Plugin_ExtArray(void)
    struct plug_list *current;
    int i = 0;
 
-   LIST_FOREACH(current, &loaded_plug_list, next)
-   {
+   LIST_FOREACH(current, &loaded_plug_list, next) {
          ++i;
          Plugins_Array = (struct plug_array *)realloc(Plugins_Array, (i+1)*sizeof(struct plug_array));
          Plugins_Array[i-1].name = strdup(current->plugin.name);
@@ -466,7 +419,7 @@ void Plugin_Output(char *message, ...)
    va_end(ap);
 
 #ifdef HAVE_NCURSES
-   if (!Options.normal)
+   if (Options.onscreen)
    {
       wprintw(plugin_window, "%s", plug_output);
       pnoutrefresh(plugin_window, scroll_yp, 0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 - 2);
@@ -492,7 +445,7 @@ void Plugin_SYS_Output(char *message, ...)
 
 
 #ifdef HAVE_NCURSES
-   if (!Options.normal)
+   if (Options.onscreen)
    {
       #define HELP_COLOR 6
       #define NORM_COLOR 1
@@ -522,7 +475,7 @@ void Plugin_Hook_Output(char *message, ...)
    va_end(ap);
 
 #ifdef HAVE_NCURSES
-   if (!Options.normal)
+   if (Options.onscreen)
    {
       int mesglen = strlen(plug_output);
       Buffer_Put(pipe_with_plugins, &mesglen, sizeof(int) );
@@ -546,7 +499,7 @@ int Plugin_Input_GetChar_Block(char *string, size_t size)   // the real input
    int nchars=0;
 
    #ifdef HAVE_NCURSES
-      if (!Options.normal)
+      if (Options.onscreen)
       {
          pnoutrefresh(plugin_window, scroll_yp, 0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 - 2);
          doupdate();
@@ -558,7 +511,7 @@ int Plugin_Input_GetChar_Block(char *string, size_t size)   // the real input
    loop
    {
       #ifdef HAVE_NCURSES
-         if (!Options.normal)
+         if (Options.onscreen)
          {
             int c = 0;
             static int p_text = 0;
@@ -629,7 +582,7 @@ int Plugin_Input_GetChar_NonBlock(char *string, size_t size)   // the real input
       if (FD_ISSET(0, &msk_fd))
       {
          #ifdef HAVE_NCURSES
-            if (!Options.normal)
+            if (Options.onscreen)
             {
                int c = 0;
                static int p_text = 0;
@@ -689,3 +642,6 @@ int Plugin_Input_GetChar_NonBlock(char *string, size_t size)   // the real input
 #endif   // PERMIT_PLUGINS
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
