@@ -17,18 +17,23 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_simple.c,v 1.15 2002/02/10 10:07:49 alor Exp $
+    $Id: ec_simple.c,v 1.32 2002/04/18 17:03:17 alor Exp $
 */
 
 #include "include/ec_main.h"
 
 #include <fcntl.h>
 #ifndef CYGWIN
-	#include <sys/wait.h>
+   #include <sys/wait.h>
 #endif
 #include <signal.h>
 
-#include "include/ec_error.h"
+#if defined(HAVE_SYS_POLL_H)
+   #include <sys/poll.h>
+#elif defined (HAVE_POLL_H)
+   #include <poll.h>
+#endif
+
 #include "include/ec_inet.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_inet_forge.h"
@@ -45,7 +50,10 @@
 #include "include/ec_dryad.h"
 #include "include/ec_thread.h"
 
-#if defined (HAVE_TERMIOS_H) && !defined (CYGWIN)
+#if defined (HAVE_TERMIOS_H)
+   #ifdef CYGWIN
+      #undef FIONBIO    // avoid conflict with windows.h declarations
+   #endif
    #include <termios.h>
 
    struct termios old_tc;
@@ -71,9 +79,10 @@ void Simple_Run(void);
 void Simple_CheckForPoisoner(void);
 void Simple_FingerPrint(void);
 void Simple_CheckForSwitch(void);
-void Simple_Demonize(void);
+void Simple_Daemonize(void);
 void Simple_CreateCertFile(void);
 void Simple_PassiveScan(void);
+void Simple_OnlyPoison(pthread_t Dopple_pid);
 
 //---------------------------------
 
@@ -81,9 +90,7 @@ void Simple_HostList(void)
 {
    int j;
 
-#ifdef DEBUG
-   Debug_msg("Simple_HostList");
-#endif
+   DEBUG_MSG("Simple_HostList");
 
    printf("\nHost in this LAN:\n\n");
 
@@ -102,9 +109,7 @@ void Simple_FingerPrint(void)
    char MAC[6];
    char MACs[17];
 
-#ifdef DEBUG
-   Debug_msg("Simple_FingerPrint -- [%s]", Host_Dest.ip);
-#endif
+   DEBUG_MSG("Simple_FingerPrint -- [%s]", Host_Dest.ip);
 
    IP = inet_addr(Host_Dest.ip);
    memcpy(MAC, Inet_MacFromIP(IP), 6);
@@ -128,9 +133,7 @@ void Simple_CreateCertFile(void)
    FILE *fta, *ftr;
    char line[512];
 
-#ifdef DEBUG
-   Debug_msg("Simple_CreateCertFile");
-#endif
+   DEBUG_MSG("Simple_CreateCertFile");
 
    fprintf(stdout, "\nGenerating Openssl [%s] certificate...\n\n", CERT_FILE);
 
@@ -203,17 +206,13 @@ void Simple_CheckForPoisoner(void)
    int i;
    short found = 0;
 
-
-#ifdef DEBUG
-   Debug_msg("Simple_CheckForPoisoner");
-#endif
-
+   DEBUG_MSG("Simple_CheckForPoisoner");
 
    printf("\nChecking for poisoners...\n\n");
 
    SniffList = Inet_NoSniff();
 
-   for (i=0; i<number_of_hosts_in_lan; i++)
+   for (i=0; ; i++)
    {
       if (SniffList[i].mode == 0) break;
       if (SniffList[i].mode == 1)
@@ -240,9 +239,7 @@ void Simple_CheckForPoisoner(void)
 
 void Simple_Plugin(void)
 {
-#ifdef DEBUG
-   Debug_msg("Simple_Plugin -- %s", Execute_Plugin);
-#endif
+   DEBUG_MSG("Simple_Plugin -- %s", Execute_Plugin);
 
    if (strcmp(Host_Source.name, ""))
       strcpy(Host_Source.ip, Inet_NameToIp(Host_Source.name));
@@ -250,9 +247,7 @@ void Simple_Plugin(void)
    if (strcmp(Host_Dest.name, ""))
       strcpy(Host_Dest.ip, Inet_NameToIp(Host_Dest.name));
 
-#ifdef DEBUG
-   Debug_msg("Simple_Plugin -- [%s] [%s] [%s] [%s]", Host_Source.name, Host_Source.ip, Host_Dest.name, Host_Dest.ip );
-#endif
+   DEBUG_MSG("Simple_Plugin -- [%s] [%s] [%s] [%s]", Host_Source.name, Host_Source.ip, Host_Dest.name, Host_Dest.ip );
 
    if (!strcmp(Execute_Plugin, "list"))
    {
@@ -286,14 +281,19 @@ void Simple_Plugin(void)
 #endif
 
 
-void Simple_Demonize(void)
+void Simple_Daemonize(void)
 {
  pid_t pid;
 
-#ifdef DEBUG
-   Debug_msg("Simple_Demonize");
+   DEBUG_MSG("Simple_Daemonize");
+
+#ifdef CYGWIN
+   Error_msg("Demonization not yet supported under windows...");
 #endif
 
+   if (!Options.logtofile && !Options.onlypoison)
+      Error_msg("Demonizing without logging ?!?  what's the usefulness ?!?");
+
    if((signal(SIGTTOU, SIG_IGN)) == SIG_ERR)
       ERROR_MSG("signal()");
 
@@ -309,16 +309,92 @@ void Simple_Demonize(void)
    if((pid = fork()) < 0)
       ERROR_MSG("fork()");
    else if(pid != 0)
-      Error_msg("ettercap demonized with PID: %d", pid);
+      Error_msg("ettercap demonized with PID: %d", pid);    /* here is the father */
+
+
+   /* here is the son */
 
    if(setsid() == -1)
       ERROR_MSG("setsid()");
 
+   close(0);
+   close(1);
 
 }
 
 
-#if defined (HAVE_TERMIOS_H) && !defined (CYGWIN)
+
+void Simple_OnlyPoison(pthread_t Dopple_pid)
+{
+
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+   struct pollfd poll_fd;
+#else
+   fd_set msk_fd;
+   struct timeval TimeOut;
+#endif
+
+   
+   if (Options.quiet) {
+      while(1) sleep(10);  // wait the kill
+   }
+
+#if defined (HAVE_TERMIOS_H)
+   set_raw_term();   // non blocking stdin... yes this work !!
+#else
+   DEBUG_MSG("Simple_Run -- NO TERMIOS_H");
+   fcntl(0, F_SETFL, O_NONBLOCK);   // stdin non blocking... seems to be a non working method for me...
+#endif
+   
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+   poll_fd.fd = 0;
+   poll_fd.events = POLLIN;
+#else
+   memset(&TimeOut, 0, sizeof(TimeOut));  //  timeout = 0
+   FD_ZERO(&msk_fd);
+#endif
+
+   loop
+   {
+
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+      poll(&poll_fd, 1, 1);
+      if (poll_fd.revents & POLLIN)
+#else
+      FD_SET(0, &msk_fd);
+      select(FOPEN_MAX, &msk_fd, (fd_set *) 0, (fd_set *) 0, &TimeOut);
+      if (FD_ISSET(0, &msk_fd))
+#endif
+      {
+         char ch = 0;
+         ch = getchar();
+         switch(ch)
+         {
+            case 'H':
+            case 'h':
+                  printf("\n\n[qQ]  - quit\n");
+                  break;
+
+            case 'Q':
+            case 'q':
+#if defined (HAVE_TERMIOS_H)
+                 reset_term();
+#endif
+                  printf("\n\n\nShutting down all threads... ");
+                  fflush(stdout);
+                  ECThread_destroy(Dopple_pid);
+                  printf("Done.\n\n");
+                  exit(0);
+                  break;
+         }
+      }
+   }
+        
+}
+
+
+
+#if defined (HAVE_TERMIOS_H)
 
 void set_raw_term()        // taken from readchar.c, by M. Andreoli (2000)
 {
@@ -347,34 +423,40 @@ void Simple_Run(void)
    int i, index_source=-1, index_dest=-1;
    char view = ASCII_VIEW;
    char stop = 0;
-   fd_set msk_fd;
-   struct timeval TimeOut;
    SNIFFED_DATA data_from_illithid;
    int datalen = 0;
    char source[20], dest[20];
-   char proto = 'T', mode = IPBASED;
+   char proto = 'A';       // default value
+   char mode = IPBASED;    // defaulf value
    struct in_addr addr;
    TIME_DECLARE;
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+   struct pollfd poll_fd;
+#else
+   fd_set msk_fd;
+   struct timeval TimeOut;
+#endif
 
    if (Options.udp) proto = 'U';
+   else if (Options.tcp) proto = 'T';
+
+   if (Options.udp && Options.tcp) proto = 'A';
 
    number_of_connections = 0;
 
 #ifdef DEBUG
-   Debug_msg("Simple_Run - name - [%s][%s]", Host_Dest.name, Host_Source.name);
-   Debug_msg("Simple_Run -  IP  - [%s][%s]", Host_Dest.ip, Host_Source.ip);
-   Debug_msg("Simple_Run - port - [%d][%d]", Host_Dest.port, Host_Source.port);
-   Debug_msg("Simple_Run -  MAC - [%s][%s]", Host_Dest.mac, Host_Source.mac);
-   if (Options.sniff)      Debug_msg("Simple_Run - %c - sniff", proto);
-   if (Options.arpsniff)   Debug_msg("Simple_Run - %c - arpsniff", proto);
-   if (Options.macsniff)   Debug_msg("Simple_Run - %c - macsniff", proto);
+   DEBUG_MSG("Simple_Run - name - [%s][%s]", Host_Dest.name, Host_Source.name);
+   DEBUG_MSG("Simple_Run -  IP  - [%s][%s]", Host_Dest.ip, Host_Source.ip);
+   DEBUG_MSG("Simple_Run - port - [%d][%d]", Host_Dest.port, Host_Source.port);
+   DEBUG_MSG("Simple_Run -  MAC - [%s][%s]", Host_Dest.mac, Host_Source.mac);
+   if (Options.sniff)      DEBUG_MSG("Simple_Run - %c - sniff", proto);
+   if (Options.arpsniff)   DEBUG_MSG("Simple_Run - %c - arpsniff", proto);
+   if (Options.macsniff)   DEBUG_MSG("Simple_Run - %c - macsniff", proto);
 #endif
 
    if (Options.hexview)
       view = HEX_VIEW;
 
-   if (Options.quiet)
-      Simple_Demonize();
 
    if (strcmp(Host_Source.name, ""))
    {
@@ -455,14 +537,23 @@ void Simple_Run(void)
    }
 
 
+   if (Options.quiet)
+      Simple_Daemonize();
+   
    // it is ok...
 
-   if (Options.arpsniff)      // Doppleganger born...
+   if (Options.arpsniff || Options.onlypoison)      // Doppleganger born...
    {
       Inet_DisableForwarding();
       Dopple_pid = Doppleganger_Run(Options.netiface, Host_Source.ip, Host_Dest.ip, Host_Source.mac, Host_Dest.mac);
    }
 
+   
+   if (Options.onlypoison) {
+      printf(" Poisoning (ARP based) : %s:%d <--> %s <--> %s:%d\n\n", source, Host_Source.port, Inet_MyIPAddress(), dest, Host_Dest.port);
+      Simple_OnlyPoison(Dopple_pid);    // never returns
+   }
+   
    if (!Options.quiet) printf("\nPress 'h' for help...\n\n");
 
    pipe_with_illithid_data = Buffer_Create(5.0e5); // 500 Kb
@@ -506,26 +597,29 @@ void Simple_Run(void)
          break;
    }
 
-   switch (proto)
-   {
-      case 'T': printf(" TCP packets only... (default)\n\n"); break;
-      case 'U': printf(" UDP packets only...\n\n"); break;
+   if (Options.dumpfile) {
+      if (Options.writedump)
+         printf(" DUMPING to file [%s]...\n\n", Options.dumpfile);
+      else
+         printf(" OFFLINE sniffing from file [%s]...\n\n", Options.dumpfile);
    }
 
+   switch (proto) {
+      case 'T': printf(" TCP packets only...\n\n"); break;
+      case 'U': printf(" UDP packets only...\n\n"); break;
+      case 'A': printf(" TCP + UDP packets... (default)\n\n"); break;
+   }
+
+
 
    if (!Options.quiet && Options.collect) printf("Collecting passwords... \n\n");
 
-   memset(&TimeOut, 0, sizeof(TimeOut));  //  timeout = 0
-   FD_ZERO(&msk_fd);
-
    if(!Options.quiet)
    {
-      #if defined (HAVE_TERMIOS_H) && !defined (CYGWIN)
+      #if defined (HAVE_TERMIOS_H)
          set_raw_term();   // non blocking stdin... yes this work !!
       #else
-         #ifdef DEBUG
-            Debug_msg("Simple_Run -- NO TERMIOS_H");
-         #endif
+         DEBUG_MSG("Simple_Run -- NO TERMIOS_H");
          fcntl(0, F_SETFL, O_NONBLOCK);   // stdin non blocking... seems to be a non working method for me...
       #endif
    }
@@ -541,124 +635,138 @@ void Simple_Run(void)
 
    TIME_START;
 
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+   poll_fd.fd = 0;
+   poll_fd.events = POLLIN;
+#else
+   memset(&TimeOut, 0, sizeof(TimeOut));  //  timeout = 0
+   FD_ZERO(&msk_fd);
+#endif
+
    loop
    {
 
-      FD_SET(0, &msk_fd);
+      if (!Options.quiet) {
 
-      select(FOPEN_MAX, &msk_fd, (fd_set *) 0, (fd_set *) 0, &TimeOut);
-
-      if (FD_ISSET(0, &msk_fd))
-      {
-         char ch = 0;
-         ch = getchar();
-         switch(ch)
-         {
-            case 'A':
-            case 'a':
-                  if (!Options.collect)
-                  {
-                     printf("\n\nAscii mode...\n\n");
-                     view = ASCII_VIEW;
-                  }
-                  break;
-
-            case 'X':
-            case 'x':
-                  if (!Options.collect)
-                  {
-                     printf("\n\nHex mode...\n\n");
-                     view = HEX_VIEW;
-                  }
-                  break;
-
-            case 'T':
-            case 't':
-                  if (!Options.collect)
-                  {
-                     printf("\n\nTEXT only mode...\n\n");
-                     view = TEXT_VIEW;
-                  }
-                  break;
-
-            case 'L':
-            case 'l':
-                  if (Options.logtofile)
-                  {
-                     printf("\n\nStop logging to file(s)...\n\n");
-                     Options.logtofile = 0;
-                  }
-                  else
-                  {
-                     printf("\n\nLogging to file(s)...\n\n");
-                     Options.logtofile = 1;
-                  }
-                  break;
-
-            case ' ':
-                  if (stop == 1)
-                  {
-                     printf("\n\nLet's go...\n\n");
-                     stop = 0;
-                  }
-                  else
-                  {
-                     printf("\n\nStopped...\n\n");
-                     stop = 1;
-                  }
-                  break;
-
-            case 'S':
-            case 's':
-                  if (Options.filter)
-                  {
-                     filter_on_source = (filter_on_source) ? 0 : 1;
-                     printf("\n\nFILTERS: on source %d | on dest %d\n\n", filter_on_source, filter_on_dest);
-                  }
-                  break;
-
-            case 'D':
-            case 'd':
-                  if (Options.filter)
-                  {
-                     filter_on_dest = (filter_on_dest) ? 0 : 1;
-                     printf("\n\nFILTERS: on source %d | on dest %d\n\n", filter_on_source, filter_on_dest);
-                  }
-                  break;
-
-            case 'H':
-            case 'h':
-                  printf("\n\n[qQ]  - quit\n");
-                  if (!Options.collect)
-                  {
-                     printf(    "[aA]  - dump data in ascii mode\n");
-                     printf(    "[xX]  - dump data in hex mode\n");
-                     printf(    "[tT]  - dump data in text only mode\n");
-                  }
-                  if (Options.filter)
-                  {
-                     printf(    "[sS]  - set/unset filter on source\n");
-                     printf(    "[dD]  - set/unset filter on dest\n");
-                  }
-                  printf(    "[lL]  - log all trafic to file(s)\n");
-                  printf(    "space - stop/cont sniffing\n\n");
-                  break;
-
-            case 'Q':
-            case 'q':
-#if defined (HAVE_TERMIOS_H) && !defined (CYGWIN)
-                  if(!Options.quiet) reset_term();
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+         poll(&poll_fd, 1, 1);
+         if (poll_fd.revents & POLLIN)
+#else
+         FD_SET(0, &msk_fd);
+         select(FOPEN_MAX, &msk_fd, (fd_set *) 0, (fd_set *) 0, &TimeOut);
+         if (FD_ISSET(0, &msk_fd))
 #endif
-                  printf("\n\n\nShutting down all threads... ");
-                  fflush(stdout);
-                  ECThread_destroy(Illithid_pid);
-                  if (Dopple_pid) ECThread_destroy(Dopple_pid);
-                  #if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
-                     if (Grell_pid) ECThread_destroy(Grell_pid);
-                  #endif
-                  printf("Done.\n\n");
-                  exit(0);
-                  break;
+         {
+            char ch = 0;
+            ch = getchar();
+            switch(ch)
+            {
+               case 'A':
+               case 'a':
+                     if (!Options.collect)
+                     {
+                        printf("\n\nAscii mode...\n\n");
+                        view = ASCII_VIEW;
+                     }
+                     break;
+
+               case 'X':
+               case 'x':
+                     if (!Options.collect)
+                     {
+                        printf("\n\nHex mode...\n\n");
+                        view = HEX_VIEW;
+                     }
+                     break;
+
+               case 'T':
+               case 't':
+                     if (!Options.collect)
+                     {
+                        printf("\n\nTEXT only mode...\n\n");
+                        view = TEXT_VIEW;
+                     }
+                     break;
+
+               case 'L':
+               case 'l':
+                     if (Options.logtofile)
+                     {
+                        printf("\n\nStop logging to file(s)...\n\n");
+                        Options.logtofile = 0;
+                     }
+                     else
+                     {
+                        printf("\n\nLogging to file(s)...\n\n");
+                        Options.logtofile = 1;
+                     }
+                     break;
+
+               case ' ':
+                     if (stop == 1)
+                     {
+                        printf("\n\nLet's go...\n\n");
+                        stop = 0;
+                     }
+                     else
+                     {
+                        printf("\n\nStopped...\n\n");
+                        stop = 1;
+                     }
+                     break;
+
+               case 'S':
+               case 's':
+                     if (Options.filter)
+                     {
+                        filter_on_source = (filter_on_source) ? 0 : 1;
+                        printf("\n\nFILTERS: on source %d | on dest %d\n\n", filter_on_source, filter_on_dest);
+                     }
+                     break;
+
+               case 'D':
+               case 'd':
+                     if (Options.filter)
+                     {
+                        filter_on_dest = (filter_on_dest) ? 0 : 1;
+                        printf("\n\nFILTERS: on source %d | on dest %d\n\n", filter_on_source, filter_on_dest);
+                     }
+                     break;
+
+               case 'H':
+               case 'h':
+                     printf("\n\n[qQ]  - quit\n");
+                     if (!Options.collect)
+                     {
+                        printf(    "[aA]  - dump data in ascii mode\n");
+                        printf(    "[xX]  - dump data in hex mode\n");
+                        printf(    "[tT]  - dump data in text only mode\n");
+                     }
+                     if (Options.filter)
+                     {
+                        printf(    "[sS]  - set/unset filter on source\n");
+                        printf(    "[dD]  - set/unset filter on dest\n");
+                     }
+                     printf(    "[lL]  - log all trafic to file(s)\n");
+                     printf(    "space - stop/cont sniffing\n\n");
+                     break;
+
+               case 'Q':
+               case 'q':
+#if defined (HAVE_TERMIOS_H)
+                     if(!Options.quiet) reset_term();
+#endif
+                     printf("\n\n\nShutting down all threads... ");
+                     fflush(stdout);
+                     ECThread_destroy(Illithid_pid);
+                     if (Dopple_pid) ECThread_destroy(Dopple_pid);
+                     #if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+                        if (Grell_pid) ECThread_destroy(Grell_pid);
+                     #endif
+                     printf("Done.\n\n");
+                     exit(0);
+                     break;
+            }
          }
       }
 
@@ -676,13 +784,14 @@ void Simple_Run(void)
 
             for (j=0; j < number_of_connections; j++)
             {
+
                if (Conn_Between_Hosts[j].user[0] != 0 &&  Conn_Between_Hosts[j].pass[0] != 0)
                {
                   if (Options.logtofile) LogToFile_Collect(&Conn_Between_Hosts[j]);
 
                   if (!Options.quiet)
                   {
-                     printf("\n\n%02d:%02d:%02d  %s:%d <--> %s:%d%15s\n\n", dd->tm_hour, dd->tm_min, dd->tm_sec,
+                     printf("\n\n%02d:%02d:%02d  %s:%d <--> %s:%d%20s\n\n", dd->tm_hour, dd->tm_min, dd->tm_sec,
                            Conn_Between_Hosts[j].source_ip,
                            Conn_Between_Hosts[j].source_port,
                            Conn_Between_Hosts[j].dest_ip,
@@ -699,17 +808,13 @@ void Simple_Run(void)
                   memset(&Conn_Between_Hosts[j].user, 0, sizeof(Conn_Between_Hosts[j].user));
                   memset(&Conn_Between_Hosts[j].pass, 0, sizeof(Conn_Between_Hosts[j].pass));
                   memset(&Conn_Between_Hosts[j].info, 0, sizeof(Conn_Between_Hosts[j].info));
-                  #ifdef DEBUG
-                     Debug_msg("\tConnection %d displayed and deleted...", j+1);
-                  #endif
+                  DEBUG_MSG("\tConnection %d displayed and deleted...", j+1);
                }
             }  // end for
             TIME_FINISH;
             if (TIME_ELAPSED >= 300)
             {
-               #ifdef DEBUG
-                  Debug_msg("\tConnection List refreshed after %.0f minutes...", (TIME_ELAPSED)/60);
-               #endif
+               DEBUG_MSG("\tConnection List refreshed after %.0f minutes...", (TIME_ELAPSED)/60);
                TIME_START;                         // after 300 seconds (5 min)...
                Decodedata_RefreshConnectionList(); // periodically refresh the list...
             }
@@ -724,21 +829,23 @@ void Simple_Run(void)
                switch (view)
                {
                   case ASCII_VIEW:
-                     printf("\n\n\n%02d:%02d:%02d  %s:%d --> %s:%d\n\n%s", dd->tm_hour, dd->tm_min, dd->tm_sec,
+                     printf("\n\n\n%02d:%02d:%02d  %s:%d --> %s:%d  proto: %c\n\n%s", dd->tm_hour, dd->tm_min, dd->tm_sec,
                         data_from_illithid.source_ip,
                         data_from_illithid.source_port,
                         data_from_illithid.dest_ip,
                         data_from_illithid.dest_port,
+                        data_from_illithid.proto,
                         Decodedata_GetAsciiData(data_from_illithid.data, data_from_illithid.datasize)
                      );
                      break;
 
                   case TEXT_VIEW:
-                     printf("\n\n\n%02d:%02d:%02d  %s:%d --> %s:%d\n\n%s", dd->tm_hour, dd->tm_min, dd->tm_sec,
+                     printf("\n\n\n%02d:%02d:%02d  %s:%d --> %s:%d  proto: %c\n\n%s", dd->tm_hour, dd->tm_min, dd->tm_sec,
                         data_from_illithid.source_ip,
                         data_from_illithid.source_port,
                         data_from_illithid.dest_ip,
                         data_from_illithid.dest_port,
+                        data_from_illithid.proto,
                         Decodedata_GetTextData(data_from_illithid.data, data_from_illithid.datasize)
                      );
                      break;
@@ -755,7 +862,7 @@ void Simple_Run(void)
                            Decodedata_TCPFlags(data_from_illithid.flags),
                            Decodedata_GetHexData(data_from_illithid.data, data_from_illithid.datasize, 80)
                         );
-                     else
+                     else if (data_from_illithid.proto == 'U')
                         printf("\n\n%02d:%02d:%02d  %s:%d --> %s:%d | UDP |\n%s ", dd->tm_hour, dd->tm_min, dd->tm_sec,
                            data_from_illithid.source_ip,
                            data_from_illithid.source_port,
@@ -779,16 +886,18 @@ void Simple_PassiveScan(void)
 {
    pthread_t Dryad_pid;
    int i;
-   fd_set msk_fd;
-   struct timeval TimeOut;
    TIME_DECLARE;
    u_short passive_csum=0;
-
-#ifdef DEBUG
-   Debug_msg("Simple_PassiveScan");
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+   struct pollfd poll_fd;
+#else
+   fd_set msk_fd;
+   struct timeval TimeOut;
 #endif
 
-   if (Options.quiet)  Simple_Demonize();
+   DEBUG_MSG("Simple_PassiveScan");
+
+   if (Options.quiet)  Simple_Daemonize();
 
    if (!Options.quiet) printf("\nPress 'h' for help...\n\n");
 
@@ -796,150 +905,159 @@ void Simple_PassiveScan(void)
 
    if (!Options.quiet) printf(" Passive Scanning : ANY <--> ANY\n\n");
 
-   memset(&TimeOut, 0, sizeof(TimeOut));  //  timeout = 0
-   FD_ZERO(&msk_fd);
-
    if(!Options.quiet)
    {
-      #if defined (HAVE_TERMIOS_H) && !defined (CYGWIN)
+      #if defined (HAVE_TERMIOS_H)
          set_raw_term();   // non blocking stdin... yes this work !!
       #else
-         #ifdef DEBUG
-            Debug_msg("Simple_PassiveScan -- NO TERMIOS_H");
-         #endif
+         DEBUG_MSG("Simple_PassiveScan -- NO TERMIOS_H");
          fcntl(0, F_SETFL, O_NONBLOCK);   // stdin non blocking... seems to be a non working method for me...
       #endif
    }
 
    TIME_START;
 
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+   poll_fd.fd = 0;
+   poll_fd.events = POLLIN;
+#else
+   memset(&TimeOut, 0, sizeof(TimeOut));  //  timeout = 0
+   FD_ZERO(&msk_fd);
+#endif
+
       loop
       {
 
-         FD_SET(0, &msk_fd);
+         if (!Options.quiet) {
 
-         select(FOPEN_MAX, &msk_fd, (fd_set *) 0, (fd_set *) 0, &TimeOut);
-
-         if (FD_ISSET(0, &msk_fd))
-         {
-            char ch = 0;
-            ch = getchar();
-            switch(ch)
-            {
-
-               case 'L':
-               case 'l':
-                     printf("\n\nCollected infos dumped to %s\n\n", LogToFile_MakePassiveReport(ch));
-                     break;
-
-               case 'V':
-               case 'v':
-                     fprintf(stdout, "\n\n=================================================================\n");
-                     fprintf(stdout, "                        ETTERCAP REPORT \n");
-                     fprintf(stdout, "=================================================================\n");
-                        for (i=0; i < number_of_passive_hosts; i++)
-                        {
-                           struct open_ports *current;
-
-                           if (ch == 'v' && !strcmp(Passive_Host[i].type, "NL")) continue; // skip non local ip
-                           fprintf(stdout, "\n=================================================================\n");
-                           fprintf(stdout, "\n IP & MAC address    : %-15s%27s\n\n", Passive_Host[i].ip, Passive_Host[i].mac );
-                           fprintf(stdout, " HOSTNAME            : %s\n\n", Inet_HostName(Passive_Host[i].ip));
-                           if (!strcmp(Passive_Host[i].type, "GW")) fprintf(stdout, "**** THIS HOST IS A GATEWAY FOR IPs LIKE %s ****\n\n", Passive_Host[i].gwforthis);
-                           if (!strcmp(Passive_Host[i].type, "RT")) fprintf(stdout, "**** THIS HOST ACTS AS A ROUTER FOR THE LAN ****\n\n");
-                           if (!strcmp(Passive_Host[i].type, "NL")) fprintf(stdout, "**** THIS HOST DOESN'T BELONG TO THE NETMASK ****\n\n");
-                           if (Passive_Host[i].os[0] == 0 && Passive_Host[i].os[1] != 0)
-                           {
-                              fprintf(stdout, " UNKNOWN FINGERPRINT : %s\n",  Passive_Host[i].fingerprint);
-                              fprintf(stdout, " THE NEAREST IS      : %s\n\n", Passive_Host[i].os + 1);
-                           }
-                           else
-                           {
-                              fprintf(stdout, " FINGERPRINT         : %s\n\n",  Passive_Host[i].fingerprint);
-                              fprintf(stdout, " OPERATING SYSTEM    : %s\n\n",  Passive_Host[i].os);
-                           }
-                           fprintf(stdout, " NETWORK ADAPTER     : %s\n\n",  Fingerprint_MAC(Passive_Host[i].mac));
-                           fprintf(stdout, " DISTANCE IN HOP     : %d\n\n", Passive_Host[i].hop);
-                           if (!LIST_EMPTY(&Passive_Host[i].tcp_ports))
-                           {
-                              LIST_FOREACH(current, &Passive_Host[i].tcp_ports, next)
-                              {
-                                 if (current == LIST_FIRST(&Passive_Host[i].tcp_ports))
-                                    fprintf(stdout, " OPEN PORTS  (tcp)   : %-5d  %s\n", current->port, Decodedata_GetType('T', current->port, current->port) );
-                                 else
-                                    fprintf(stdout, "                     : %-5d  %s\n", current->port, Decodedata_GetType('T', current->port, current->port) );
-                              }
-                           }
-                           else
-                              fprintf(stdout, " OPEN PORTS  (tcp)   : NONE\n");
-
-                           fprintf(stdout, "\n");
-
-                           if (!LIST_EMPTY(&Passive_Host[i].udp_ports))
-                           {
-                              LIST_FOREACH(current, &Passive_Host[i].udp_ports, next)
-                              {
-                                 if (current == LIST_FIRST(&Passive_Host[i].udp_ports))
-                                    fprintf(stdout, " OPEN PORTS  (udp)   : %-5d  %s\n", current->port, Decodedata_GetType('U', current->port, current->port) );
-                                 else
-                                    fprintf(stdout, "                     : %-5d  %s\n", current->port, Decodedata_GetType('U', current->port, current->port) );
-                              }
-                           }
-                           else
-                              fprintf(stdout, " OPEN PORTS  (udp)   : NONE\n");
-
-                           fprintf(stdout, "\n");
-
-                           if (!LIST_EMPTY(&Passive_Host[i].tcp_ports))
-                           {
-                              LIST_FOREACH(current, &Passive_Host[i].tcp_ports, next)
-                              {
-                                 if (!strlen(current->banner)) continue;
-                                 if (current == LIST_FIRST(&Passive_Host[i].tcp_ports))
-                                    fprintf(stdout, " TCP SERVICES BANNER : %-5d  %s\n", current->port, current->banner );
-                                 else
-                                    fprintf(stdout, "                     : %-5d  %s\n", current->port, current->banner );
-                              }
-                           }
-                           fprintf(stdout, "\n=================================================================\n");
-                        }
-                     break;
-
-               case 'H':
-               case 'h':
-                     printf("\n\n[qQ]  - quit\n");
-                     printf(    "[l ]  - dump the local report to a file\n");
-                     printf(    "[L ]  - dump the FULL report to a file\n");
-                     printf(    "[v ]  - view the local report\n");
-                     printf(    "[V ]  - view the FULL report\n\n");
-                     break;
-
-               case 'Q':
-               case 'q':
-#if defined (HAVE_TERMIOS_H) && !defined (CYGWIN)
-                     if(!Options.quiet) reset_term();
+#if defined(HAVE_SYS_POLL_H) || defined(HAVE_POLL_H)
+            poll(&poll_fd, 1, 1);
+            if (poll_fd.revents & POLLIN)
+#else
+            FD_SET(0, &msk_fd);
+            select(FOPEN_MAX, &msk_fd, (fd_set *) 0, (fd_set *) 0, &TimeOut);
+            if (FD_ISSET(0, &msk_fd))
 #endif
-                     printf("\n\n\nShutting down all threads... ");
-                     fflush(stdout);
-                     ECThread_destroy(Dryad_pid);
-                     Decodedata_FreePassiveList();
-                     printf("Done.\n\n");
-                     exit(0);
-                     break;
+            {
+               char ch = 0;
+               ch = getchar();
+               switch(ch)
+               {
+
+                  case 'L':
+                  case 'l':
+                        printf("\n\nCollected infos dumped to %s\n\n", LogToFile_MakePassiveReport(ch));
+                        break;
+
+                  case 'V':
+                  case 'v':
+                        fprintf(stdout, "\n\n=================================================================\n");
+                        fprintf(stdout, "                        ETTERCAP REPORT \n");
+                        fprintf(stdout, "=================================================================\n");
+                           for (i=0; i < number_of_passive_hosts; i++)
+                           {
+                              struct open_ports *current;
+
+                              if (ch == 'v' && !strcmp(Passive_Host[i].type, "NL")) continue; // skip non local ip
+                              fprintf(stdout, "\n=================================================================\n");
+                              fprintf(stdout, "\n IP & MAC address    : %-15s%27s\n\n", Passive_Host[i].ip, Passive_Host[i].mac );
+                              fprintf(stdout, " HOSTNAME            : %s\n\n", Inet_HostName(Passive_Host[i].ip));
+                              if (!strcmp(Passive_Host[i].type, "GW")) fprintf(stdout, "**** THIS HOST IS A GATEWAY FOR IPs LIKE %s ****\n\n", Passive_Host[i].gwforthis);
+                              if (!strcmp(Passive_Host[i].type, "RT")) fprintf(stdout, "**** THIS HOST ACTS AS A ROUTER FOR THE LAN ****\n\n");
+                              if (!strcmp(Passive_Host[i].type, "NL")) fprintf(stdout, "**** THIS HOST DOESN'T BELONG TO THE NETMASK ****\n\n");
+                              if (Passive_Host[i].os[0] == 0 && Passive_Host[i].os[1] != 0)
+                              {
+                                 fprintf(stdout, " UNKNOWN FINGERPRINT : %s\n",  Passive_Host[i].fingerprint);
+                                 fprintf(stdout, " THE NEAREST IS      : %s\n\n", Passive_Host[i].os + 1);
+                              }
+                              else
+                              {
+                                 fprintf(stdout, " FINGERPRINT         : %s\n\n",  Passive_Host[i].fingerprint);
+                                 fprintf(stdout, " OPERATING SYSTEM    : %s\n\n",  Passive_Host[i].os);
+                              }
+                              fprintf(stdout, " NETWORK ADAPTER     : %s\n\n",  Fingerprint_MAC(Passive_Host[i].mac));
+                              fprintf(stdout, " DISTANCE IN HOP     : %d\n\n", Passive_Host[i].hop);
+                              if (!LIST_EMPTY(&Passive_Host[i].tcp_ports))
+                              {
+                                 LIST_FOREACH(current, &Passive_Host[i].tcp_ports, next)
+                                 {
+                                    if (current == LIST_FIRST(&Passive_Host[i].tcp_ports))
+                                       fprintf(stdout, " OPEN PORTS  (tcp)   : %-5d  %s\n", current->port, Decodedata_GetType('T', current->port, current->port) );
+                                    else
+                                       fprintf(stdout, "                     : %-5d  %s\n", current->port, Decodedata_GetType('T', current->port, current->port) );
+                                 }
+                              }
+                              else
+                                 fprintf(stdout, " OPEN PORTS  (tcp)   : NONE\n");
+
+                              fprintf(stdout, "\n");
+
+                              if (!LIST_EMPTY(&Passive_Host[i].udp_ports))
+                              {
+                                 LIST_FOREACH(current, &Passive_Host[i].udp_ports, next)
+                                 {
+                                    if (current == LIST_FIRST(&Passive_Host[i].udp_ports))
+                                       fprintf(stdout, " OPEN PORTS  (udp)   : %-5d  %s\n", current->port, Decodedata_GetType('U', current->port, current->port) );
+                                    else
+                                       fprintf(stdout, "                     : %-5d  %s\n", current->port, Decodedata_GetType('U', current->port, current->port) );
+                                 }
+                              }
+                              else
+                                 fprintf(stdout, " OPEN PORTS  (udp)   : NONE\n");
+
+                              fprintf(stdout, "\n");
+
+                              if (!LIST_EMPTY(&Passive_Host[i].tcp_ports))
+                              {
+                                 LIST_FOREACH(current, &Passive_Host[i].tcp_ports, next)
+                                 {
+                                    if (!strlen(current->banner)) continue;
+                                    if (current == LIST_FIRST(&Passive_Host[i].tcp_ports))
+                                       fprintf(stdout, " TCP SERVICES BANNER : %-5d  %s\n", current->port, current->banner );
+                                    else
+                                       fprintf(stdout, "                     : %-5d  %s\n", current->port, current->banner );
+                                 }
+                              }
+                              fprintf(stdout, "\n=================================================================\n");
+                           }
+                        break;
+
+                  case 'H':
+                  case 'h':
+                        printf("\n\n[qQ]  - quit\n");
+                        printf(    "[l ]  - dump the local report to a file\n");
+                        printf(    "[L ]  - dump the FULL report to a file\n");
+                        printf(    "[v ]  - view the local report\n");
+                        printf(    "[V ]  - view the FULL report\n\n");
+                        break;
+
+                  case 'Q':
+                  case 'q':
+#if defined (HAVE_TERMIOS_H)
+                        if(!Options.quiet) reset_term();
+#endif
+                        printf("\n\n\nShutting down all threads... ");
+                        fflush(stdout);
+                        ECThread_destroy(Dryad_pid);
+                        Decodedata_FreePassiveList();
+                        printf("Done.\n\n");
+                        exit(0);
+                        break;
+               }
             }
+
          }
 
+
          if (Options.logtofile)
          {
             TIME_FINISH;
             if (TIME_ELAPSED >= 300)
             {
-               #ifdef DEBUG
-                  Debug_msg("\tCollected infos saved after %.0f minutes...", (TIME_ELAPSED)/60);
-               #endif
+               DEBUG_MSG("\tCollected infos saved after %.0f minutes...", (TIME_ELAPSED)/60);
                if (!Options.quiet) printf("\tCollected infos saved after %.0f minutes..." ,(TIME_ELAPSED)/60);
                TIME_START;                       // after 300 seconds (5 min)...
-               LogToFile_MakePassiveReport('l'); // periodically save the list...
+               LogToFile_MakePassiveReport('L'); // periodically save the list...
             }
          }
 
@@ -966,3 +1084,6 @@ void Simple_PassiveScan(void)
 
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
