@@ -17,14 +17,11 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_threads.c,v 1.4 2002/02/10 10:07:49 alor Exp $
+    $Id: ec_threads.c,v 1.7 2002/04/11 20:16:36 alor Exp $
 */
 
 #include "include/ec_main.h"
 
-#include "include/ec_error.h"
-#include "include/ec_queue.h"
-
 
 struct thread_list {
    char name[10];
@@ -50,8 +47,7 @@ char * ECThread_getname(pthread_t id)
 {
    struct thread_list *current;
 
-   LIST_FOREACH(current, &thread_list_head, next)
-   {
+   LIST_FOREACH(current, &thread_list_head, next) {
       if (current->id == id)
          return current->name;
    }
@@ -64,9 +60,7 @@ void ECThread_register(pthread_t id, char * name)
 {
    struct thread_list *current, *newelem;
 
-#ifdef DEBUG
-   Debug_msg("ECThread_register -- %s", name);
-#endif
+   DEBUG_MSG("ECThread_register -- %s", name);
 
    newelem = (struct thread_list *) calloc(1, sizeof(struct thread_list));
    if (!newelem)
@@ -75,10 +69,8 @@ void ECThread_register(pthread_t id, char * name)
    newelem->id = id;
    strlcpy(newelem->name, name, 10);
 
-   LIST_FOREACH(current, &thread_list_head, next)
-   {
-      if (current->id == id)
-      {
+   LIST_FOREACH(current, &thread_list_head, next) {
+      if (current->id == id) {
          LIST_REPLACE(current, newelem, next);
          return;
       }
@@ -92,9 +84,7 @@ pthread_t ECThread_create(char * name, void *(*function)(void *), void *args)
 {
    pthread_t id;
 
-#ifdef DEBUG
-   Debug_msg("ECThread_create -- %s", name);
-#endif
+   DEBUG_MSG("ECThread_create -- %s", name);
 
    pthread_create(&id, NULL, function, args);
 
@@ -108,9 +98,7 @@ void ECThread_destroy(pthread_t id)
 {
    struct thread_list *current;
 
-#ifdef DEBUG
-   Debug_msg("ECThread_destroy -- terminating %d", id);
-#endif
+   DEBUG_MSG("ECThread_destroy -- terminating %d [%s]", id, ECThread_getname(id));
 
    pthread_cancel(id);
 
@@ -129,13 +117,9 @@ void ECThread_destroy(pthread_t id)
 
 #endif
 
-   LIST_FOREACH(current, &thread_list_head, next)
-   {
-      if (current->id == id)
-      {
-         #ifdef DEBUG
-            Debug_msg("ECThread_destroy -- %d [%s] terminated !", current->id, current->name);
-         #endif
+   LIST_FOREACH(current, &thread_list_head, next) {
+      if (current->id == id) {
+         DEBUG_MSG("ECThread_destroy -- %d [%s] terminated !", current->id, current->name);
          LIST_REMOVE(current, next);
          free(current);
       }
@@ -145,3 +129,6 @@ void ECThread_destroy(pthread_t id)
 
 /* EOF */
 
+
+// vim:ts=3:expandtab
+
