@@ -5,6 +5,7 @@
 extern void Decodedata_SetArrayIndex(CONNECTION *data, int index);
 extern int Decodedata_MakeConnectionList(CONNECTION *data);
 extern int Decodedata_RefreshConnectionList(void);
+extern void * DecodeData_Connection_Timeouter(void *dummy);
 
 extern int Decodedata_GetPassiveOS(char *fingerprint, char *os);
 extern int Decodedata_MakePassiveList(PASSIVE_DATA *data);
@@ -22,3 +23,6 @@ extern void Decodedata_Passive_SortList(void);
 #endif
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
