@@ -27,8 +27,13 @@ typedef struct {
    RPC_PORTS *ports;
 } RPC_DISSECTOR;
 
+
+/* forward declaration */
+struct packet_object;
+
 // functions...
 extern int Dissector_Connections( char mode, short proto, u_char *data, CONNECTION *data_to_ettercap, SNIFFED_DATA *sniff_data_to_ettercap, int Conn_Mode );
+extern int Dissector_SetDissector(struct packet_object *po);
 extern void Dissector_SetHandle( char *name, char active, short port, short proto);
 extern int Dissector_StateMachine_GetStatus(CONNECTION *data_to_ettercap, char *info);
 extern int Dissector_StateMachine_SetStatus(CONNECTION *data_to_ettercap, char status, char *info);
@@ -51,6 +56,13 @@ extern int Dissector_base64decode(char *bufplain, const char *bufcoded);
 #define ONLY_CONNECTION {}
 #define DATA_DISSECTOR  {}
 
+
+#define PREPARE_VIRTUAL_BUFFER   { \
+                                    vbuf_p vbuf; \
+                                    vbuf_create(&vbuf, po->data.data, po->data.len); \
+                                 }
+
+
 // dissectors....
 extern FUNC_DISSECTOR(Dissector_ftp);        // 21
 #ifdef HAVE_OPENSSL
@@ -73,13 +85,17 @@ extern FUNC_DISSECTOR(Dissector_https);      // 443
 extern FUNC_DISSECTOR(Dissector_rlogin);     // 512 513 514
 extern FUNC_DISSECTOR(Dissector_rip);        // 520              UDP
 extern FUNC_DISSECTOR(Dissector_socks);      // 1080
+extern FUNC_DISSECTOR(Dissector_msn);        // 1863
 extern FUNC_DISSECTOR(Dissector_mysql);      // 3306
-extern FUNC_DISSECTOR(Dissector_icq);        // 4000 5190 ALL_P  UDP
+extern FUNC_DISSECTOR(Dissector_icqv5);      // 4000 ALL_P       UDP
+extern FUNC_DISSECTOR(Dissector_ymsg);       // 5050
+extern FUNC_DISSECTOR(Dissector_icqv7);      // 5190
 extern FUNC_DISSECTOR(Dissector_vnc);        // 5900-5905
 extern FUNC_DISSECTOR(Dissector_x11);        // 6000-6005
 extern FUNC_DISSECTOR(Dissector_napster);    // 6666 7777 8888
 extern FUNC_DISSECTOR(Dissector_irc);        // 6667-6669
 extern FUNC_DISSECTOR(Dissector_hl_rcon);    // 27015            UDP
+extern FUNC_DISSECTOR(Dissector_quake3);     // 27960            UDP
 extern FUNC_DISSECTOR(Dissector_pcanywhere); // 65301
 
 // RPC Dissectors
@@ -89,3 +105,6 @@ extern FUNC_DISSECTOR(Dissector_mountdUDP);
 #endif
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
