@@ -13,6 +13,14 @@ extern void Interface_Redraw(void);
 extern char Interface_PopUp(char *question, ...);
 extern void Interface_HelpWindow(char *help[]);
 
+
+#ifdef CYGWIN
+   #define MIN_DO_UPDATE_DELAY 50
+#endif
+
 #endif
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
