@@ -1,5 +1,5 @@
 
-/* $Id: ec_main.h,v 1.22 2002/02/11 20:46:50 alor Exp $ */
+/* $Id: ec_main.h,v 1.43 2002/04/22 19:43:44 alor Exp $ */
 
 
 #if !defined(EC_MAIN_H)
@@ -10,10 +10,11 @@
    #include <config.h>     // autoheader   -I.
 #endif
 
-#define DEVEL_RELEASE 0
-#define VERSION "0.6.4"
-#define PROGRAM "ettercap"
-#define AUTHORS "ALoR & NaGA"
+#define DEVEL_RELEASE   0 
+#define RELEASE_DATE    "20020422"
+#define VERSION         "0.6.5"
+#define PROGRAM         "ettercap"
+#define AUTHORS         "ALoR & NaGA"
 
 #define loop for(;;)
 
@@ -28,19 +29,24 @@
 #endif
 #include <strings.h>
 #ifdef CYGWIN
-	#include <windows.h>
-	#include <winsock2.h>
+   #include <windows.h>
+   #include <winsock2.h>
 #else
-	#include <sys/types.h>
-	#include <sys/time.h>
+   #include <sys/types.h>
+   #include <sys/time.h>
 #endif
 #include <unistd.h>
 #include <time.h>
 #include <pthread.h>
 #include "ec_queue.h"
+#include "ec_error.h"
+#include "ec_debug.h"
 
-#ifdef DEBUG
-   #include "ec_debug.h"
+#include "ec_stdint.h"
+
+
+#ifdef HAVE_PDCURSES
+   #undef MOUSE_MOVED
 #endif
 
 #ifndef HAVE_STRLCAT             // missing functions
@@ -60,11 +66,11 @@
 #endif
 
 #if defined (MACOSX) || defined (CYGWIN)
-	#define exit_func(x) atexit((void (*)(void))x)
-	#define exit_func_end()
+   #define exit_func(x) atexit((void (*)(void))x)
+   #define exit_func_end()
 #else
-	#define exit_func(x)    pthread_cleanup_push(x, (void *)NULL)
-	#define exit_func_end() pthread_cleanup_pop(0)
+   #define exit_func(x)    pthread_cleanup_push(x, (void *)NULL)
+   #define exit_func_end() pthread_cleanup_pop(0)
 #endif
 
 typedef struct host_arp          // hosts in LAN info
@@ -84,36 +90,41 @@ extern HOST Host_Dest;
 
 typedef struct options_list      // arguments passed on command line
 {
-   char list:1;
-   char arpsniff:1;
+   char list:1;            // list of hosts in the lan
+   char arpsniff:1;        // sniffing methods
    char sniff:1;
    char macsniff:1;
-   char normal:1;
-   char check:1;
+   char normal:1;          // no ncurses
+   char onscreen:1;        // 1 when ncurses screen is inizialized
+   char check:1;           // check for other poisoners
    char plugin:1;
    char hexview:1;
-   char silent:1;
-   char udp:1;
-   char finger:1;
-   char link:1;
-   char collect:1;
-   char broadping:1;
+   char silent:1;          // no ARP storm on startup
+   char udp:1;             // which packet to sniff ?
+   char tcp:1;
+   char finger:1;          // active fingerprinting
+   char link:1;            // test the link type (switch or hub)
+   char collect:1;         // collect USER and PASS
+   char broadping:1;       // uses ICMP instead of ARP to scan the lan
    char logtofile:1;
-   char quiet:1;
-   char dontresolve:1;
+   char quiet:1;           // demonization
+   char dontresolve:1;     // dont resolve host names
    char filter:1;
-   char version:1;
-   char yes:1;
-   char reverse;
-   char passive:1;
-   char hostsfromfile:1;
-   char hoststofile:1;
+   char version:1;         // checks for new version
+   char yes:1;             // answer yes to questions of version
+   char reverse;           // all the connection BUT this (reverse matching)
+   char passive:1;         // passive OS fingerprint
+   char hostsfromfile:1;   // load the list from a file
+   char hoststofile:1;     // save the host list to a file
    char *hostfile;
-   char netiface[10];
+   char netiface[10];      // the name of the selected interface
    char netmask[16];
-   short delay;
-   u_long spoofIp;
-   int storm_delay;
+   char writedump:1;			// dump the file
+   char *dumpfile;         // the tcpdump file format for offline analysis
+   char onlypoison:1;
+   short delay;            // delay between ARP replies
+   u_long spoofIp;         // the IP used to spoof the ARP request
+   int storm_delay;        // delay between ARP request on startup
 } OPTIONS;
 
 extern OPTIONS Options;
@@ -204,13 +215,13 @@ typedef struct connection        // connection list
    char status[8];
    time_t timestamp;
    char type[18];          // from /etc/services
-   char user[30];          // pay attention on buffer overflow !!
-   char pass[30];
+   char user[50];          // pay attention on buffer overflow !!
+   char pass[50];
    char info[150];         // additional info... ( smb domain, http page ...)
 } CONNECTION;
 
 
-typedef struct dissect		// structs to be passed to Plugin_HookPoint
+typedef struct dissect     // structs to be passed to Plugin_HookPoint
 {
    u_char *layer4;
    CONNECTION *connection;
@@ -278,7 +289,21 @@ extern char filter_on_source;
 extern char filter_on_dest;
 extern int Connection_Mode;      // ec_illithid.c
 
-#if defined(HAVE_GETTIMEOFDAY) && !defined(CYGWIN)
+#ifdef CYGWIN 				// damned cygwin include...
+struct timezone {
+  int tz_minuteswest;
+  int tz_dsttime;
+};
+
+int gettimeofday(struct timeval *__p, struct timezone *__z);
+#endif
+
+#ifdef CYGWIN
+   #define TIME_DECLARE float start, finish
+   #define TIME_START   start=GetTickCount()
+   #define TIME_FINISH  finish=GetTickCount()
+   #define TIME_ELAPSED ((finish-start)/1.0e3)          // GetTickCount returns milliseconds
+#elif defined(HAVE_GETTIMEOFDAY)
    #define TIME_DECLARE struct timeval start, finish
    #define TIME_START   gettimeofday(&start, 0)
    #define TIME_FINISH  gettimeofday(&finish, 0)
@@ -318,6 +343,9 @@ extern int host_to_be_scanned;
 #define CONN_TIME_TIMEOUT  1200
 
 
-#endif	// EC_MAIN_H
+#endif   // EC_MAIN_H
 
 /* EOF */
+
+// vim:ts=3:expandtab
+
