@@ -33,10 +33,10 @@ struct packet_object {
 
 	int * len;
 
-	int (*decode)(struct packet_object *, void *);  /* pointer to the dissector function */
-   char decode_mode;                               /* sniffing method: ARP, SMART, IP, MAC */
+	int (*decode)(struct packet_object *, void *);
+   char decode_mode;
 
-	int (*filter)(struct packet_object *, void *);  /* filtering function */
+	int (*filter)(struct packet_object *, void *);
 };
 
 extern int packet_create_object(struct packet_object **po, u_char * buf, int * len);
@@ -46,11 +46,11 @@ extern int packet_destroy_object(struct packet_object **po);
 extern int packet_duplicate(struct packet_object *po, char level, u_char **buf);
 #define LEVEL_2		0           /* 00000000 */
 #define LEVEL_3		1           /* 00000001 */ 
-#define LEVEL_4		(1 << 1)    /* 00000010 */ 
-#define LEVEL_DATA	(1 << 2)    /* 00000100 */ 
+#define LEVEL_4		(1 << 2)    /* 00000010 */ 
+#define LEVEL_DATA	(1 << 3)    /* 00000100 */ 
 #define LEVEL_MASK   0x7         /* 00000111 */
-#define DUP_COPY     (1 << 3)    /* 00001000 */ 
-#define DUP_ALLOC    (1 << 4)    /* 00010000 */
+#define DUP_COPY     (1 << 4)    /* 00001000 */ 
+#define DUP_ALLOC    (1 << 5)    /* 00010000 */
 
 
 
