@@ -22,23 +22,16 @@
 
 	typedef int8_t    int8;
 	typedef int16_t   int16;
-   #ifndef CYGWIN
+	#ifndef CYGWIN
 	typedef int32_t   int32;
-   #endif
+	#endif
 	typedef int64_t   int64;
 
-   #ifdef SOLARIS
-	typedef uint8_t   u_int8;
-	typedef uint16_t  u_int16;
-	typedef uint32_t  u_int32;
-	typedef uint64_t  u_int64;
-   #else
 	typedef u_int8_t   u_int8;
 	typedef u_int16_t  u_int16;
 	typedef u_int32_t  u_int32;
 	typedef u_int64_t  u_int64;
-   #endif
-   
+
 #endif
 
 
